searchNodes=[{"doc":"Definition of macro to make mapping of asset URLs from their file paths.If a gear invokes static_prefix/0 in its Router module, antikythera automatically serves static assets (such as HTML, CSS, JS, images) under priv/static/ directory (see Antikythera.Router for detail). Although this is handy it's suboptimal in cloud environments. Instead, in cloud environments, static assets can be delivered from CDN service. Using CDN for assets has the following benefits:faster page loadless resource consumption (CPU, network bandwidth, etc.) in both ErlangVMs and load balancersmore fine-grained control on asset versionsTo keep track of modifications in asset files, we use MD5 digest of file contents: download URLs contain MD5 hashes in their paths. This way we can serve multiple versions of a single asset file.When a gear is deployed, antikythera's auto-deploy script uploads each asset to cloud storage (if the file has modification since last deploy) so that they are readily served by CDN. Each asset is served in gzip-compressed format if its file extension indicates that gzip compression can be beneficial. Also, assets are configured to accept CORS with e.g. XMLHttpRequest. When downloaded, each asset comes with a relatively long max-age in cache-control response header so that the data can be reused as long as its content (and thus MD5 digest) does not change.This module provides __using__/2 macro thatenables asset serving via CDNgenerates functions that absorb differences in asset download URLsUsageDefine a module that uses Antikythera.Asset as follows:defmodule YourGear.Asset do use Antikythera.Asset endThen YourGear.Asset has the following functions.url/1 : given a file path relative to priv/static/ directory, returns a URL to download the fileall/0 : returns all pairs of file path and download URL as a mapIf you want antikythera's auto-deploy script to perform asset preparation BEFORE compilations of your gear (including YourGear.Asset module), set up asset preparation methods as described in Mix.Tasks.Antikythera.PrepareAssets.You can now freely use the module for e.g.HAML templates that refers to asset filesWebAPI that returns the URLs of the latest assets in your preferred format (JSON, javascript, etc.)With YourGear.Asset as above, antikythera's auto-deploy script uploads asset files to cloud storage so that they are readily served by CDN.Asset URLs during developmentIf you are using tools such as webpack-dev-server during development, you may want your browser to download assets from a web server other than locally-running antikythera. In this case, pass :base_url_during_development option to __using__/2 so that url/1 and all/0 return URLs that point to the specified endpoint.Retention/cleanup policy for asset filesAn asset file uploaded to cloud storage during deployment of a certain gear version becomes &quot;obsolete&quot; when a newly-deployed gear version no longer uses it (the file has been either modified, removed or renamed).Antikythera keeps track of whether each asset file is obsolete or not. Then, antikythera periodically removes asset files that have been obsolete for more than 90 days. The retention period (chosen such that each period includes several deployments of each gear) should be long enough for clients to switch from older assets to newer ones.","ref":"Antikythera.Asset.html","title":"Antikythera.Asset","type":"module"},{"doc":"","ref":"Antikythera.Asset.html#list_asset_file_paths/0","title":"Antikythera.Asset.list_asset_file_paths/0","type":"function"},{"doc":"","ref":"Antikythera.Asset.html#retention_days/0","title":"Antikythera.Asset.retention_days/0","type":"function"},{"doc":"Antikythera's &quot;async job&quot; functionality allows gears to run their code in background.This module is the interface for gear implementations to define and register their own async jobs.UsagePreparing your async job moduleEach gear can define multiple async job modules. Those modules must use this module as in the following example:defmodule YourGear.SomeAsyncJob do use Antikythera.AsyncJob # run/3 callback is required @impl true def run(_payload, _metadata, _context) do # do something here end # abandon/3 callback is optional; you can omit it @impl true def abandon(_payload, _metadata, _context) do # cleanup code when all retries failed end # inspect_payload/1 callback is optional; you can omit it @impl true def inspect_payload(payload) do # convert a payload to a short string that can be used to identify a job in logs end endImplementations of run/3 can return any value; it is simply ignored. If execution of run/3 terminated abnormally (exception, timeout, etc.) the job is regarded as failed. Failed jobs are automatically retried up to a specified number of attempts (see below).abandon/3 optional callback is called when a job is abandoned after all attempts failed. You can put your cleanup logic in this callback when e.g. you use external storage system to store job information. Note that abandon/3 must finish within 10 seconds; when it takes longer, antikythera stops the execution of abandon/3 in the middle.inspect_payload/1 optional callback is solely for logging purpose. By providing a concrete callback implementation you can additionally include summary of each jobs's payload into logs. As an example, suppose your payload contains &quot;id&quot; field; then it's natural to define the following inspect_payload/1:def inspect_payload(%{&quot;id&quot; =&gt; id}) do id endYour gear can have multiple modules that use Antikythera.AsyncJob.Registering jobsWith the above module defined, you can call register/3 to invoke a new job:YourGear.SomeAsyncJob.register(%{&quot;arbitrary&quot; =&gt; &quot;map&quot;}, context, options)Here first argument is an arbitrary map that is passed to run/3 callback implementation (note that structs are maps and thus usable as payloads). context is a value of Antikythera.Context.t/0 and is used to obtain the executor pool which this job is registered to. When you need to register a job to an executor pool that is not the current one, you can pass a Antikythera.ExecutorPool.Id.t/0 instead of Antikythera.Context.t/0. options must be a Keyword.t/0 which can include the following values:id: An ID of the job. If given it must match the regex pattern ~r/\\A[0-9A-Za-z_-]{1,32}\\z/ and must be unique in the job queue specified by the second argument. If not given antikythera automatically generates one for you.schedule: When to run the job as a 2-tuple. If not given it defaults to {:once, Antikythera.Time.now()}, i.e., the job will be executed as soon as an available worker process is found in the specified executor pool. Allowed value format is:{:once, Antikythera.Time.t}The job is executed at the given time. After the job is either successfully completed or abandoned by failure(s), the job is removed from the job queue. The time must be a future time and within 50 days from now.{:cron, Antikythera.Cron.t}The job is repeatedly executed at the given cron schedule. After the job is either successfully completed or abandoned by failure(s), the job is requeued to the job queue. Note that next start time is computed from the time of requeuing. For example, if a job is scheduled on every 10 minutes (&quot;/10 *&quot;) and its execution takes 15 minutes to complete, then the job will in effect run on every 20 minutes. The schedule will repeat indefinitely; when you have done with the job you can remove it by cancel/3.max_duration: Maximum execution time (in milliseconds) of the job. A job which has been running for more than max_duration is brutally killed and if it has remaining attempts it will be retried. Defaults to 300000 (5 minutes). If explicitly given it cannot exceed 1800000 (30 minutes).attempts: A positive integer within 1..10), up to which antikythera tries to run the job. Defaults to 3.retry_interval: A 2-tuple of integer and float to calculate time interval between retries. Defaults to {5000, 2.0}. First element is a time interval (in milliseconds) between 1st and 2nd attempts and must be within 0..300000. Second element is a multiplying factor for exponential backoff and must be within 1.0..5.0. For example:When retry_interval: {10_000, 2.0} is given,2nd attempt (1st retry) after failure of 1st attempt is started in 10s,3rd attempt (2nd retry) after failure of 2nd attempt is started in 20s,4th attempt (3rd retry) after failure of 3rd attempt is started in 40s,and so on.If you want to set constant interval, specify 1.0 to second element.bypass_job_queue: Whether or not to run the job immediately, skipping addition to the job queue. Defaults to false.When this option is true, register/3 tries to pick a worker process in the executor pool in the same node and then immediately start the job using the worker process. If all processes in the local executor pool are busy, register/3 returns {:error, :no_available_workers}. In that case you have 2 options:give up running the job, orcall register/3 again without bypass_job_queue option so that the job will be executed afterward, possibly in another node.Execution with bypass_job_queue option takes advantage of being free from rate limiting (see below) and having no overhead with pushing to the distributed job queue. Please note that if you bypass the job queue you cannotspecify start time of the job (it's started immediately and only once), andthe job is not retried when its execution results in a failure.Therefore this option cannot be used with schedule, attempts or retry_interval. Note also that jobs running with bypass_job_queue: true cannot be inspected by Antikythera.AsyncJob.list/1 or Antikythera.AsyncJob.status/2.register/3 returns a tuple of {:ok, Antikythera.AsyncJob.Id.t} on success. You can register jobs up to 1000. When 1000 jobs remain unfinished in the job queue, trying to register a new job results in {:error, :full}.The example call to register/3 above will eventually invoke YourGear.SomeAsyncJob.run/3 with the given payload and options.Rate limiting of accesses to each job queueAntikythera's async job queues are distributed, fault tolerant, persistent data structures. These features come at an extra cost: interacting with a job queue is a relatively expensive operation. In order not to overwhelm a job queue, accesses to a job queue are rate-limited by the token bucket algorithm. Rate limiting is imposed on a per-node basis; in each node, there exists a bucket per job queue.Each bucket contains up to 30 tokens and one token is generated in every 500 milliseconds. The following operations take tokens from the corresponding bucket:3 tokens per register/33 tokens per cancel/31 token per status/21 token per list/1When there are not enough tokens in the bucket, register/3 and cancel/3 return {:error, {:rate_limit_reached, milliseconds_to_wait}}. On the other hand status/2 and list/1 automatically wait and retry several times when hitting the rate limit.During testing, the rate limiting feature may disrupt smooth test executions. To bypass rate limiting in your tests you can use Antikythera.Test.AsyncJobHelper.reset_rate_limit_status/1.PayloadPayloads are registered by calling register/3 and used in run/3, abandon/3 or inspect_payload/1. Payloads are compressed as binary when register/3 is called and kept in memory until job executions, so large payloads could degrade overall system performance. Please avoid including large data in payloads; instead put ID of the data in payload and fetch the whole data in run/3.","ref":"Antikythera.AsyncJob.html","title":"Antikythera.AsyncJob","type":"behaviour"},{"doc":"","ref":"Antikythera.AsyncJob.html#c:abandon/3","title":"Antikythera.AsyncJob.abandon/3","type":"callback"},{"doc":"Cancels an async job registered with the job queue specified by context_or_epool_id.Note that currently-running job executions cannot be cancelled. However, calling cancel/2 with currently running job's job_id prevents retries of the job when it fails.","ref":"Antikythera.AsyncJob.html#cancel/3","title":"Antikythera.AsyncJob.cancel/3","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.html#c:inspect_payload/1","title":"Antikythera.AsyncJob.inspect_payload/1","type":"callback"},{"doc":"Retrieves list of async jobs registered with the job queue specified by context_or_epool_id.Each element of returned list is a 3-tuple: scheduled execution time, job ID and current status. The returned list is already sorted.","ref":"Antikythera.AsyncJob.html#list/1","title":"Antikythera.AsyncJob.list/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.html#c:run/3","title":"Antikythera.AsyncJob.run/3","type":"callback"},{"doc":"Retrieves detailed information of an async job registered with the job queue specified by context_or_epool_id.","ref":"Antikythera.AsyncJob.html#status/2","title":"Antikythera.AsyncJob.status/2","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.html#t:option/0","title":"Antikythera.AsyncJob.option/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.Attempts.html","title":"Antikythera.AsyncJob.Attempts","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.Attempts.html#default/0","title":"Antikythera.AsyncJob.Attempts.default/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Attempts.html#max/0","title":"Antikythera.AsyncJob.Attempts.max/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Attempts.html#min/0","title":"Antikythera.AsyncJob.Attempts.min/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Attempts.html#valid?/1","title":"Antikythera.AsyncJob.Attempts.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Attempts.html#t:t/0","title":"Antikythera.AsyncJob.Attempts.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.Id.html","title":"Antikythera.AsyncJob.Id","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.Id.html#generate/0","title":"Antikythera.AsyncJob.Id.generate/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Id.html#pattern/0","title":"Antikythera.AsyncJob.Id.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Id.html#valid?/1","title":"Antikythera.AsyncJob.Id.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Id.html#t:t/0","title":"Antikythera.AsyncJob.Id.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.MaxDuration.html","title":"Antikythera.AsyncJob.MaxDuration","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.MaxDuration.html#default/0","title":"Antikythera.AsyncJob.MaxDuration.default/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.MaxDuration.html#max/0","title":"Antikythera.AsyncJob.MaxDuration.max/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.MaxDuration.html#min/0","title":"Antikythera.AsyncJob.MaxDuration.min/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.MaxDuration.html#valid?/1","title":"Antikythera.AsyncJob.MaxDuration.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.MaxDuration.html#t:t/0","title":"Antikythera.AsyncJob.MaxDuration.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.Metadata.html","title":"Antikythera.AsyncJob.Metadata","type":"module"},{"doc":"Type-aware getter for attempts.","ref":"Antikythera.AsyncJob.Metadata.html#attempts/1","title":"Antikythera.AsyncJob.Metadata.attempts/1","type":"function"},{"doc":"Type-aware setter for attempts.","ref":"Antikythera.AsyncJob.Metadata.html#attempts/2","title":"Antikythera.AsyncJob.Metadata.attempts/2","type":"function"},{"doc":"Type-aware getter for id.","ref":"Antikythera.AsyncJob.Metadata.html#id/1","title":"Antikythera.AsyncJob.Metadata.id/1","type":"function"},{"doc":"Type-aware setter for id.","ref":"Antikythera.AsyncJob.Metadata.html#id/2","title":"Antikythera.AsyncJob.Metadata.id/2","type":"function"},{"doc":"Type-aware getter for max_duration.","ref":"Antikythera.AsyncJob.Metadata.html#max_duration/1","title":"Antikythera.AsyncJob.Metadata.max_duration/1","type":"function"},{"doc":"Type-aware setter for max_duration.","ref":"Antikythera.AsyncJob.Metadata.html#max_duration/2","title":"Antikythera.AsyncJob.Metadata.max_duration/2","type":"function"},{"doc":"Creates a new instance of Antikythera.AsyncJob.Metadata by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.AsyncJob.Metadata.html#new/1","title":"Antikythera.AsyncJob.Metadata.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.AsyncJob.Metadata.html#new!/1","title":"Antikythera.AsyncJob.Metadata.new!/1","type":"function"},{"doc":"Type-aware getter for remaining_attempts.","ref":"Antikythera.AsyncJob.Metadata.html#remaining_attempts/1","title":"Antikythera.AsyncJob.Metadata.remaining_attempts/1","type":"function"},{"doc":"Type-aware setter for remaining_attempts.","ref":"Antikythera.AsyncJob.Metadata.html#remaining_attempts/2","title":"Antikythera.AsyncJob.Metadata.remaining_attempts/2","type":"function"},{"doc":"Type-aware getter for retry_interval.","ref":"Antikythera.AsyncJob.Metadata.html#retry_interval/1","title":"Antikythera.AsyncJob.Metadata.retry_interval/1","type":"function"},{"doc":"Type-aware setter for retry_interval.","ref":"Antikythera.AsyncJob.Metadata.html#retry_interval/2","title":"Antikythera.AsyncJob.Metadata.retry_interval/2","type":"function"},{"doc":"Type-aware getter for run_at.","ref":"Antikythera.AsyncJob.Metadata.html#run_at/1","title":"Antikythera.AsyncJob.Metadata.run_at/1","type":"function"},{"doc":"Type-aware setter for run_at.","ref":"Antikythera.AsyncJob.Metadata.html#run_at/2","title":"Antikythera.AsyncJob.Metadata.run_at/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.AsyncJob.Metadata with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.AsyncJob.Metadata.html#update/2","title":"Antikythera.AsyncJob.Metadata.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.AsyncJob.Metadata.html#update!/2","title":"Antikythera.AsyncJob.Metadata.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.AsyncJob.Metadata.html#valid?/1","title":"Antikythera.AsyncJob.Metadata.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Metadata.html#t:t/0","title":"Antikythera.AsyncJob.Metadata.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.html","title":"Antikythera.AsyncJob.RetryInterval","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.html#default/0","title":"Antikythera.AsyncJob.RetryInterval.default/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.html#interval/2","title":"Antikythera.AsyncJob.RetryInterval.interval/2","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.html#valid?/1","title":"Antikythera.AsyncJob.RetryInterval.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.html#t:t/0","title":"Antikythera.AsyncJob.RetryInterval.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Base.html","title":"Antikythera.AsyncJob.RetryInterval.Base","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Base.html#default/0","title":"Antikythera.AsyncJob.RetryInterval.Base.default/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Base.html#max/0","title":"Antikythera.AsyncJob.RetryInterval.Base.max/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Base.html#min/0","title":"Antikythera.AsyncJob.RetryInterval.Base.min/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Base.html#valid?/1","title":"Antikythera.AsyncJob.RetryInterval.Base.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Base.html#t:t/0","title":"Antikythera.AsyncJob.RetryInterval.Base.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Factor.html","title":"Antikythera.AsyncJob.RetryInterval.Factor","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Factor.html#default/0","title":"Antikythera.AsyncJob.RetryInterval.Factor.default/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Factor.html#max/0","title":"Antikythera.AsyncJob.RetryInterval.Factor.max/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Factor.html#min/0","title":"Antikythera.AsyncJob.RetryInterval.Factor.min/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Factor.html#valid?/1","title":"Antikythera.AsyncJob.RetryInterval.Factor.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.RetryInterval.Factor.html#t:t/0","title":"Antikythera.AsyncJob.RetryInterval.Factor.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.Schedule.html","title":"Antikythera.AsyncJob.Schedule","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.Schedule.html#valid?/1","title":"Antikythera.AsyncJob.Schedule.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Schedule.html#t:t/0","title":"Antikythera.AsyncJob.Schedule.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.StateLabel.html","title":"Antikythera.AsyncJob.StateLabel","type":"module"},{"doc":"","ref":"Antikythera.AsyncJob.StateLabel.html#new/1","title":"Antikythera.AsyncJob.StateLabel.new/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.StateLabel.html#new!/1","title":"Antikythera.AsyncJob.StateLabel.new!/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.StateLabel.html#valid?/1","title":"Antikythera.AsyncJob.StateLabel.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.StateLabel.html#values/0","title":"Antikythera.AsyncJob.StateLabel.values/0","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.StateLabel.html#t:t/0","title":"Antikythera.AsyncJob.StateLabel.t/0","type":"type"},{"doc":"","ref":"Antikythera.AsyncJob.Status.html","title":"Antikythera.AsyncJob.Status","type":"module"},{"doc":"Type-aware getter for attempts.","ref":"Antikythera.AsyncJob.Status.html#attempts/1","title":"Antikythera.AsyncJob.Status.attempts/1","type":"function"},{"doc":"Type-aware setter for attempts.","ref":"Antikythera.AsyncJob.Status.html#attempts/2","title":"Antikythera.AsyncJob.Status.attempts/2","type":"function"},{"doc":"Type-aware getter for gear_name.","ref":"Antikythera.AsyncJob.Status.html#gear_name/1","title":"Antikythera.AsyncJob.Status.gear_name/1","type":"function"},{"doc":"Type-aware setter for gear_name.","ref":"Antikythera.AsyncJob.Status.html#gear_name/2","title":"Antikythera.AsyncJob.Status.gear_name/2","type":"function"},{"doc":"Type-aware getter for id.","ref":"Antikythera.AsyncJob.Status.html#id/1","title":"Antikythera.AsyncJob.Status.id/1","type":"function"},{"doc":"Type-aware setter for id.","ref":"Antikythera.AsyncJob.Status.html#id/2","title":"Antikythera.AsyncJob.Status.id/2","type":"function"},{"doc":"Type-aware getter for max_duration.","ref":"Antikythera.AsyncJob.Status.html#max_duration/1","title":"Antikythera.AsyncJob.Status.max_duration/1","type":"function"},{"doc":"Type-aware setter for max_duration.","ref":"Antikythera.AsyncJob.Status.html#max_duration/2","title":"Antikythera.AsyncJob.Status.max_duration/2","type":"function"},{"doc":"Type-aware getter for module.","ref":"Antikythera.AsyncJob.Status.html#module/1","title":"Antikythera.AsyncJob.Status.module/1","type":"function"},{"doc":"Type-aware setter for module.","ref":"Antikythera.AsyncJob.Status.html#module/2","title":"Antikythera.AsyncJob.Status.module/2","type":"function"},{"doc":"Creates a new instance of Antikythera.AsyncJob.Status by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.AsyncJob.Status.html#new/1","title":"Antikythera.AsyncJob.Status.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.AsyncJob.Status.html#new!/1","title":"Antikythera.AsyncJob.Status.new!/1","type":"function"},{"doc":"Type-aware getter for payload.","ref":"Antikythera.AsyncJob.Status.html#payload/1","title":"Antikythera.AsyncJob.Status.payload/1","type":"function"},{"doc":"Type-aware setter for payload.","ref":"Antikythera.AsyncJob.Status.html#payload/2","title":"Antikythera.AsyncJob.Status.payload/2","type":"function"},{"doc":"Type-aware getter for remaining_attempts.","ref":"Antikythera.AsyncJob.Status.html#remaining_attempts/1","title":"Antikythera.AsyncJob.Status.remaining_attempts/1","type":"function"},{"doc":"Type-aware setter for remaining_attempts.","ref":"Antikythera.AsyncJob.Status.html#remaining_attempts/2","title":"Antikythera.AsyncJob.Status.remaining_attempts/2","type":"function"},{"doc":"Type-aware getter for retry_interval.","ref":"Antikythera.AsyncJob.Status.html#retry_interval/1","title":"Antikythera.AsyncJob.Status.retry_interval/1","type":"function"},{"doc":"Type-aware setter for retry_interval.","ref":"Antikythera.AsyncJob.Status.html#retry_interval/2","title":"Antikythera.AsyncJob.Status.retry_interval/2","type":"function"},{"doc":"Type-aware getter for schedule.","ref":"Antikythera.AsyncJob.Status.html#schedule/1","title":"Antikythera.AsyncJob.Status.schedule/1","type":"function"},{"doc":"Type-aware setter for schedule.","ref":"Antikythera.AsyncJob.Status.html#schedule/2","title":"Antikythera.AsyncJob.Status.schedule/2","type":"function"},{"doc":"Type-aware getter for start_time.","ref":"Antikythera.AsyncJob.Status.html#start_time/1","title":"Antikythera.AsyncJob.Status.start_time/1","type":"function"},{"doc":"Type-aware setter for start_time.","ref":"Antikythera.AsyncJob.Status.html#start_time/2","title":"Antikythera.AsyncJob.Status.start_time/2","type":"function"},{"doc":"Type-aware getter for state.","ref":"Antikythera.AsyncJob.Status.html#state/1","title":"Antikythera.AsyncJob.Status.state/1","type":"function"},{"doc":"Type-aware setter for state.","ref":"Antikythera.AsyncJob.Status.html#state/2","title":"Antikythera.AsyncJob.Status.state/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.AsyncJob.Status with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.AsyncJob.Status.html#update/2","title":"Antikythera.AsyncJob.Status.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.AsyncJob.Status.html#update!/2","title":"Antikythera.AsyncJob.Status.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.AsyncJob.Status.html#valid?/1","title":"Antikythera.AsyncJob.Status.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.AsyncJob.Status.html#t:t/0","title":"Antikythera.AsyncJob.Status.t/0","type":"type"},{"doc":"This module provides functions to generate a signed URL for CloudFront","ref":"Antikythera.Aws.CloudfrontSignedUrl.html","title":"Antikythera.Aws.CloudfrontSignedUrl","type":"module"},{"doc":"Generates a signed URL to access a file via CloudFront.Parametersresource_url (string): CloudFront URL used for accessing the file, including query string parameters, if any.lifetime_in_seconds (positive integer): Expiration time is determined as the sum of the current time (in seconds) and this value.key_pair_id (string): ID for an active CloudFront key pair used for generating the signature.private_key (string): RSA private key for the key pair specified by key_pair_id.url_encoded? (boolean): Whether resource_url is encoded or not (optional, default is false).Return valueA generated signed URL (string).","ref":"Antikythera.Aws.CloudfrontSignedUrl.html#generate_signed_url/5","title":"Antikythera.Aws.CloudfrontSignedUrl.generate_signed_url/5","type":"function"},{"doc":"Generates a signed URL to access a file via CloudFront using a custom policy.Parametersresource_url (string): CloudFront URL used for accessing the file, including query string parameters, if any.lifetime_in_seconds (positive integer): Expiration time is determined as the sum of the current time (in seconds) and this value.key_pair_id (string): ID for an active CloudFront key pair used for generating the signature.private_key (string): RSA private key for the key pair specified by key_pair_id.url_encoded? (boolean): Whether resource_url is encoded or not (optional, default is false).optional_policy (Keyword): Optional policy conditions to be added to a custom policy (default is []). Currently, supports only the following keywords::date_greater_than(integer &gt;= 0): Seconds in AWS:EpochTime. Specified to DateGreaterThan:ip_address (list of strings): Specified to IpAddress.Return valueA generated signed URL (string).","ref":"Antikythera.Aws.CloudfrontSignedUrl.html#generate_signed_url_using_custom_policy/6","title":"Antikythera.Aws.CloudfrontSignedUrl.generate_signed_url_using_custom_policy/6","type":"function"},{"doc":"Utilities involving Code module, used for metaprogramming.","ref":"Antikythera.CodeUtil.html","title":"Antikythera.CodeUtil","type":"module"},{"doc":"Fetches function document from already existing module.Used when annotating a function with the same doc attribute as that of another function.","ref":"Antikythera.CodeUtil.html#doc_by_mfa!/3","title":"Antikythera.CodeUtil.doc_by_mfa!/3","type":"function"},{"doc":"Definition of Antikythera.Conn struct, which represents a client-server connection.This module also defines many functions to work with Antikythera.Conn.","ref":"Antikythera.Conn.html","title":"Antikythera.Conn","type":"module"},{"doc":"","ref":"Antikythera.Conn.html#assign/3","title":"Antikythera.Conn.assign/3","type":"function"},{"doc":"Type-aware getter for assigns.","ref":"Antikythera.Conn.html#assigns/1","title":"Antikythera.Conn.assigns/1","type":"function"},{"doc":"Type-aware setter for assigns.","ref":"Antikythera.Conn.html#assigns/2","title":"Antikythera.Conn.assigns/2","type":"function"},{"doc":"Type-aware getter for before_send.","ref":"Antikythera.Conn.html#before_send/1","title":"Antikythera.Conn.before_send/1","type":"function"},{"doc":"Type-aware setter for before_send.","ref":"Antikythera.Conn.html#before_send/2","title":"Antikythera.Conn.before_send/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#clear_session/1","title":"Antikythera.Conn.clear_session/1","type":"function"},{"doc":"Type-aware getter for context.","ref":"Antikythera.Conn.html#context/1","title":"Antikythera.Conn.context/1","type":"function"},{"doc":"Type-aware setter for context.","ref":"Antikythera.Conn.html#context/2","title":"Antikythera.Conn.context/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#delete_session/2","title":"Antikythera.Conn.delete_session/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#destroy_session/1","title":"Antikythera.Conn.destroy_session/1","type":"function"},{"doc":"Gets a flash message stored in the given Antikythera.Conn.t/0.","ref":"Antikythera.Conn.html#get_flash/2","title":"Antikythera.Conn.get_flash/2","type":"function"},{"doc":"Returns a request cookie specified by name.","ref":"Antikythera.Conn.html#get_req_cookie/2","title":"Antikythera.Conn.get_req_cookie/2","type":"function"},{"doc":"Returns all request cookies.","ref":"Antikythera.Conn.html#get_req_cookies/1","title":"Antikythera.Conn.get_req_cookies/1","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#get_req_header/2","title":"Antikythera.Conn.get_req_header/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#get_req_query/2","title":"Antikythera.Conn.get_req_query/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#get_session/2","title":"Antikythera.Conn.get_session/2","type":"function"},{"doc":"Returns a JSON response.","ref":"Antikythera.Conn.html#json/3","title":"Antikythera.Conn.json/3","type":"function"},{"doc":"Creates a new instance of Antikythera.Conn by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Conn.html#new/1","title":"Antikythera.Conn.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Conn.html#new!/1","title":"Antikythera.Conn.new!/1","type":"function"},{"doc":"Put cache-control response header for responses that must not be cached.The actual header value to be set is: &quot;private, no-cache, no-store, max-age=0&quot;.","ref":"Antikythera.Conn.html#no_cache/1","title":"Antikythera.Conn.no_cache/1","type":"function"},{"doc":"Stores the flash message into the current Antikythera.Conn.t/0.","ref":"Antikythera.Conn.html#put_flash/3","title":"Antikythera.Conn.put_flash/3","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#put_resp_body/2","title":"Antikythera.Conn.put_resp_body/2","type":"function"},{"doc":"Adds a set-cookie response header to the given Antikythera.Conn.t.path directive of set-cookie header is automatically filled with &quot;/&quot; if not explicitly given. Also secure directive is filled by default in the cloud environments (assuming that it's serving with HTTPS).Note that response cookies are stored separately from the other response headers, as cookies require special treatment according to the HTTP specs.","ref":"Antikythera.Conn.html#put_resp_cookie/4","title":"Antikythera.Conn.put_resp_cookie/4","type":"function"},{"doc":"Tells the client to delete an existing cookie specified by name.This is a wrapper around put_resp_cookie/4 that sets an immediately expiring cookie (whose value is an empty string).","ref":"Antikythera.Conn.html#put_resp_cookie_to_revoke/2","title":"Antikythera.Conn.put_resp_cookie_to_revoke/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#put_resp_header/3","title":"Antikythera.Conn.put_resp_header/3","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#put_resp_headers/2","title":"Antikythera.Conn.put_resp_headers/2","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#put_session/3","title":"Antikythera.Conn.put_session/3","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#put_status/2","title":"Antikythera.Conn.put_status/2","type":"function"},{"doc":"Returns an HTTP response that make the client redirect to the specified url.","ref":"Antikythera.Conn.html#redirect/3","title":"Antikythera.Conn.redirect/3","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#register_before_send/2","title":"Antikythera.Conn.register_before_send/2","type":"function"},{"doc":"Renders a HAML template file and returns the dynamic content as an HTML response.","ref":"Antikythera.Conn.html#render/5","title":"Antikythera.Conn.render/5","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#renew_session/1","title":"Antikythera.Conn.renew_session/1","type":"function"},{"doc":"Type-aware getter for request.","ref":"Antikythera.Conn.html#request/1","title":"Antikythera.Conn.request/1","type":"function"},{"doc":"Type-aware setter for request.","ref":"Antikythera.Conn.html#request/2","title":"Antikythera.Conn.request/2","type":"function"},{"doc":"Type-aware getter for resp_body.","ref":"Antikythera.Conn.html#resp_body/1","title":"Antikythera.Conn.resp_body/1","type":"function"},{"doc":"Type-aware setter for resp_body.","ref":"Antikythera.Conn.html#resp_body/2","title":"Antikythera.Conn.resp_body/2","type":"function"},{"doc":"Type-aware getter for resp_cookies.","ref":"Antikythera.Conn.html#resp_cookies/1","title":"Antikythera.Conn.resp_cookies/1","type":"function"},{"doc":"Type-aware setter for resp_cookies.","ref":"Antikythera.Conn.html#resp_cookies/2","title":"Antikythera.Conn.resp_cookies/2","type":"function"},{"doc":"Type-aware getter for resp_headers.","ref":"Antikythera.Conn.html#resp_headers/1","title":"Antikythera.Conn.resp_headers/1","type":"function"},{"doc":"Type-aware setter for resp_headers.","ref":"Antikythera.Conn.html#resp_headers/2","title":"Antikythera.Conn.resp_headers/2","type":"function"},{"doc":"Sends a file which resides in priv/ directory as a response.path must be a file path relative to the priv/ directory. content-type header is inferred from the file's extension.Don't use this function for sending large files; you should use CDN for large files (see Antikythera.Asset). Also, if all you need to do is just to return a file (i.e. you don't need any authentication), you should not use this function; just placing the file under priv/static/ directory should suffice.","ref":"Antikythera.Conn.html#send_priv_file/3","title":"Antikythera.Conn.send_priv_file/3","type":"function"},{"doc":"Type-aware getter for status.","ref":"Antikythera.Conn.html#status/1","title":"Antikythera.Conn.status/1","type":"function"},{"doc":"Type-aware setter for status.","ref":"Antikythera.Conn.html#status/2","title":"Antikythera.Conn.status/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Conn with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Conn.html#update/2","title":"Antikythera.Conn.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Conn.html#update!/2","title":"Antikythera.Conn.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Conn.html#valid?/1","title":"Antikythera.Conn.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Conn.html#t:t/0","title":"Antikythera.Conn.t/0","type":"type"},{"doc":"","ref":"Antikythera.Conn.Assigns.html","title":"Antikythera.Conn.Assigns","type":"module"},{"doc":"","ref":"Antikythera.Conn.Assigns.html#default/0","title":"Antikythera.Conn.Assigns.default/0","type":"function"},{"doc":"","ref":"Antikythera.Conn.Assigns.html#valid?/1","title":"Antikythera.Conn.Assigns.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Conn.Assigns.html#t:t/0","title":"Antikythera.Conn.Assigns.t/0","type":"type"},{"doc":"","ref":"Antikythera.Conn.BeforeSend.html","title":"Antikythera.Conn.BeforeSend","type":"module"},{"doc":"","ref":"Antikythera.Conn.BeforeSend.html#default/0","title":"Antikythera.Conn.BeforeSend.default/0","type":"function"},{"doc":"","ref":"Antikythera.Conn.BeforeSend.html#valid?/1","title":"Antikythera.Conn.BeforeSend.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Conn.BeforeSend.html#t:t/0","title":"Antikythera.Conn.BeforeSend.t/0","type":"type"},{"doc":"Definition of Antikythera.Context struct which represents a context for an execution of gear code.Note that gear_entry_point is basically of type {module, atom}, it is nil during (1) executor_pool_web_request/1 and (2) no_route/1 error handler.","ref":"Antikythera.Context.html","title":"Antikythera.Context","type":"module"},{"doc":"Type-aware getter for context_id.","ref":"Antikythera.Context.html#context_id/1","title":"Antikythera.Context.context_id/1","type":"function"},{"doc":"Type-aware setter for context_id.","ref":"Antikythera.Context.html#context_id/2","title":"Antikythera.Context.context_id/2","type":"function"},{"doc":"Type-aware getter for executor_pool_id.","ref":"Antikythera.Context.html#executor_pool_id/1","title":"Antikythera.Context.executor_pool_id/1","type":"function"},{"doc":"Type-aware setter for executor_pool_id.","ref":"Antikythera.Context.html#executor_pool_id/2","title":"Antikythera.Context.executor_pool_id/2","type":"function"},{"doc":"Type-aware getter for gear_entry_point.","ref":"Antikythera.Context.html#gear_entry_point/1","title":"Antikythera.Context.gear_entry_point/1","type":"function"},{"doc":"Type-aware setter for gear_entry_point.","ref":"Antikythera.Context.html#gear_entry_point/2","title":"Antikythera.Context.gear_entry_point/2","type":"function"},{"doc":"Type-aware getter for gear_name.","ref":"Antikythera.Context.html#gear_name/1","title":"Antikythera.Context.gear_name/1","type":"function"},{"doc":"Type-aware setter for gear_name.","ref":"Antikythera.Context.html#gear_name/2","title":"Antikythera.Context.gear_name/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Context by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Context.html#new/1","title":"Antikythera.Context.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Context.html#new!/1","title":"Antikythera.Context.new!/1","type":"function"},{"doc":"Type-aware getter for start_time.","ref":"Antikythera.Context.html#start_time/1","title":"Antikythera.Context.start_time/1","type":"function"},{"doc":"Type-aware setter for start_time.","ref":"Antikythera.Context.html#start_time/2","title":"Antikythera.Context.start_time/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Context with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Context.html#update/2","title":"Antikythera.Context.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Context.html#update!/2","title":"Antikythera.Context.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Context.html#valid?/1","title":"Antikythera.Context.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Context.html#t:t/0","title":"Antikythera.Context.t/0","type":"type"},{"doc":"","ref":"Antikythera.Context.GearEntryPoint.html","title":"Antikythera.Context.GearEntryPoint","type":"module"},{"doc":"","ref":"Antikythera.Context.GearEntryPoint.html#valid?/1","title":"Antikythera.Context.GearEntryPoint.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Context.GearEntryPoint.html#t:t/0","title":"Antikythera.Context.GearEntryPoint.t/0","type":"type"},{"doc":"","ref":"Antikythera.ContextId.html","title":"Antikythera.ContextId","type":"module"},{"doc":"","ref":"Antikythera.ContextId.html#pattern/0","title":"Antikythera.ContextId.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.ContextId.html#system_context/0","title":"Antikythera.ContextId.system_context/0","type":"function"},{"doc":"","ref":"Antikythera.ContextId.html#valid?/1","title":"Antikythera.ContextId.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.ContextId.html#t:t/0","title":"Antikythera.ContextId.t/0","type":"type"},{"doc":"Helper module to bulk-import many controller-related modules.It's recommended to use Antikythera.Controller (either directly or indirectly) in your controller modules.","ref":"Antikythera.Controller.html","title":"Antikythera.Controller","type":"module"},{"doc":"Macro definition for plug DSL.&quot;Plug&quot; is a specification of composable modules for web apps. For example, you can define your authentication logic as a plug and apply it to all your controller actions.UsageTo use plug you must first add use Antikythera.Controller in your controller module. Then you can invoke plug/3 macro as follows.plug Antikythera.Plug.BasicAuthentication, :check_with_config, []The arguments aremodulefunction nameoptions to be passed to plug function(optional) options for enabling plugIn this case Antikythera.Plug.BasicAuthentication.check_with_config/2 is invoked just before execution of actions defined in this controller module. If you want to skip running plug for some actions in a controller module, you can use :except or :only option.plug YourGear.SomePlug1, :do_something, [], [except: [:action_x, :action_y]] plug YourGear.SomePlug2, :do_something, [], [only: [:action_x]]","ref":"Antikythera.Controller.Plug.html","title":"Antikythera.Controller.Plug","type":"module"},{"doc":"","ref":"Antikythera.Controller.Plug.html#plug/4","title":"Antikythera.Controller.Plug.plug/4","type":"macro"},{"doc":"Calculate time schedules based on cron format strings.parse/1 recognizes the POSIX specifications of crontab format with the extension of &quot;step values&quot; (explained below). The parsed object can be used to compute next matching time in next/2.Note that all times are in UTC, as is the case with Antikythera.Time.Schedule formatThe cron schedule is specified by 5 fields separated by whitespaces.Allowed values for each field are:minutes : 0-59hours : 0-23day of month : 1-31month : 1-12day of week : 0-6 (0=Sunday)Multiple elements can be used within a field by separating each by ,.An element shall be either a number or two numbers separated by a - (meaning an inclusive range).A field may contain * which stands for &quot;first-last&quot;.Step values as in &quot;/&lt;skip&gt;&quot; can be used in conjunction with ranges. For example,&quot;0-18/4&quot; is identical to &quot;0,4,8,12,16&quot;, and&quot;*/10&quot; in minutes field is identical to &quot;0,10,20,30,40,50&quot;.If both 'day of month' and 'day of week' are not &quot;&quot;, then the dates are the ones matching either of the fields. For example, &quot;30 4 1,15 5&quot; indicates both of the followings:4:30 on the 1st and 15th of each month4:30 on every FridaySchedules that actually don't represent valid date are not allowed. For example, &quot;0 0 31 4 *&quot; is rejected as 31st of April does not exist.","ref":"Antikythera.Cron.html","title":"Antikythera.Cron","type":"module"},{"doc":"Type-aware getter for day_of_month.","ref":"Antikythera.Cron.html#day_of_month/1","title":"Antikythera.Cron.day_of_month/1","type":"function"},{"doc":"Type-aware setter for day_of_month.","ref":"Antikythera.Cron.html#day_of_month/2","title":"Antikythera.Cron.day_of_month/2","type":"function"},{"doc":"Type-aware getter for day_of_week.","ref":"Antikythera.Cron.html#day_of_week/1","title":"Antikythera.Cron.day_of_week/1","type":"function"},{"doc":"Type-aware setter for day_of_week.","ref":"Antikythera.Cron.html#day_of_week/2","title":"Antikythera.Cron.day_of_week/2","type":"function"},{"doc":"Type-aware getter for hour.","ref":"Antikythera.Cron.html#hour/1","title":"Antikythera.Cron.hour/1","type":"function"},{"doc":"Type-aware setter for hour.","ref":"Antikythera.Cron.html#hour/2","title":"Antikythera.Cron.hour/2","type":"function"},{"doc":"Type-aware getter for minute.","ref":"Antikythera.Cron.html#minute/1","title":"Antikythera.Cron.minute/1","type":"function"},{"doc":"Type-aware setter for minute.","ref":"Antikythera.Cron.html#minute/2","title":"Antikythera.Cron.minute/2","type":"function"},{"doc":"Type-aware getter for month.","ref":"Antikythera.Cron.html#month/1","title":"Antikythera.Cron.month/1","type":"function"},{"doc":"Type-aware setter for month.","ref":"Antikythera.Cron.html#month/2","title":"Antikythera.Cron.month/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Cron by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Cron.html#new/1","title":"Antikythera.Cron.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Cron.html#new!/1","title":"Antikythera.Cron.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.html#next/2","title":"Antikythera.Cron.next/2","type":"function"},{"doc":"","ref":"Antikythera.Cron.html#next_in_epoch_milliseconds/2","title":"Antikythera.Cron.next_in_epoch_milliseconds/2","type":"function"},{"doc":"","ref":"Antikythera.Cron.html#parse/1","title":"Antikythera.Cron.parse/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.html#parse!/1","title":"Antikythera.Cron.parse!/1","type":"function"},{"doc":"Type-aware getter for source.","ref":"Antikythera.Cron.html#source/1","title":"Antikythera.Cron.source/1","type":"function"},{"doc":"Type-aware setter for source.","ref":"Antikythera.Cron.html#source/2","title":"Antikythera.Cron.source/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Cron with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Cron.html#update/2","title":"Antikythera.Cron.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Cron.html#update!/2","title":"Antikythera.Cron.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Cron.html#valid?/1","title":"Antikythera.Cron.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.html#t:t/0","title":"Antikythera.Cron.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.html","title":"Antikythera.Cron.DayOfMonth","type":"module"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.html#max/0","title":"Antikythera.Cron.DayOfMonth.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.html#min/0","title":"Antikythera.Cron.DayOfMonth.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.html#valid?/1","title":"Antikythera.Cron.DayOfMonth.valid?/1","type":"function"},{"doc":"Wildcard :* or sorted list of values.","ref":"Antikythera.Cron.DayOfMonth.html#t:t/0","title":"Antikythera.Cron.DayOfMonth.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.Int.html","title":"Antikythera.Cron.DayOfMonth.Int","type":"module"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.Int.html#max/0","title":"Antikythera.Cron.DayOfMonth.Int.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.Int.html#min/0","title":"Antikythera.Cron.DayOfMonth.Int.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.Int.html#valid?/1","title":"Antikythera.Cron.DayOfMonth.Int.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfMonth.Int.html#t:t/0","title":"Antikythera.Cron.DayOfMonth.Int.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.html","title":"Antikythera.Cron.DayOfWeek","type":"module"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.html#max/0","title":"Antikythera.Cron.DayOfWeek.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.html#min/0","title":"Antikythera.Cron.DayOfWeek.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.html#valid?/1","title":"Antikythera.Cron.DayOfWeek.valid?/1","type":"function"},{"doc":"Wildcard :* or sorted list of values.","ref":"Antikythera.Cron.DayOfWeek.html#t:t/0","title":"Antikythera.Cron.DayOfWeek.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.Int.html","title":"Antikythera.Cron.DayOfWeek.Int","type":"module"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.Int.html#max/0","title":"Antikythera.Cron.DayOfWeek.Int.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.Int.html#min/0","title":"Antikythera.Cron.DayOfWeek.Int.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.Int.html#valid?/1","title":"Antikythera.Cron.DayOfWeek.Int.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.DayOfWeek.Int.html#t:t/0","title":"Antikythera.Cron.DayOfWeek.Int.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.Hour.html","title":"Antikythera.Cron.Hour","type":"module"},{"doc":"","ref":"Antikythera.Cron.Hour.html#max/0","title":"Antikythera.Cron.Hour.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Hour.html#min/0","title":"Antikythera.Cron.Hour.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Hour.html#valid?/1","title":"Antikythera.Cron.Hour.valid?/1","type":"function"},{"doc":"Wildcard :* or sorted list of values.","ref":"Antikythera.Cron.Hour.html#t:t/0","title":"Antikythera.Cron.Hour.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.Hour.Int.html","title":"Antikythera.Cron.Hour.Int","type":"module"},{"doc":"","ref":"Antikythera.Cron.Hour.Int.html#max/0","title":"Antikythera.Cron.Hour.Int.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Hour.Int.html#min/0","title":"Antikythera.Cron.Hour.Int.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Hour.Int.html#valid?/1","title":"Antikythera.Cron.Hour.Int.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.Hour.Int.html#t:t/0","title":"Antikythera.Cron.Hour.Int.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.Minute.html","title":"Antikythera.Cron.Minute","type":"module"},{"doc":"","ref":"Antikythera.Cron.Minute.html#max/0","title":"Antikythera.Cron.Minute.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Minute.html#min/0","title":"Antikythera.Cron.Minute.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Minute.html#valid?/1","title":"Antikythera.Cron.Minute.valid?/1","type":"function"},{"doc":"Wildcard :* or sorted list of values.","ref":"Antikythera.Cron.Minute.html#t:t/0","title":"Antikythera.Cron.Minute.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.Minute.Int.html","title":"Antikythera.Cron.Minute.Int","type":"module"},{"doc":"","ref":"Antikythera.Cron.Minute.Int.html#max/0","title":"Antikythera.Cron.Minute.Int.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Minute.Int.html#min/0","title":"Antikythera.Cron.Minute.Int.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Minute.Int.html#valid?/1","title":"Antikythera.Cron.Minute.Int.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.Minute.Int.html#t:t/0","title":"Antikythera.Cron.Minute.Int.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.Month.html","title":"Antikythera.Cron.Month","type":"module"},{"doc":"","ref":"Antikythera.Cron.Month.html#max/0","title":"Antikythera.Cron.Month.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Month.html#min/0","title":"Antikythera.Cron.Month.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Month.html#valid?/1","title":"Antikythera.Cron.Month.valid?/1","type":"function"},{"doc":"Wildcard :* or sorted list of values.","ref":"Antikythera.Cron.Month.html#t:t/0","title":"Antikythera.Cron.Month.t/0","type":"type"},{"doc":"","ref":"Antikythera.Cron.Month.Int.html","title":"Antikythera.Cron.Month.Int","type":"module"},{"doc":"","ref":"Antikythera.Cron.Month.Int.html#max/0","title":"Antikythera.Cron.Month.Int.max/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Month.Int.html#min/0","title":"Antikythera.Cron.Month.Int.min/0","type":"function"},{"doc":"","ref":"Antikythera.Cron.Month.Int.html#valid?/1","title":"Antikythera.Cron.Month.Int.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Cron.Month.Int.html#t:t/0","title":"Antikythera.Cron.Month.Int.t/0","type":"type"},{"doc":"","ref":"Antikythera.Crypto.html","title":"Antikythera.Crypto","type":"module"},{"doc":"Checks equality of the given two binaries in constant-time to avoid timing attacks.","ref":"Antikythera.Crypto.html#secure_compare/2","title":"Antikythera.Crypto.secure_compare/2","type":"function"},{"doc":"Easy to use data encryption/decryption utilities.Both Counter (CTR) mode and Galois/Counter mode (GCM) are supported. When only secrecy of data is required, use CTR mode. If you need not only secrecy but also data integrity, use GCM.Deriving an AES key from given passwordThe functions defined in this module accept arbitrary binary as password. To make an AES key (which is 128bit length) from a given password, the functions by default use MD5 hash algorithm. If you need to increase computational cost of key derivation and make attacks such as dictionary attacks more difficult, you may pass your own key derivation function. To implement your key derivation function you can use :pbkdf2 library.Transparent handling of initialization vectorWhen encrypting given data, the encrypt function generates a random initialization vector and prepends it to the encrypted data. The decrypt function extracts the initialization vector and use it to decrypt the rest.Associated Authenticated Data (AAD) for GCMFor GCM you may pass AAD (arbitrary binary) as an additional argument. AAD is used only for generating/validating authentication tag; it doesn't affect resulting cipher text.AAD can be used to provide contextual information for the authentication of cipher text. For example, you could pass &quot;login user ID&quot; as AAD when encrypting/decrypting each user's data, This way, even when a malicious user who somehow copied another user's encrypted data and secret key into his own account, you could prevent him from decrypting the data because of the difference in AAD.If you don't have any suitable data for AAD you can pass an empty string (which is the default value).","ref":"Antikythera.Crypto.Aes.html","title":"Antikythera.Crypto.Aes","type":"module"},{"doc":"","ref":"Antikythera.Crypto.Aes.html#ctr128_decrypt/3","title":"Antikythera.Crypto.Aes.ctr128_decrypt/3","type":"function"},{"doc":"","ref":"Antikythera.Crypto.Aes.html#ctr128_encrypt/3","title":"Antikythera.Crypto.Aes.ctr128_encrypt/3","type":"function"},{"doc":"","ref":"Antikythera.Crypto.Aes.html#gcm128_decrypt/4","title":"Antikythera.Crypto.Aes.gcm128_decrypt/4","type":"function"},{"doc":"","ref":"Antikythera.Crypto.Aes.html#gcm128_encrypt/4","title":"Antikythera.Crypto.Aes.gcm128_encrypt/4","type":"function"},{"doc":"","ref":"Antikythera.Crypto.Aes.html#t:key128/0","title":"Antikythera.Crypto.Aes.key128/0","type":"type"},{"doc":"Domain name format, originally defined in RFC1034.It accepts 1 to 63 letters label in top-level domains as per original syntax definition.It accepts all-numeric top-level domains as opposed to the restriction in RFC3696.If it is the sole part of domain name, (e.g. http://2130706433) client applications will most likely parse them as 32-bit integer representation of IPv4 address.","ref":"Antikythera.Domain.html","title":"Antikythera.Domain","type":"module"},{"doc":"","ref":"Antikythera.Domain.html#pattern/0","title":"Antikythera.Domain.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.Domain.html#pattern_body/0","title":"Antikythera.Domain.pattern_body/0","type":"function"},{"doc":"","ref":"Antikythera.Domain.html#valid?/1","title":"Antikythera.Domain.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Domain.html#t:t/0","title":"Antikythera.Domain.t/0","type":"type"},{"doc":"","ref":"Antikythera.DomainList.html","title":"Antikythera.DomainList","type":"module"},{"doc":"","ref":"Antikythera.DomainList.html#max_length/0","title":"Antikythera.DomainList.max_length/0","type":"function"},{"doc":"","ref":"Antikythera.DomainList.html#valid?/1","title":"Antikythera.DomainList.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.DomainList.html#t:t/0","title":"Antikythera.DomainList.t/0","type":"type"},{"doc":"Email address format, defined in RFC5321, and RFC5322. There are some differences from original RFCs for simplicity:Leading, trailing and/or consecutive '.'s in local parts are allowed.Double-quoted local parts are not allowed.'[]'-enclosed IP address literals in domain parts are not allowed.Total length of domain parts are not limited to 255.","ref":"Antikythera.Email.html","title":"Antikythera.Email","type":"module"},{"doc":"","ref":"Antikythera.Email.html#pattern/0","title":"Antikythera.Email.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.Email.html#valid?/1","title":"Antikythera.Email.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Email.html#t:t/0","title":"Antikythera.Email.t/0","type":"type"},{"doc":"","ref":"Antikythera.EncodedPath.html","title":"Antikythera.EncodedPath","type":"module"},{"doc":"","ref":"Antikythera.EncodedPath.html#pattern/0","title":"Antikythera.EncodedPath.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.EncodedPath.html#valid?/1","title":"Antikythera.EncodedPath.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.EncodedPath.html#t:t/0","title":"Antikythera.EncodedPath.t/0","type":"type"},{"doc":"Utility functions to work with enumerables.","ref":"Antikythera.EnumUtil.html","title":"Antikythera.EnumUtil","type":"module"},{"doc":"A variant of Enum.find/2 that raises an exception when no matching element is found.","ref":"Antikythera.EnumUtil.html#find!/2","title":"Antikythera.EnumUtil.find!/2","type":"function"},{"doc":"A variant of Enum.find_value/2 that raises an exception when no matching element is found.","ref":"Antikythera.EnumUtil.html#find_value!/2","title":"Antikythera.EnumUtil.find_value!/2","type":"function"},{"doc":"Updates items of an enumerable with the given function, depending on context. Context can be any.The function fun takes item and context as arguments, and must achieve 2 purposes:Update an item according to current contextProduces new context for next itemthen, return both as tuple {new_item, new_context}.","ref":"Antikythera.EnumUtil.html#map_with_context/3","title":"Antikythera.EnumUtil.map_with_context/3","type":"function"},{"doc":"","ref":"Antikythera.EnumUtil.html#t:context/0","title":"Antikythera.EnumUtil.context/0","type":"type"},{"doc":"","ref":"Antikythera.EnumUtil.html#t:element/0","title":"Antikythera.EnumUtil.element/0","type":"type"},{"doc":"Module to provide helpers to access environment variables defined by antikythera.Environments and deploymentsAntikythera instances and gears may run in the following two modes:As a mix project, when invoked by running iex or mix command-line tool.As an OTP release, which is generated by e.g. antikythera_core.generate_release task.In general there are multiple deployments per antikythera instance. To distingish the target deployment from code, antikythera defines the following environment variables:At compile time (for metaprogramming): ANTIKYTHERA_COMPILE_ENV must be appropriately set; the value can be retrieved by compile_env/0.At runtime: ANTIKYTHERA_RUNTIME_ENV must be appropriately set; the value can be retrieved by runtime_env/0.It is the responsibility of antikythera instance administrators to correctly set these environment variables when compiling/running antikythera and gears. Possible values returned by compile_env/0 and runtime_env/0 are:names of deployments given by :deployments application config:local (running an OTP release at local machine for testing purpose):undefinedAs an example, if you set :dev and :prod in :deployments, then you get:| | Mix.env() at compile-time | Mix.env() at runtime | compile_env(), runtime_env() | |---------------------------+----------------------------------------+-------------------------+------------------------------| | $ iex -S mix | :dev (toplevel), :prod (dependencies) | :dev | :undefined | | $ mix test | :test (toplevel), :prod (dependencies) | :test | :undefined | | $ mix antikythera_local.* | :prod | (:mix is not available) | :local | | :dev deployment | :prod | (:mix is not available) | :dev | | :prod deployment | :prod | (:mix is not available) | :prod |You can use these values to distinguish the current context from your code.","ref":"Antikythera.Env.html","title":"Antikythera.Env","type":"module"},{"doc":"","ref":"Antikythera.Env.html#antikythera_instance_name/0","title":"Antikythera.Env.antikythera_instance_name/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#asset_base_url/1","title":"Antikythera.Env.asset_base_url/1","type":"function"},{"doc":"","ref":"Antikythera.Env.html#compile_env/0","title":"Antikythera.Env.compile_env/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#compiling_for_cloud?/0","title":"Antikythera.Env.compiling_for_cloud?/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#compiling_for_mix_task?/0","title":"Antikythera.Env.compiling_for_mix_task?/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#compiling_for_release?/0","title":"Antikythera.Env.compiling_for_release?/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#default_base_url/2","title":"Antikythera.Env.default_base_url/2","type":"function"},{"doc":"Timeout (in milli-seconds) for gear actions.This can be configurable by specifying &quot;GEAR_ACTION_TIMEOUT&quot; environment variable when compiling antikythera. Defaults to 10000.","ref":"Antikythera.Env.html#gear_action_timeout/0","title":"Antikythera.Env.gear_action_timeout/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#new/1","title":"Antikythera.Env.new/1","type":"function"},{"doc":"","ref":"Antikythera.Env.html#new!/1","title":"Antikythera.Env.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Env.html#no_listen?/0","title":"Antikythera.Env.no_listen?/0","type":"function"},{"doc":"TCP port to listen to for incoming web requests.The port can be specified by &quot;PORT&quot; runtime environment variable. Defaults to 8081 during mix test, and 8080 otherwise (thus one can run both iex -S mix and mix test at the same time).","ref":"Antikythera.Env.html#port_to_listen/0","title":"Antikythera.Env.port_to_listen/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#running_in_cloud?/0","title":"Antikythera.Env.running_in_cloud?/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#running_on_mix_task?/0","title":"Antikythera.Env.running_on_mix_task?/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#running_with_release?/0","title":"Antikythera.Env.running_with_release?/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#runtime_env/0","title":"Antikythera.Env.runtime_env/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#valid?/1","title":"Antikythera.Env.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Env.html#values/0","title":"Antikythera.Env.values/0","type":"function"},{"doc":"","ref":"Antikythera.Env.html#t:t/0","title":"Antikythera.Env.t/0","type":"type"},{"doc":"","ref":"Antikythera.Env.Mapping.html","title":"Antikythera.Env.Mapping","type":"module"},{"doc":"","ref":"Antikythera.Env.Mapping.html#cloud?/1","title":"Antikythera.Env.Mapping.cloud?/1","type":"function"},{"doc":"","ref":"Antikythera.Env.Mapping.html#env_var_to_atom/1","title":"Antikythera.Env.Mapping.env_var_to_atom/1","type":"function"},{"doc":"Type module for error that describes what went wrong during a process execution.Possible values for t/0 are:{:error, Exception.t} : An exception was thrown and was not handled.:timeout : Execution timed out.:killed : Process was brutally killed, typically due to heap limit violation.{:throw, any} : A value was thrown but not caught.{:exit, any} : Process exited before completing the execution.","ref":"Antikythera.ErrorReason.html","title":"Antikythera.ErrorReason","type":"module"},{"doc":"","ref":"Antikythera.ErrorReason.html#format/2","title":"Antikythera.ErrorReason.format/2","type":"function"},{"doc":"","ref":"Antikythera.ErrorReason.html#valid?/1","title":"Antikythera.ErrorReason.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.ErrorReason.html#t:gear_action_error_reason/0","title":"Antikythera.ErrorReason.gear_action_error_reason/0","type":"type"},{"doc":"","ref":"Antikythera.ErrorReason.html#t:stack_item/0","title":"Antikythera.ErrorReason.stack_item/0","type":"type"},{"doc":"","ref":"Antikythera.ErrorReason.html#t:stacktrace/0","title":"Antikythera.ErrorReason.stacktrace/0","type":"type"},{"doc":"","ref":"Antikythera.ErrorReason.html#t:t/0","title":"Antikythera.ErrorReason.t/0","type":"type"},{"doc":"","ref":"Antikythera.ExecutorPool.BadIdReason.html","title":"Antikythera.ExecutorPool.BadIdReason","type":"module"},{"doc":"","ref":"Antikythera.ExecutorPool.BadIdReason.html#valid?/1","title":"Antikythera.ExecutorPool.BadIdReason.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.ExecutorPool.BadIdReason.html#t:t/0","title":"Antikythera.ExecutorPool.BadIdReason.t/0","type":"type"},{"doc":"","ref":"Antikythera.ExecutorPool.Id.html","title":"Antikythera.ExecutorPool.Id","type":"module"},{"doc":"","ref":"Antikythera.ExecutorPool.Id.html#nopool/0","title":"Antikythera.ExecutorPool.Id.nopool/0","type":"function"},{"doc":"","ref":"Antikythera.ExecutorPool.Id.html#to_string/1","title":"Antikythera.ExecutorPool.Id.to_string/1","type":"function"},{"doc":"","ref":"Antikythera.ExecutorPool.Id.html#valid?/1","title":"Antikythera.ExecutorPool.Id.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.ExecutorPool.Id.html#t:nopool_t/0","title":"Antikythera.ExecutorPool.Id.nopool_t/0","type":"type"},{"doc":"","ref":"Antikythera.ExecutorPool.Id.html#t:t/0","title":"Antikythera.ExecutorPool.Id.t/0","type":"type"},{"doc":"This module converts structures to JSON at low load by avoiding protocol calls. Internally Jason is used.","ref":"Antikythera.FastJasonEncoder.html","title":"Antikythera.FastJasonEncoder","type":"module"},{"doc":"","ref":"Antikythera.FastJasonEncoder.html#encode/1","title":"Antikythera.FastJasonEncoder.encode/1","type":"function"},{"doc":"","ref":"Antikythera.FastJasonEncoder.html#encode/2","title":"Antikythera.FastJasonEncoder.encode/2","type":"function"},{"doc":"","ref":"Antikythera.FastJasonEncoder.html#encode!/1","title":"Antikythera.FastJasonEncoder.encode!/1","type":"function"},{"doc":"","ref":"Antikythera.FastJasonEncoder.Wrapper.html","title":"Antikythera.FastJasonEncoder.Wrapper","type":"module"},{"doc":"","ref":"Antikythera.G2gRequest.html","title":"Antikythera.G2gRequest","type":"module"},{"doc":"Type-aware getter for body.","ref":"Antikythera.G2gRequest.html#body/1","title":"Antikythera.G2gRequest.body/1","type":"function"},{"doc":"Type-aware setter for body.","ref":"Antikythera.G2gRequest.html#body/2","title":"Antikythera.G2gRequest.body/2","type":"function"},{"doc":"Type-aware getter for cookies.","ref":"Antikythera.G2gRequest.html#cookies/1","title":"Antikythera.G2gRequest.cookies/1","type":"function"},{"doc":"Type-aware setter for cookies.","ref":"Antikythera.G2gRequest.html#cookies/2","title":"Antikythera.G2gRequest.cookies/2","type":"function"},{"doc":"","ref":"Antikythera.G2gRequest.html#from_web_request/1","title":"Antikythera.G2gRequest.from_web_request/1","type":"function"},{"doc":"Type-aware getter for headers.","ref":"Antikythera.G2gRequest.html#headers/1","title":"Antikythera.G2gRequest.headers/1","type":"function"},{"doc":"Type-aware setter for headers.","ref":"Antikythera.G2gRequest.html#headers/2","title":"Antikythera.G2gRequest.headers/2","type":"function"},{"doc":"Type-aware getter for method.","ref":"Antikythera.G2gRequest.html#method/1","title":"Antikythera.G2gRequest.method/1","type":"function"},{"doc":"Type-aware setter for method.","ref":"Antikythera.G2gRequest.html#method/2","title":"Antikythera.G2gRequest.method/2","type":"function"},{"doc":"Creates a new instance of Antikythera.G2gRequest by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.G2gRequest.html#new/1","title":"Antikythera.G2gRequest.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.G2gRequest.html#new!/1","title":"Antikythera.G2gRequest.new!/1","type":"function"},{"doc":"Type-aware getter for path.","ref":"Antikythera.G2gRequest.html#path/1","title":"Antikythera.G2gRequest.path/1","type":"function"},{"doc":"Type-aware setter for path.","ref":"Antikythera.G2gRequest.html#path/2","title":"Antikythera.G2gRequest.path/2","type":"function"},{"doc":"Type-aware getter for query_params.","ref":"Antikythera.G2gRequest.html#query_params/1","title":"Antikythera.G2gRequest.query_params/1","type":"function"},{"doc":"Type-aware setter for query_params.","ref":"Antikythera.G2gRequest.html#query_params/2","title":"Antikythera.G2gRequest.query_params/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.G2gRequest with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.G2gRequest.html#update/2","title":"Antikythera.G2gRequest.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.G2gRequest.html#update!/2","title":"Antikythera.G2gRequest.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.G2gRequest.html#valid?/1","title":"Antikythera.G2gRequest.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.G2gRequest.html#t:t/0","title":"Antikythera.G2gRequest.t/0","type":"type"},{"doc":"","ref":"Antikythera.G2gResponse.html","title":"Antikythera.G2gResponse","type":"module"},{"doc":"Type-aware getter for body.","ref":"Antikythera.G2gResponse.html#body/1","title":"Antikythera.G2gResponse.body/1","type":"function"},{"doc":"Type-aware setter for body.","ref":"Antikythera.G2gResponse.html#body/2","title":"Antikythera.G2gResponse.body/2","type":"function"},{"doc":"Type-aware getter for cookies.","ref":"Antikythera.G2gResponse.html#cookies/1","title":"Antikythera.G2gResponse.cookies/1","type":"function"},{"doc":"Type-aware setter for cookies.","ref":"Antikythera.G2gResponse.html#cookies/2","title":"Antikythera.G2gResponse.cookies/2","type":"function"},{"doc":"Creates a new version of Antikythera.G2gResponse struct by body decompression and decoding.This function decompresses body of g2g response according to content-encoding and then decodes the uncompressed body according to content-type. If decompressed, content-encoding header is removed from the returned Antikythera.G2gResponse.This function is used internally in G2g.send/{1,2} (i.e. body decoding is done automatically). Basically gear implementations do not need this function. The typical use case of this function (in conjunction with G2g.send_without_decoding/{1,2}) is to avoid unnecessary encoding/decoding when a gear actionreturns the g2g response as it is, andreads body of the g2g response.","ref":"Antikythera.G2gResponse.html#decode_body/1","title":"Antikythera.G2gResponse.decode_body/1","type":"function"},{"doc":"Type-aware getter for headers.","ref":"Antikythera.G2gResponse.html#headers/1","title":"Antikythera.G2gResponse.headers/1","type":"function"},{"doc":"Type-aware setter for headers.","ref":"Antikythera.G2gResponse.html#headers/2","title":"Antikythera.G2gResponse.headers/2","type":"function"},{"doc":"Creates a new instance of Antikythera.G2gResponse by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.G2gResponse.html#new/1","title":"Antikythera.G2gResponse.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.G2gResponse.html#new!/1","title":"Antikythera.G2gResponse.new!/1","type":"function"},{"doc":"Type-aware getter for status.","ref":"Antikythera.G2gResponse.html#status/1","title":"Antikythera.G2gResponse.status/1","type":"function"},{"doc":"Type-aware setter for status.","ref":"Antikythera.G2gResponse.html#status/2","title":"Antikythera.G2gResponse.status/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.G2gResponse with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.G2gResponse.html#update/2","title":"Antikythera.G2gResponse.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.G2gResponse.html#update!/2","title":"Antikythera.G2gResponse.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.G2gResponse.html#valid?/1","title":"Antikythera.G2gResponse.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.G2gResponse.html#t:t/0","title":"Antikythera.G2gResponse.t/0","type":"type"},{"doc":"Template for gear application module.Invoking use Antikythera.GearApplication generates bunch of code, including (but not limited to)Application callbacksLogger module for the gearaccessors to gear configAll gear implementations must have exactly one module that uses this module.For antikythera maintainers: Note that, when modifying the macros defined in GearApplication and GearApplication.*, we need to re-compile all gears in order to deploy the changes.","ref":"Antikythera.GearApplication.html","title":"Antikythera.GearApplication","type":"behaviour"},{"doc":"","ref":"Antikythera.GearApplication.html#c:children/0","title":"Antikythera.GearApplication.children/0","type":"callback"},{"doc":"","ref":"Antikythera.GearApplication.html#c:executor_pool_for_web_request/1","title":"Antikythera.GearApplication.executor_pool_for_web_request/1","type":"callback"},{"doc":"","ref":"Antikythera.GearApplication.html#t:child_spec/0","title":"Antikythera.GearApplication.child_spec/0","type":"type"},{"doc":"Helper module to define interface module for alerting.","ref":"Antikythera.GearApplication.AlertManager.html","title":"Antikythera.GearApplication.AlertManager","type":"module"},{"doc":"Helper module to define getter functions of gear configs.","ref":"Antikythera.GearApplication.ConfigGetter.html","title":"Antikythera.GearApplication.ConfigGetter","type":"module"},{"doc":"","ref":"Antikythera.GearApplication.ConfigGetter.html#cleanup_configs_in_process_dictionary/0","title":"Antikythera.GearApplication.ConfigGetter.cleanup_configs_in_process_dictionary/0","type":"function"},{"doc":"Helper module for gear's custom error handler.To customize HTTP responses returned on errors, gear must implement an error handler module whichis named YourGear.Controller.Error, anddefines the following functions:Mandatory error handlerserror(Antikythera.Conn.t, Antikythera.ErrorReason.gear_action_error_reason) :: Antikythera.Conn.tno_route(Antikythera.Conn.t) :: Antikythera.Conn.tbad_request(Antikythera.Conn.t) :: Antikythera.Conn.tOptional error handlersbad_executor_pool_id(Antikythera.Conn.t, Antikythera.ExecutorPool.BadIdReason.t) :: Antikythera.Conn.tws_too_many_connections(Antikythera.Conn.t) :: Antikythera.Conn.t (when your gear uses websocket)This module generates YourGear.error_handler_module/0 function, which is called by antikythera when handling errors.","ref":"Antikythera.GearApplication.ErrorHandler.html","title":"Antikythera.GearApplication.ErrorHandler","type":"module"},{"doc":"Helper module to define each gear's G2g module that contains interface for gear-to-gear communication.","ref":"Antikythera.GearApplication.G2g.html","title":"Antikythera.GearApplication.G2g","type":"module"},{"doc":"Helper module to define each gear's Logger module.","ref":"Antikythera.GearApplication.Logger.html","title":"Antikythera.GearApplication.Logger","type":"module"},{"doc":"Helper module to define interface module to submit custom metrics data.","ref":"Antikythera.GearApplication.MetricsUploader.html","title":"Antikythera.GearApplication.MetricsUploader","type":"module"},{"doc":"Type module to represent gear names as atoms.","ref":"Antikythera.GearName.html","title":"Antikythera.GearName","type":"module"},{"doc":"","ref":"Antikythera.GearName.html#valid?/1","title":"Antikythera.GearName.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.GearName.html#t:t/0","title":"Antikythera.GearName.t/0","type":"type"},{"doc":"","ref":"Antikythera.GearNameStr.html","title":"Antikythera.GearNameStr","type":"module"},{"doc":"","ref":"Antikythera.GearNameStr.html#pattern/0","title":"Antikythera.GearNameStr.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.GearNameStr.html#valid?/1","title":"Antikythera.GearNameStr.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.GearNameStr.html#t:t/0","title":"Antikythera.GearNameStr.t/0","type":"type"},{"doc":"A thin wrapper around Gettext.__using__/1 to forward error logs to each gear's logger.Usage of this module is exactly the same as Gettext; just use Antikythera.Gettext instead of use Gettext. Options given to use Antikythera.Gettext are directly passed to use Gettext. This module overrides the default implementation of Gettext.Backend.handle_missing_bindings/2 to suit the use cases for antikythera gears.","ref":"Antikythera.Gettext.html","title":"Antikythera.Gettext","type":"module"},{"doc":"","ref":"Antikythera.Http.html","title":"Antikythera.Http","type":"module"},{"doc":"","ref":"Antikythera.Http.Body.html","title":"Antikythera.Http.Body","type":"module"},{"doc":"","ref":"Antikythera.Http.Body.html#default/0","title":"Antikythera.Http.Body.default/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Body.html#valid?/1","title":"Antikythera.Http.Body.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Body.html#t:t/0","title":"Antikythera.Http.Body.t/0","type":"type"},{"doc":"HTTP headers as a map.If multiple headers in a single request/response have the same header name, their values are concatenated with commas. In case of cookie header values are concatenated using semicolons instead of commas.","ref":"Antikythera.Http.Headers.html","title":"Antikythera.Http.Headers","type":"module"},{"doc":"","ref":"Antikythera.Http.Headers.html#default/0","title":"Antikythera.Http.Headers.default/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Headers.html#valid?/1","title":"Antikythera.Http.Headers.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Headers.html#t:t/0","title":"Antikythera.Http.Headers.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.Method.html","title":"Antikythera.Http.Method","type":"module"},{"doc":"","ref":"Antikythera.Http.Method.html#all/0","title":"Antikythera.Http.Method.all/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#from_string/1","title":"Antikythera.Http.Method.from_string/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#new/1","title":"Antikythera.Http.Method.new/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#new!/1","title":"Antikythera.Http.Method.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#to_string/1","title":"Antikythera.Http.Method.to_string/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#valid?/1","title":"Antikythera.Http.Method.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#values/0","title":"Antikythera.Http.Method.values/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Method.html#t:t/0","title":"Antikythera.Http.Method.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.QueryParams.html","title":"Antikythera.Http.QueryParams","type":"module"},{"doc":"","ref":"Antikythera.Http.QueryParams.html#default/0","title":"Antikythera.Http.QueryParams.default/0","type":"function"},{"doc":"","ref":"Antikythera.Http.QueryParams.html#valid?/1","title":"Antikythera.Http.QueryParams.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.QueryParams.html#t:t/0","title":"Antikythera.Http.QueryParams.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.RawBody.html","title":"Antikythera.Http.RawBody","type":"module"},{"doc":"","ref":"Antikythera.Http.RawBody.html#default/0","title":"Antikythera.Http.RawBody.default/0","type":"function"},{"doc":"","ref":"Antikythera.Http.RawBody.html#valid?/1","title":"Antikythera.Http.RawBody.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.RawBody.html#t:t/0","title":"Antikythera.Http.RawBody.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.ReqCookiesMap.html","title":"Antikythera.Http.ReqCookiesMap","type":"module"},{"doc":"","ref":"Antikythera.Http.ReqCookiesMap.html#default/0","title":"Antikythera.Http.ReqCookiesMap.default/0","type":"function"},{"doc":"","ref":"Antikythera.Http.ReqCookiesMap.html#valid?/1","title":"Antikythera.Http.ReqCookiesMap.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.ReqCookiesMap.html#t:t/0","title":"Antikythera.Http.ReqCookiesMap.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.SetCookie.html","title":"Antikythera.Http.SetCookie","type":"module"},{"doc":"Type-aware getter for domain.","ref":"Antikythera.Http.SetCookie.html#domain/1","title":"Antikythera.Http.SetCookie.domain/1","type":"function"},{"doc":"Type-aware setter for domain.","ref":"Antikythera.Http.SetCookie.html#domain/2","title":"Antikythera.Http.SetCookie.domain/2","type":"function"},{"doc":"Type-aware getter for http_only.","ref":"Antikythera.Http.SetCookie.html#http_only/1","title":"Antikythera.Http.SetCookie.http_only/1","type":"function"},{"doc":"Type-aware setter for http_only.","ref":"Antikythera.Http.SetCookie.html#http_only/2","title":"Antikythera.Http.SetCookie.http_only/2","type":"function"},{"doc":"Type-aware getter for max_age.","ref":"Antikythera.Http.SetCookie.html#max_age/1","title":"Antikythera.Http.SetCookie.max_age/1","type":"function"},{"doc":"Type-aware setter for max_age.","ref":"Antikythera.Http.SetCookie.html#max_age/2","title":"Antikythera.Http.SetCookie.max_age/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Http.SetCookie by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Http.SetCookie.html#new/1","title":"Antikythera.Http.SetCookie.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Http.SetCookie.html#new!/1","title":"Antikythera.Http.SetCookie.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Http.SetCookie.html#parse!/1","title":"Antikythera.Http.SetCookie.parse!/1","type":"function"},{"doc":"Type-aware getter for path.","ref":"Antikythera.Http.SetCookie.html#path/1","title":"Antikythera.Http.SetCookie.path/1","type":"function"},{"doc":"Type-aware setter for path.","ref":"Antikythera.Http.SetCookie.html#path/2","title":"Antikythera.Http.SetCookie.path/2","type":"function"},{"doc":"Type-aware getter for secure.","ref":"Antikythera.Http.SetCookie.html#secure/1","title":"Antikythera.Http.SetCookie.secure/1","type":"function"},{"doc":"Type-aware setter for secure.","ref":"Antikythera.Http.SetCookie.html#secure/2","title":"Antikythera.Http.SetCookie.secure/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Http.SetCookie with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Http.SetCookie.html#update/2","title":"Antikythera.Http.SetCookie.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Http.SetCookie.html#update!/2","title":"Antikythera.Http.SetCookie.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Http.SetCookie.html#valid?/1","title":"Antikythera.Http.SetCookie.valid?/1","type":"function"},{"doc":"Type-aware getter for value.","ref":"Antikythera.Http.SetCookie.html#value/1","title":"Antikythera.Http.SetCookie.value/1","type":"function"},{"doc":"Type-aware setter for value.","ref":"Antikythera.Http.SetCookie.html#value/2","title":"Antikythera.Http.SetCookie.value/2","type":"function"},{"doc":"","ref":"Antikythera.Http.SetCookie.html#t:options_t/0","title":"Antikythera.Http.SetCookie.options_t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.SetCookie.html#t:t/0","title":"Antikythera.Http.SetCookie.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.SetCookiesMap.html","title":"Antikythera.Http.SetCookiesMap","type":"module"},{"doc":"","ref":"Antikythera.Http.SetCookiesMap.html#default/0","title":"Antikythera.Http.SetCookiesMap.default/0","type":"function"},{"doc":"","ref":"Antikythera.Http.SetCookiesMap.html#new/1","title":"Antikythera.Http.SetCookiesMap.new/1","type":"function"},{"doc":"","ref":"Antikythera.Http.SetCookiesMap.html#new!/1","title":"Antikythera.Http.SetCookiesMap.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Http.SetCookiesMap.html#valid?/1","title":"Antikythera.Http.SetCookiesMap.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.SetCookiesMap.html#t:t/0","title":"Antikythera.Http.SetCookiesMap.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.Status.html","title":"Antikythera.Http.Status","type":"module"},{"doc":"","ref":"Antikythera.Http.Status.html#code/1","title":"Antikythera.Http.Status.code/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.html#valid?/1","title":"Antikythera.Http.Status.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.html#t:t/0","title":"Antikythera.Http.Status.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.Status.Atom.html","title":"Antikythera.Http.Status.Atom","type":"module"},{"doc":"","ref":"Antikythera.Http.Status.Atom.html#new/1","title":"Antikythera.Http.Status.Atom.new/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Atom.html#new!/1","title":"Antikythera.Http.Status.Atom.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Atom.html#valid?/1","title":"Antikythera.Http.Status.Atom.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Atom.html#values/0","title":"Antikythera.Http.Status.Atom.values/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Atom.html#t:t/0","title":"Antikythera.Http.Status.Atom.t/0","type":"type"},{"doc":"","ref":"Antikythera.Http.Status.Int.html","title":"Antikythera.Http.Status.Int","type":"module"},{"doc":"","ref":"Antikythera.Http.Status.Int.html#max/0","title":"Antikythera.Http.Status.Int.max/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Int.html#min/0","title":"Antikythera.Http.Status.Int.min/0","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Int.html#valid?/1","title":"Antikythera.Http.Status.Int.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Http.Status.Int.html#t:t/0","title":"Antikythera.Http.Status.Int.t/0","type":"type"},{"doc":"HTTP client library.This is a wrapper around hackney, an HTTP client library. Httpc supports the following features:gzip-compression is tranparently handledheaders are represented by maps instead of listsheader names are always lower caseTCP connections are automatically re-established when closed by server due to keepalive timeoutBody formatThe body argument in post/4, put/4, patch/4, request/5 takes either:binary - Sends raw dataiolist - Sends raw data list (for more details see documentation for built-in types){:form, [{key, value}]} - Sends key-value data as x-www-form-urlencoded{:json, map} - Converts map into JSON and sends as application/json{:file, path} - Sends given file contentsOptions:timeout - Timeout to establish a connection, in milliseconds. Default is 8000.:recv_timeout - Timeout used when receiving a response. Default is 5000.:params - An enumerable of 2-tuples that will be URL-encoded and appended to the URL as query string parameters.:cookie - An enumerable of name-value pairs of cookies. Httpc automatically URL-encodes the given names/values for you.:basic_auth - A pair of {username, password} tuple to be used for HTTP basic authentication.:proxy - A proxy to be used for the request; it can be a regular URL or a {host, port} tuple.:proxy_auth - Proxy authentication {username, password} tuple.:ssl - SSL options supported by the ssl erlang module.:skip_ssl_verification - Whether to verify server's SSL certificate or not. Defaults to false. Specify skip_ssl_verification: true when accessing insecure server with HTTPS.:max_body - Maximum content-length of the response body (compressed size if it's compressed). Defaults to 10485760 (10MB) and must not exceed 150MB. Responses having body larger than the specified size will be rejected with {:error, :response_too_large}.:follow_redirect - A boolean that causes redirects to be followed. Defaults to false.:max_redirect - An integer denoting the maximum number of redirects to follow if follow_redirect: true is given.:skip_body_decompression - By default gzip-compressed body is automatically decompressed (i.e. defaults to false). Pass skip_body_decompression: true if compressed body is what you need.","ref":"Antikythera.Httpc.html","title":"Antikythera.Httpc","type":"module"},{"doc":"","ref":"Antikythera.Httpc.html#default_max_body/0","title":"Antikythera.Httpc.default_max_body/0","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#delete/3","title":"Antikythera.Httpc.delete/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#delete!/3","title":"Antikythera.Httpc.delete!/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#get/3","title":"Antikythera.Httpc.get/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#get!/3","title":"Antikythera.Httpc.get!/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#head/3","title":"Antikythera.Httpc.head/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#head!/3","title":"Antikythera.Httpc.head!/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#maximum_max_body/0","title":"Antikythera.Httpc.maximum_max_body/0","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#options/3","title":"Antikythera.Httpc.options/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#options!/3","title":"Antikythera.Httpc.options!/3","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#patch/4","title":"Antikythera.Httpc.patch/4","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#patch!/4","title":"Antikythera.Httpc.patch!/4","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#post/4","title":"Antikythera.Httpc.post/4","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#post!/4","title":"Antikythera.Httpc.post!/4","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#put/4","title":"Antikythera.Httpc.put/4","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#put!/4","title":"Antikythera.Httpc.put!/4","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#request/5","title":"Antikythera.Httpc.request/5","type":"function"},{"doc":"","ref":"Antikythera.Httpc.html#request!/5","title":"Antikythera.Httpc.request!/5","type":"function"},{"doc":"Just wrapping Httpc without any modification. Can be mocked with :meck.expect(Httpc.Mockable, :request, ...) without interfering other Httpc action.","ref":"Antikythera.Httpc.Mockable.html","title":"Antikythera.Httpc.Mockable","type":"module"},{"doc":"See Antikythera.Httpc.delete/3.","ref":"Antikythera.Httpc.Mockable.html#delete/3","title":"Antikythera.Httpc.Mockable.delete/3","type":"function"},{"doc":"See Antikythera.Httpc.delete!/3.","ref":"Antikythera.Httpc.Mockable.html#delete!/3","title":"Antikythera.Httpc.Mockable.delete!/3","type":"function"},{"doc":"See Antikythera.Httpc.get/3.","ref":"Antikythera.Httpc.Mockable.html#get/3","title":"Antikythera.Httpc.Mockable.get/3","type":"function"},{"doc":"See Antikythera.Httpc.get!/3.","ref":"Antikythera.Httpc.Mockable.html#get!/3","title":"Antikythera.Httpc.Mockable.get!/3","type":"function"},{"doc":"See Antikythera.Httpc.head/3.","ref":"Antikythera.Httpc.Mockable.html#head/3","title":"Antikythera.Httpc.Mockable.head/3","type":"function"},{"doc":"See Antikythera.Httpc.head!/3.","ref":"Antikythera.Httpc.Mockable.html#head!/3","title":"Antikythera.Httpc.Mockable.head!/3","type":"function"},{"doc":"See Antikythera.Httpc.options/3.","ref":"Antikythera.Httpc.Mockable.html#options/3","title":"Antikythera.Httpc.Mockable.options/3","type":"function"},{"doc":"See Antikythera.Httpc.options!/3.","ref":"Antikythera.Httpc.Mockable.html#options!/3","title":"Antikythera.Httpc.Mockable.options!/3","type":"function"},{"doc":"See Antikythera.Httpc.patch/4.","ref":"Antikythera.Httpc.Mockable.html#patch/4","title":"Antikythera.Httpc.Mockable.patch/4","type":"function"},{"doc":"See Antikythera.Httpc.patch!/4.","ref":"Antikythera.Httpc.Mockable.html#patch!/4","title":"Antikythera.Httpc.Mockable.patch!/4","type":"function"},{"doc":"See Antikythera.Httpc.post/4.","ref":"Antikythera.Httpc.Mockable.html#post/4","title":"Antikythera.Httpc.Mockable.post/4","type":"function"},{"doc":"See Antikythera.Httpc.post!/4.","ref":"Antikythera.Httpc.Mockable.html#post!/4","title":"Antikythera.Httpc.Mockable.post!/4","type":"function"},{"doc":"See Antikythera.Httpc.put/4.","ref":"Antikythera.Httpc.Mockable.html#put/4","title":"Antikythera.Httpc.Mockable.put/4","type":"function"},{"doc":"See Antikythera.Httpc.put!/4.","ref":"Antikythera.Httpc.Mockable.html#put!/4","title":"Antikythera.Httpc.Mockable.put!/4","type":"function"},{"doc":"See Antikythera.Httpc.request/5.","ref":"Antikythera.Httpc.Mockable.html#request/5","title":"Antikythera.Httpc.Mockable.request/5","type":"function"},{"doc":"See Antikythera.Httpc.request!/5.","ref":"Antikythera.Httpc.Mockable.html#request!/5","title":"Antikythera.Httpc.Mockable.request!/5","type":"function"},{"doc":"Type for Antikythera.Httpc's request body.","ref":"Antikythera.Httpc.ReqBody.html","title":"Antikythera.Httpc.ReqBody","type":"module"},{"doc":"","ref":"Antikythera.Httpc.ReqBody.html#convert_body_and_headers_by_body_type/2","title":"Antikythera.Httpc.ReqBody.convert_body_and_headers_by_body_type/2","type":"function"},{"doc":"","ref":"Antikythera.Httpc.ReqBody.html#valid?/1","title":"Antikythera.Httpc.ReqBody.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Httpc.ReqBody.html#t:json_obj/0","title":"Antikythera.Httpc.ReqBody.json_obj/0","type":"type"},{"doc":"","ref":"Antikythera.Httpc.ReqBody.html#t:t/0","title":"Antikythera.Httpc.ReqBody.t/0","type":"type"},{"doc":"A struct to represent an HTTP response.Response headers are converted to a Antikythera.Http.Headers.t and all header names are lower-cased. set-cookie response headers are handled separately and stored in cookies field as a Antikythera.Http.SetCookiesMap.t.","ref":"Antikythera.Httpc.Response.html","title":"Antikythera.Httpc.Response","type":"module"},{"doc":"Type-aware getter for body.","ref":"Antikythera.Httpc.Response.html#body/1","title":"Antikythera.Httpc.Response.body/1","type":"function"},{"doc":"Type-aware setter for body.","ref":"Antikythera.Httpc.Response.html#body/2","title":"Antikythera.Httpc.Response.body/2","type":"function"},{"doc":"Type-aware getter for cookies.","ref":"Antikythera.Httpc.Response.html#cookies/1","title":"Antikythera.Httpc.Response.cookies/1","type":"function"},{"doc":"Type-aware setter for cookies.","ref":"Antikythera.Httpc.Response.html#cookies/2","title":"Antikythera.Httpc.Response.cookies/2","type":"function"},{"doc":"Type-aware getter for headers.","ref":"Antikythera.Httpc.Response.html#headers/1","title":"Antikythera.Httpc.Response.headers/1","type":"function"},{"doc":"Type-aware setter for headers.","ref":"Antikythera.Httpc.Response.html#headers/2","title":"Antikythera.Httpc.Response.headers/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Httpc.Response by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Httpc.Response.html#new/1","title":"Antikythera.Httpc.Response.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Httpc.Response.html#new!/1","title":"Antikythera.Httpc.Response.new!/1","type":"function"},{"doc":"Type-aware getter for status.","ref":"Antikythera.Httpc.Response.html#status/1","title":"Antikythera.Httpc.Response.status/1","type":"function"},{"doc":"Type-aware setter for status.","ref":"Antikythera.Httpc.Response.html#status/2","title":"Antikythera.Httpc.Response.status/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Httpc.Response with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Httpc.Response.html#update/2","title":"Antikythera.Httpc.Response.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Httpc.Response.html#update!/2","title":"Antikythera.Httpc.Response.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Httpc.Response.html#valid?/1","title":"Antikythera.Httpc.Response.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Httpc.Response.html#t:t/0","title":"Antikythera.Httpc.Response.t/0","type":"type"},{"doc":"An IMF-fixdate format of date/time. Used in HTTP headers. Only 'GMT' is allowed as timezone string.","ref":"Antikythera.ImfFixdate.html","title":"Antikythera.ImfFixdate","type":"module"},{"doc":"","ref":"Antikythera.ImfFixdate.html#pattern/0","title":"Antikythera.ImfFixdate.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.ImfFixdate.html#valid?/1","title":"Antikythera.ImfFixdate.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.ImfFixdate.html#t:t/0","title":"Antikythera.ImfFixdate.t/0","type":"type"},{"doc":"Functions to parse/compare IP addresses.","ref":"Antikythera.IpAddress.html","title":"Antikythera.IpAddress","type":"module"},{"doc":"","ref":"Antikythera.IpAddress.V4.html","title":"Antikythera.IpAddress.V4","type":"module"},{"doc":"","ref":"Antikythera.IpAddress.V4.html#parse/1","title":"Antikythera.IpAddress.V4.parse/1","type":"function"},{"doc":"","ref":"Antikythera.IpAddress.V4.html#parse!/1","title":"Antikythera.IpAddress.V4.parse!/1","type":"function"},{"doc":"","ref":"Antikythera.IpAddress.V4.html#parse_range!/1","title":"Antikythera.IpAddress.V4.parse_range!/1","type":"function"},{"doc":"","ref":"Antikythera.IpAddress.V4.html#range_include?/2","title":"Antikythera.IpAddress.V4.range_include?/2","type":"function"},{"doc":"","ref":"Antikythera.IpAddress.V4.html#t:range/0","title":"Antikythera.IpAddress.V4.range/0","type":"type"},{"doc":"","ref":"Antikythera.IpAddress.V4.html#t:u32/0","title":"Antikythera.IpAddress.V4.u32/0","type":"type"},{"doc":"","ref":"Antikythera.IpAddress.V6.html","title":"Antikythera.IpAddress.V6","type":"module"},{"doc":"A strict subset of ISO8601 format of timestamp.","ref":"Antikythera.IsoTimestamp.html","title":"Antikythera.IsoTimestamp","type":"module"},{"doc":"","ref":"Antikythera.IsoTimestamp.html#valid?/1","title":"Antikythera.IsoTimestamp.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.IsoTimestamp.html#t:t/0","title":"Antikythera.IsoTimestamp.t/0","type":"type"},{"doc":"ISO8601 basic format.","ref":"Antikythera.IsoTimestamp.Basic.html","title":"Antikythera.IsoTimestamp.Basic","type":"module"},{"doc":"","ref":"Antikythera.IsoTimestamp.Basic.html#valid?/1","title":"Antikythera.IsoTimestamp.Basic.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.IsoTimestamp.Basic.html#t:t/0","title":"Antikythera.IsoTimestamp.Basic.t/0","type":"type"},{"doc":"Utilities to manipulate Elixir AST.","ref":"Antikythera.MacroUtil.html","title":"Antikythera.MacroUtil","type":"module"},{"doc":"","ref":"Antikythera.MacroUtil.html#prewalk_accumulate/3","title":"Antikythera.MacroUtil.prewalk_accumulate/3","type":"function"},{"doc":"Utility functions to work with maps.","ref":"Antikythera.MapUtil.html","title":"Antikythera.MapUtil","type":"module"},{"doc":"","ref":"Antikythera.MapUtil.html#difference/2","title":"Antikythera.MapUtil.difference/2","type":"function"},{"doc":"","ref":"Antikythera.MapUtil.html#map_values/2","title":"Antikythera.MapUtil.map_values/2","type":"function"},{"doc":"Update the key in map with the given function, only when the key exists. Unlike Map.update!/3, it returns :error if the key does not exist.","ref":"Antikythera.MapUtil.html#update_existing/3","title":"Antikythera.MapUtil.update_existing/3","type":"function"},{"doc":"Easy-to-use in-memory cache for each executor pool.Antikythera.Memcache behaves as a key-value storage. Cached key-value pairs are internally stored in ETS. It accepts arbitrary (but not too large) terms as both keys and values.Usageiex&gt; Antikythera.Memcache.write(&quot;foo&quot;, &quot;bar&quot;, epool_id, 3_600) :ok iex&gt; Antikythera.Memcache.read(&quot;foo&quot;, epool_id) {:ok, &quot;bar&quot;}LimitsThe number of records and the size of keys and values are limited.The maximum number of records for each executor pool is 100.If exceeds the limit, a record nearest to expiration is evicted so that a new record can be inserted.The maximum size of keys and values is defined in Antikythera.Memcache.Key and Antikythera.Memcache.Value.To know how the size of keys and values is calculated, see Antikythera.TermUtil.If exceeds the limit, write/5 returns an error :too_large_key or :too_large_value.Lifetime of recordsThere are 2 cases where records in Antikythera.Memcache are evicted:Records are expired (see Mechanism of Expiration below for more details)Reach the maximum number of records for each executor pool (as mentioned in Limits)Please note that records in Antikythera.Memcache could be evicted anytime.Mechanism of ExpirationThe lifetime of records must be set as lifetime_in_sec in write/5. This lifetime does not guarantee that records remain in the entire specified lifetime.To avoid the thundering herd, whether records are expired is decided probabilistically. The probability of expiration is shown in the following.If the thundering herd becomes a big problem, adjust prob_lifetime_ratio in write/5.","ref":"Antikythera.Memcache.html","title":"Antikythera.Memcache","type":"module"},{"doc":"Read the value associated with the key from Antikythera.Memcache.Please note that records in Antikythera.Memcache could be evicted anytime so the error handling must be needed.","ref":"Antikythera.Memcache.html#read/2","title":"Antikythera.Memcache.read/2","type":"function"},{"doc":"Try to read a value associated with the key from Antikythera.Memcache and if that fails, write a value returned by fun to Antikythera.Memcache.fun is evaluated only if a value is not found, and the new value returned by fun is stored in Antikythera.Memcache. If a value is found in Antikythera.Memcache or writing the new value to Antikythera.Memcache succeeds, the value is returned as {:ok, value}, but if writing the new value fails, an error is returned in the same manner as write/5.Parameters lifetime_in_sec and prob_lifetime_ratio are used to call write/5 and the details are described above.","ref":"Antikythera.Memcache.html#read_or_else_write/5","title":"Antikythera.Memcache.read_or_else_write/5","type":"function"},{"doc":"Write a key-value pair to Antikythera.Memcache.See above descriptions for more details.","ref":"Antikythera.Memcache.html#write/5","title":"Antikythera.Memcache.write/5","type":"function"},{"doc":"A type module of keys for Antikythera.Memcache.The maximum size of keys is 128 bytes. To know how the size is calculated, see Antikythera.TermUtil.","ref":"Antikythera.Memcache.Key.html","title":"Antikythera.Memcache.Key","type":"module"},{"doc":"","ref":"Antikythera.Memcache.Key.html#max_size/0","title":"Antikythera.Memcache.Key.max_size/0","type":"function"},{"doc":"","ref":"Antikythera.Memcache.Key.html#valid?/1","title":"Antikythera.Memcache.Key.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Memcache.Key.html#t:t/0","title":"Antikythera.Memcache.Key.t/0","type":"type"},{"doc":"","ref":"Antikythera.Memcache.NormalizedFloat.html","title":"Antikythera.Memcache.NormalizedFloat","type":"module"},{"doc":"","ref":"Antikythera.Memcache.NormalizedFloat.html#max/0","title":"Antikythera.Memcache.NormalizedFloat.max/0","type":"function"},{"doc":"","ref":"Antikythera.Memcache.NormalizedFloat.html#min/0","title":"Antikythera.Memcache.NormalizedFloat.min/0","type":"function"},{"doc":"","ref":"Antikythera.Memcache.NormalizedFloat.html#valid?/1","title":"Antikythera.Memcache.NormalizedFloat.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Memcache.NormalizedFloat.html#t:t/0","title":"Antikythera.Memcache.NormalizedFloat.t/0","type":"type"},{"doc":"A type module of values for Antikythera.Memcache.The maximum size of values is 65536 bytes. To know how the size is calculated, see Antikythera.TermUtil.","ref":"Antikythera.Memcache.Value.html","title":"Antikythera.Memcache.Value","type":"module"},{"doc":"","ref":"Antikythera.Memcache.Value.html#max_size/0","title":"Antikythera.Memcache.Value.max_size/0","type":"function"},{"doc":"","ref":"Antikythera.Memcache.Value.html#valid?/1","title":"Antikythera.Memcache.Value.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Memcache.Value.html#t:t/0","title":"Antikythera.Memcache.Value.t/0","type":"type"},{"doc":"","ref":"Antikythera.Metrics.Data.html","title":"Antikythera.Metrics.Data","type":"module"},{"doc":"","ref":"Antikythera.Metrics.Data.html#valid?/1","title":"Antikythera.Metrics.Data.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Metrics.Data.html#t:t/0","title":"Antikythera.Metrics.Data.t/0","type":"type"},{"doc":"","ref":"Antikythera.Metrics.DataList.html","title":"Antikythera.Metrics.DataList","type":"module"},{"doc":"","ref":"Antikythera.Metrics.DataList.html#min_length/0","title":"Antikythera.Metrics.DataList.min_length/0","type":"function"},{"doc":"","ref":"Antikythera.Metrics.DataList.html#valid?/1","title":"Antikythera.Metrics.DataList.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Metrics.DataList.html#t:t/0","title":"Antikythera.Metrics.DataList.t/0","type":"type"},{"doc":"","ref":"Antikythera.MilliSecondsInGregorian.html","title":"Antikythera.MilliSecondsInGregorian","type":"module"},{"doc":"","ref":"Antikythera.MilliSecondsInGregorian.html#min/0","title":"Antikythera.MilliSecondsInGregorian.min/0","type":"function"},{"doc":"","ref":"Antikythera.MilliSecondsInGregorian.html#time_epoch_offset_milliseconds/0","title":"Antikythera.MilliSecondsInGregorian.time_epoch_offset_milliseconds/0","type":"function"},{"doc":"","ref":"Antikythera.MilliSecondsInGregorian.html#valid?/1","title":"Antikythera.MilliSecondsInGregorian.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.MilliSecondsInGregorian.html#t:t/0","title":"Antikythera.MilliSecondsInGregorian.t/0","type":"type"},{"doc":"","ref":"Antikythera.MilliSecondsSinceEpoch.html","title":"Antikythera.MilliSecondsSinceEpoch","type":"module"},{"doc":"","ref":"Antikythera.MilliSecondsSinceEpoch.html#min/0","title":"Antikythera.MilliSecondsSinceEpoch.min/0","type":"function"},{"doc":"","ref":"Antikythera.MilliSecondsSinceEpoch.html#valid?/1","title":"Antikythera.MilliSecondsSinceEpoch.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.MilliSecondsSinceEpoch.html#t:t/0","title":"Antikythera.MilliSecondsSinceEpoch.t/0","type":"type"},{"doc":"Helper functions for making mix tasks in gears.Functions in this module can only be used in mix tasks.","ref":"Antikythera.Mix.Task.html","title":"Antikythera.Mix.Task","type":"module"},{"doc":"Starts the current antikythera instance and its dependency applications without web server functionality.If you need web server functionality in your mix task, use Application.ensure_all_started(Antikythera.Env.antikythera_instance_name()).","ref":"Antikythera.Mix.Task.html#prepare_antikythera_instance/0","title":"Antikythera.Mix.Task.prepare_antikythera_instance/0","type":"function"},{"doc":"Set the specified node_id to the Antikythera.ContextId in GearLog.If you want to use GearLog in mix task, you must set node_id before you call GearLog functions.The Antikythera.ContextId in GearLog will become {timestamp}_{node_id}_{PID}. The timestamp and PID are automatically got from system.","ref":"Antikythera.Mix.Task.html#set_node_id_to_gear_log_context/1","title":"Antikythera.Mix.Task.set_node_id_to_gear_log_context/1","type":"function"},{"doc":"Utility functions to work with nested maps.","ref":"Antikythera.NestedMap.html","title":"Antikythera.NestedMap","type":"module"},{"doc":"","ref":"Antikythera.NestedMap.html#deep_merge/2","title":"Antikythera.NestedMap.deep_merge/2","type":"function"},{"doc":"","ref":"Antikythera.NestedMap.html#force_update/3","title":"Antikythera.NestedMap.force_update/3","type":"function"},{"doc":"Updates a key in a nested map. Recursively traversing the map according to the given keys to the last member. If the last member exists, update it with the given function. Unlike Kernel.update_in/3, returns :error if any of the keys cannot be found.","ref":"Antikythera.NestedMap.html#update_existing_in/3","title":"Antikythera.NestedMap.update_existing_in/3","type":"function"},{"doc":"","ref":"Antikythera.NodeId.html","title":"Antikythera.NodeId","type":"module"},{"doc":"","ref":"Antikythera.NodeId.html#pattern/0","title":"Antikythera.NodeId.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.NodeId.html#pattern_string/0","title":"Antikythera.NodeId.pattern_string/0","type":"function"},{"doc":"","ref":"Antikythera.NodeId.html#valid?/1","title":"Antikythera.NodeId.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.NodeId.html#t:t/0","title":"Antikythera.NodeId.t/0","type":"type"},{"doc":"","ref":"Antikythera.PathInfo.html","title":"Antikythera.PathInfo","type":"module"},{"doc":"","ref":"Antikythera.PathInfo.html#valid?/1","title":"Antikythera.PathInfo.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.PathInfo.html#t:t/0","title":"Antikythera.PathInfo.t/0","type":"type"},{"doc":"A type module to represent URI-encoded segment of URL path.See RFC3986 for the specifications of URI path. Note that this module accepts empty strings.","ref":"Antikythera.PathSegment.html","title":"Antikythera.PathSegment","type":"module"},{"doc":"","ref":"Antikythera.PathSegment.html#charclass/0","title":"Antikythera.PathSegment.charclass/0","type":"function"},{"doc":"","ref":"Antikythera.PathSegment.html#pattern/0","title":"Antikythera.PathSegment.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.PathSegment.html#valid?/1","title":"Antikythera.PathSegment.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.PathSegment.html#t:t/0","title":"Antikythera.PathSegment.t/0","type":"type"},{"doc":"Plug to restrict access to controller action by basic authentication.UsageStatic username/password: using gear configThe following line installs a plug that checks username/password in incoming requests against &quot;BASIC_AUTHENTICATION_ID&quot; and &quot;BASIC_AUTHENTICATION_PW&quot; in your gear's gear config.plug Antikythera.Plug.BasicAuthentication, :check_with_config, []Dynamic username/password: using module-function pair.In the following case you can check the username/password pair with arbitrary logic by the specified function.plug Antikythera.Plug.BasicAuthentication, :check_with_fun, [mod: YourGear.AuthModule, fun: :function_name]The given function (YourGear.AuthModule.function_name/3 in this case) must have the following type signature:receives (1) a Antikythera.Conn.t, (2) username, and (3) passwordreturns (1) {:ok, Antikythera.Conn.t} if successfully authenticated, (2) :error otherwise","ref":"Antikythera.Plug.BasicAuthentication.html","title":"Antikythera.Plug.BasicAuthentication","type":"module"},{"doc":"","ref":"Antikythera.Plug.BasicAuthentication.html#check_with_config/2","title":"Antikythera.Plug.BasicAuthentication.check_with_config/2","type":"function"},{"doc":"","ref":"Antikythera.Plug.BasicAuthentication.html#check_with_fun/2","title":"Antikythera.Plug.BasicAuthentication.check_with_fun/2","type":"function"},{"doc":"Plug to automatically load flash messages from session.UsageAdd the following line in a controller module (note that the order of the plugs is important):plug Antikythera.Plug.Session, :load, [key: &quot;12345678&quot;] plug Antikythera.Plug.Flash , :load, []Then you can access flash messages byAntikythera.Conn.get_flash/2Antikythera.Conn.put_flash/3","ref":"Antikythera.Plug.Flash.html","title":"Antikythera.Plug.Flash","type":"module"},{"doc":"","ref":"Antikythera.Plug.Flash.html#load/2","title":"Antikythera.Plug.Flash.load/2","type":"function"},{"doc":"Plug to restrict access to controller action only from within specified IP ranges.UsageStatic IP ranges specified as a plug argumentThe following lines reject requests from IP not within the 2 ranges, &quot;123.45.67.0/24&quot;, &quot;135.79.135.0/24&quot;.ranges = Enum.map([&quot;123.45.67.0/24&quot;, &quot;135.79.135.0/24&quot;], &amp;Antikythera.IpAddress.V4.parse!/1) plug Antikythera.Plug.IpFiltering, :check_by_static_ranges, [ranges: ranges]Note that this plug accepts only parsed result and not string, in order to avoid parsing the given strings on every request.Dynamic IP ranges specified by gear configThe following line uses &quot;ALLOWED_IP_RANGES&quot; field in the gear config as the list of allowed IP ranges.plug Antikythera.Plug.IpFiltering, :check_by_gear_config, []The field name can be customized by giving :field_name option as follows:plug Antikythera.Plug.IpFiltering, :check_by_gear_config, [field_name: &quot;ALLOWED_IP_RANGES_2&quot;]gear-to-gear requestsBoth plug functions explained above reject not only web requests from outside of the specified IP ranges but also gear-to-gear requests. If you want to restrict web requests and at the same time allow gear-to-gear requests, pass :allow_g2g option.plug Antikythera.Plug.IpFiltering, :check_by_gear_config, [allow_g2g: true]","ref":"Antikythera.Plug.IpFiltering.html","title":"Antikythera.Plug.IpFiltering","type":"module"},{"doc":"","ref":"Antikythera.Plug.IpFiltering.html#check_by_gear_config/2","title":"Antikythera.Plug.IpFiltering.check_by_gear_config/2","type":"function"},{"doc":"","ref":"Antikythera.Plug.IpFiltering.html#check_by_static_ranges/2","title":"Antikythera.Plug.IpFiltering.check_by_static_ranges/2","type":"function"},{"doc":"","ref":"Antikythera.Plug.IpFiltering.html#run_check_on_cloud/3","title":"Antikythera.Plug.IpFiltering.run_check_on_cloud/3","type":"function"},{"doc":"","ref":"Antikythera.Plug.IpFiltering.html#t:arg_gear_config/0","title":"Antikythera.Plug.IpFiltering.arg_gear_config/0","type":"type"},{"doc":"","ref":"Antikythera.Plug.IpFiltering.html#t:arg_static/0","title":"Antikythera.Plug.IpFiltering.arg_static/0","type":"type"},{"doc":"Plug to set a fixed value of cache-control response header in order to disable client side caching.The value used is: &quot;private, no-cache, no-store, max-age=0&quot;.UsagePut the following line in your controller module:plug Antikythera.Plug.NoCache, :put_resp_header, []Note that this plug runs before your controller's actions; in your actions you can overwrite the cache-control header set by this plug.","ref":"Antikythera.Plug.NoCache.html","title":"Antikythera.Plug.NoCache","type":"module"},{"doc":"","ref":"Antikythera.Plug.NoCache.html#header_value/0","title":"Antikythera.Plug.NoCache.header_value/0","type":"function"},{"doc":"","ref":"Antikythera.Plug.NoCache.html#put_resp_header/2","title":"Antikythera.Plug.NoCache.put_resp_header/2","type":"function"},{"doc":"Plug to automatically load/store session information using a specific session store. Uses cookie store by default.UsageAdding the following line in a controller module enables this plug:plug Antikythera.Plug.Session, :load, [key: &quot;12345678&quot;]Then,session values are loaded from cookie before controller action is executed, andsession values are stored into cookie after controller action is executed.","ref":"Antikythera.Plug.Session.html","title":"Antikythera.Plug.Session","type":"module"},{"doc":"","ref":"Antikythera.Plug.Session.html#load/2","title":"Antikythera.Plug.Session.load/2","type":"function"},{"doc":"","ref":"Antikythera.Registry.html","title":"Antikythera.Registry","type":"module"},{"doc":"","ref":"Antikythera.Registry.html#t:name/0","title":"Antikythera.Registry.name/0","type":"type"},{"doc":"A global (cluster-wide) process registry for implementing publisher-subscriber communication pattern.In this registry you can register multiple processes with the same name. Then you can broadcast a message to the group of processes having the same name. Group names can be arbitrary string. Each process can join multiple groups at the same time. When the registered process dies its pid will be automatically removed from all the groups that the process has joined.","ref":"Antikythera.Registry.Group.html","title":"Antikythera.Registry.Group","type":"module"},{"doc":"","ref":"Antikythera.Registry.Group.html#join/2","title":"Antikythera.Registry.Group.join/2","type":"function"},{"doc":"","ref":"Antikythera.Registry.Group.html#leave/2","title":"Antikythera.Registry.Group.leave/2","type":"function"},{"doc":"","ref":"Antikythera.Registry.Group.html#publish/3","title":"Antikythera.Registry.Group.publish/3","type":"function"},{"doc":"A global (cluster-wide) process registry to implement 1-to-1 process communications.Process names can be arbitrary string as long as it's unique within an executor pool. Each process is not allowed to have more than one name. When the registered process dies its name will be automatically removed from the registry.Note that the uniqueness of names is not strictly checked; in case of race conditions of simultaneous registrations on different nodes, multiple processes successfully register the same name. The conflict will be resolved by choosing a single process and killing the others. To avoid troubles with this kind of naming conflicts, it's recommended to use intrinsically unique IDs such as login IDs of clients.","ref":"Antikythera.Registry.Unique.html","title":"Antikythera.Registry.Unique","type":"module"},{"doc":"","ref":"Antikythera.Registry.Unique.html#register/2","title":"Antikythera.Registry.Unique.register/2","type":"function"},{"doc":"","ref":"Antikythera.Registry.Unique.html#send_message/3","title":"Antikythera.Registry.Unique.send_message/3","type":"function"},{"doc":"Definition of Antikythera.Request struct.","ref":"Antikythera.Request.html","title":"Antikythera.Request","type":"module"},{"doc":"Type-aware getter for body.","ref":"Antikythera.Request.html#body/1","title":"Antikythera.Request.body/1","type":"function"},{"doc":"Type-aware setter for body.","ref":"Antikythera.Request.html#body/2","title":"Antikythera.Request.body/2","type":"function"},{"doc":"Type-aware getter for cookies.","ref":"Antikythera.Request.html#cookies/1","title":"Antikythera.Request.cookies/1","type":"function"},{"doc":"Type-aware setter for cookies.","ref":"Antikythera.Request.html#cookies/2","title":"Antikythera.Request.cookies/2","type":"function"},{"doc":"Type-aware getter for headers.","ref":"Antikythera.Request.html#headers/1","title":"Antikythera.Request.headers/1","type":"function"},{"doc":"Type-aware setter for headers.","ref":"Antikythera.Request.html#headers/2","title":"Antikythera.Request.headers/2","type":"function"},{"doc":"Type-aware getter for method.","ref":"Antikythera.Request.html#method/1","title":"Antikythera.Request.method/1","type":"function"},{"doc":"Type-aware setter for method.","ref":"Antikythera.Request.html#method/2","title":"Antikythera.Request.method/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Request by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Request.html#new/1","title":"Antikythera.Request.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Request.html#new!/1","title":"Antikythera.Request.new!/1","type":"function"},{"doc":"Type-aware getter for path_info.","ref":"Antikythera.Request.html#path_info/1","title":"Antikythera.Request.path_info/1","type":"function"},{"doc":"Type-aware setter for path_info.","ref":"Antikythera.Request.html#path_info/2","title":"Antikythera.Request.path_info/2","type":"function"},{"doc":"Type-aware getter for path_matches.","ref":"Antikythera.Request.html#path_matches/1","title":"Antikythera.Request.path_matches/1","type":"function"},{"doc":"Type-aware setter for path_matches.","ref":"Antikythera.Request.html#path_matches/2","title":"Antikythera.Request.path_matches/2","type":"function"},{"doc":"Type-aware getter for query_params.","ref":"Antikythera.Request.html#query_params/1","title":"Antikythera.Request.query_params/1","type":"function"},{"doc":"Type-aware setter for query_params.","ref":"Antikythera.Request.html#query_params/2","title":"Antikythera.Request.query_params/2","type":"function"},{"doc":"Type-aware getter for raw_body.","ref":"Antikythera.Request.html#raw_body/1","title":"Antikythera.Request.raw_body/1","type":"function"},{"doc":"Type-aware setter for raw_body.","ref":"Antikythera.Request.html#raw_body/2","title":"Antikythera.Request.raw_body/2","type":"function"},{"doc":"Type-aware getter for sender.","ref":"Antikythera.Request.html#sender/1","title":"Antikythera.Request.sender/1","type":"function"},{"doc":"Type-aware setter for sender.","ref":"Antikythera.Request.html#sender/2","title":"Antikythera.Request.sender/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Request with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Request.html#update/2","title":"Antikythera.Request.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Request.html#update!/2","title":"Antikythera.Request.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Request.html#valid?/1","title":"Antikythera.Request.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Request.html#t:t/0","title":"Antikythera.Request.t/0","type":"type"},{"doc":"","ref":"Antikythera.Request.PathMatches.html","title":"Antikythera.Request.PathMatches","type":"module"},{"doc":"","ref":"Antikythera.Request.PathMatches.html#valid?/1","title":"Antikythera.Request.PathMatches.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Request.PathMatches.html#t:t/0","title":"Antikythera.Request.PathMatches.t/0","type":"type"},{"doc":"","ref":"Antikythera.Request.Sender.html","title":"Antikythera.Request.Sender","type":"module"},{"doc":"","ref":"Antikythera.Request.Sender.html#valid?/1","title":"Antikythera.Request.Sender.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Request.Sender.html#t:sender_ip/0","title":"Antikythera.Request.Sender.sender_ip/0","type":"type"},{"doc":"","ref":"Antikythera.Request.Sender.html#t:t/0","title":"Antikythera.Request.Sender.t/0","type":"type"},{"doc":"Defines the antikythera routing DSL.Routing macrosThis module defines macros to be used in each gear's Router module. The names of the macros are the same as the HTTP verbs: get, post, etc.The macros take the following 4 arguments (although you can omit the last and just pass 3 of them):URL path pattern which consists of '/'-separated segments. The 1st character must be '/'. To match against incoming request path to a pattern you can use placeholders. See examples below for the usage.Controller module. Antikythera expects that the module name given here does not contain GearName.Controller. as a prefix; it's automatically prepended by antikythera.Name of the controller action as an atom.Keyword list of options. Currently available options are :from and :as. See below for further explanations.ExampleIf you define the following router module,defmodule MyGear.Router do use Antikythera.Router static_prefix &quot;/static&quot; websocket &quot;/ws&quot; get &quot;/foo&quot; , Hello, :exact_match post &quot;/foo/:a/:b&quot; , Hello, :placeholders put &quot;/foo/bar/*w&quot;, Hello, :wildcard endThen the following requests are routed as:GET &quot;/foo&quot; =&gt; MyGear.Controller.Hello.exact_match/1 is invoked with path_matches: %{}POST &quot;/foo/bar/baz&quot; =&gt; MyGear.Controller.Hello.placeholders/1 is invoked with path_matches: %{a: &quot;bar&quot;, b: &quot;baz&quot;}PUT &quot;/foo/bar/abc/def/ghi&quot; =&gt; MyGear.Controller.Hello.wildcard/1 is invoked with path_matches: %{w: &quot;abc/def/ghi&quot;}Note thatEach controller action is expected to receive a Antikythera.Conn struct and returns a Antikythera.Conn struct.Antikythera.Conn struct has a field request which is a Antikythera.Request struct.Matched segments are URL-decoded and stored in path_matches field in Antikythera.Request. If the result of URL-decoding is nonprintable binary, the request is rejected.Websocket endpointTo enable websocket interaction with clients, you must first define MyGear.Websocket module. See Antikythera.Websocket for more details about websocket handler module. Then invoke websocket/1 macro in your router.websocket &quot;/ws_path_pattern&quot;The path pattern may have placeholders in the same way as normal routes. GET request with appropriate headers to this path will initialize a websocket connection using the HTTP 1.1 upgrade mechanism.If your gear does not interact with clients via websocket, simply don't invoke websocket/1 macro in your router.Static file servingYou can serve your static assets by placing them under /priv/static directory in your gear project. The endpoint to be used can be specified by static_prefix/1 macro. For example, if you addstatic_prefix &quot;/assets&quot;to your router, you can download /priv/static/html/index.html file by sending GET request to the path /assets/html/index.html.If you don't need to serve static assets, just don't call static_prefix/1 macro in your router.Currently, static assets served in this way are NOT automatically gzip compressed, even if acceept-encoding: gzip request header is set. It is recommended to use CDN to deliver large static assets in production.See also Antikythera.Asset for usage of CDN in delivery of static assets.Web requests and gear-to-gear (g2g) requestsAntikythera treats both web requests and g2g requests in basically the same way. This means that if you define a route in your gear one can send request to the route using both HTTP and g2g communication. If you want to define a route that can be accessible only via g2g communication, specify from: :gear option.get &quot;/foo&quot;, Hello, :action1, from: :gear post &quot;/bar&quot;, Hello, :action2, from: :gearSimilarly passing from: :web makes the route accessible only from web request.When dealing with multiple routes, only_from_web/1 and only_from_gear/1 macros can be used. For example, the following routes definition is the same as above one.only_from_gear do get &quot;/foo&quot;, Hello, :action1 post &quot;/bar&quot;, Hello, :action2 endReverse routingTo generate URL path of a route (e.g. a link in HTML), you will want to refer to the route's path. For this purpose you can specify :as option. For example, you have the following router moduledefmodule MyGear.Router do use Antikythera.Router get &quot;/foo/:a/:b/*c&quot;, Hello, :placeholders, as: :myroute endBy writing this the router automatically defines a function myroute_path/4, which receives segments that fill placeholders and an optional map for query parameters.MyGear.Router.myroute_path(&quot;segment_a&quot;, &quot;segment_b&quot;, [&quot;wildcard&quot;, &quot;part&quot;]) =&gt; &quot;/foo/segment_a/segment_b/wildcard/part MyGear.Router.myroute_path(&quot;segment_a&quot;, &quot;segment_b&quot;, [&quot;wildcard&quot;, &quot;part&quot;], %{&quot;query&quot; =&gt; &quot;param&quot;}) =&gt; &quot;/foo/segment_a/segment_b/wildcard/part?query=paramReverse routing helper functions automatically URI-encode all given arguments.If websocket endpoint is enabled, you can get its path with MyGear.Router.websocket_path/0. Also if static file serving is enabled, path prefix for static files can be obtained by MyGear.Router.static_prefix/0.","ref":"Antikythera.Router.html","title":"Antikythera.Router","type":"module"},{"doc":"","ref":"Antikythera.Router.html#connect/4","title":"Antikythera.Router.connect/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#delete/4","title":"Antikythera.Router.delete/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#fully_qualified_controller_module/3","title":"Antikythera.Router.fully_qualified_controller_module/3","type":"function"},{"doc":"","ref":"Antikythera.Router.html#get/4","title":"Antikythera.Router.get/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#head/4","title":"Antikythera.Router.head/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#only_from_gear/1","title":"Antikythera.Router.only_from_gear/1","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#only_from_web/1","title":"Antikythera.Router.only_from_web/1","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#options/4","title":"Antikythera.Router.options/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#patch/4","title":"Antikythera.Router.patch/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#post/4","title":"Antikythera.Router.post/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#put/4","title":"Antikythera.Router.put/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#static_prefix/1","title":"Antikythera.Router.static_prefix/1","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#trace/4","title":"Antikythera.Router.trace/4","type":"macro"},{"doc":"","ref":"Antikythera.Router.html#websocket/2","title":"Antikythera.Router.websocket/2","type":"macro"},{"doc":"Internal functions to implement request routing.","ref":"Antikythera.Router.Impl.html","title":"Antikythera.Router.Impl","type":"module"},{"doc":"","ref":"Antikythera.Router.Impl.html#check_path_pattern/1","title":"Antikythera.Router.Impl.check_path_pattern/1","type":"function"},{"doc":"","ref":"Antikythera.Router.Impl.html#generate_route_function_clauses/3","title":"Antikythera.Router.Impl.generate_route_function_clauses/3","type":"function"},{"doc":"","ref":"Antikythera.Router.Impl.html#route_clause_body/4","title":"Antikythera.Router.Impl.route_clause_body/4","type":"function"},{"doc":"Internal helper functions for macros in Antikythera.Router, to generate/implement reverse routing functions.","ref":"Antikythera.Router.Reverse.html","title":"Antikythera.Router.Reverse","type":"module"},{"doc":"","ref":"Antikythera.Router.Reverse.html#define_path_helper/2","title":"Antikythera.Router.Reverse.define_path_helper/2","type":"function"},{"doc":"","ref":"Antikythera.Router.Reverse.html#make_path/3","title":"Antikythera.Router.Reverse.make_path/3","type":"function"},{"doc":"","ref":"Antikythera.SecondsSinceEpoch.html","title":"Antikythera.SecondsSinceEpoch","type":"module"},{"doc":"","ref":"Antikythera.SecondsSinceEpoch.html#min/0","title":"Antikythera.SecondsSinceEpoch.min/0","type":"function"},{"doc":"","ref":"Antikythera.SecondsSinceEpoch.html#valid?/1","title":"Antikythera.SecondsSinceEpoch.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.SecondsSinceEpoch.html#t:t/0","title":"Antikythera.SecondsSinceEpoch.t/0","type":"type"},{"doc":"Definition of data structure to work with session.Gear implementations usually don't use the functions defined in this module; instead useAntikythera.Plug.Sessioninterfaces in Antikythera.Conn (e.g. Antikythera.Conn.get_session/2).","ref":"Antikythera.Session.html","title":"Antikythera.Session","type":"module"},{"doc":"","ref":"Antikythera.Session.html#clear/1","title":"Antikythera.Session.clear/1","type":"function"},{"doc":"Type-aware getter for data.","ref":"Antikythera.Session.html#data/1","title":"Antikythera.Session.data/1","type":"function"},{"doc":"Type-aware setter for data.","ref":"Antikythera.Session.html#data/2","title":"Antikythera.Session.data/2","type":"function"},{"doc":"","ref":"Antikythera.Session.html#delete/2","title":"Antikythera.Session.delete/2","type":"function"},{"doc":"","ref":"Antikythera.Session.html#destroy/1","title":"Antikythera.Session.destroy/1","type":"function"},{"doc":"","ref":"Antikythera.Session.html#get/2","title":"Antikythera.Session.get/2","type":"function"},{"doc":"Type-aware getter for id.","ref":"Antikythera.Session.html#id/1","title":"Antikythera.Session.id/1","type":"function"},{"doc":"Type-aware setter for id.","ref":"Antikythera.Session.html#id/2","title":"Antikythera.Session.id/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Session by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Session.html#new/1","title":"Antikythera.Session.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Session.html#new!/1","title":"Antikythera.Session.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Session.html#put/3","title":"Antikythera.Session.put/3","type":"function"},{"doc":"","ref":"Antikythera.Session.html#renew/1","title":"Antikythera.Session.renew/1","type":"function"},{"doc":"Type-aware getter for state.","ref":"Antikythera.Session.html#state/1","title":"Antikythera.Session.state/1","type":"function"},{"doc":"Type-aware setter for state.","ref":"Antikythera.Session.html#state/2","title":"Antikythera.Session.state/2","type":"function"},{"doc":"Updates an existing instance of Antikythera.Session with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Session.html#update/2","title":"Antikythera.Session.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Session.html#update!/2","title":"Antikythera.Session.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Session.html#valid?/1","title":"Antikythera.Session.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Session.html#t:t/0","title":"Antikythera.Session.t/0","type":"type"},{"doc":"Implementation of Antikythera.Session.Store that stores session info in cookie.","ref":"Antikythera.Session.Cookie.html","title":"Antikythera.Session.Cookie","type":"module"},{"doc":"","ref":"Antikythera.Session.State.html","title":"Antikythera.Session.State","type":"module"},{"doc":"","ref":"Antikythera.Session.State.html#new/1","title":"Antikythera.Session.State.new/1","type":"function"},{"doc":"","ref":"Antikythera.Session.State.html#new!/1","title":"Antikythera.Session.State.new!/1","type":"function"},{"doc":"","ref":"Antikythera.Session.State.html#valid?/1","title":"Antikythera.Session.State.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Session.State.html#values/0","title":"Antikythera.Session.State.values/0","type":"function"},{"doc":"","ref":"Antikythera.Session.State.html#t:t/0","title":"Antikythera.Session.State.t/0","type":"type"},{"doc":"Behaviour of session store.","ref":"Antikythera.Session.Store.html","title":"Antikythera.Session.Store","type":"behaviour"},{"doc":"","ref":"Antikythera.Session.Store.html#c:delete/1","title":"Antikythera.Session.Store.delete/1","type":"callback"},{"doc":"","ref":"Antikythera.Session.Store.html#c:load/1","title":"Antikythera.Session.Store.load/1","type":"callback"},{"doc":"","ref":"Antikythera.Session.Store.html#c:save/2","title":"Antikythera.Session.Store.save/2","type":"callback"},{"doc":"","ref":"Antikythera.Session.Store.html#t:session_id/0","title":"Antikythera.Session.Store.session_id/0","type":"type"},{"doc":"","ref":"Antikythera.Session.Store.html#t:session_kv/0","title":"Antikythera.Session.Store.session_kv/0","type":"type"},{"doc":"","ref":"Antikythera.StringFormat.html","title":"Antikythera.StringFormat","type":"module"},{"doc":"","ref":"Antikythera.StringFormat.html#pad2/1","title":"Antikythera.StringFormat.pad2/1","type":"function"},{"doc":"","ref":"Antikythera.StringFormat.html#pad3/1","title":"Antikythera.StringFormat.pad3/1","type":"function"},{"doc":"Definition of macro to precompile HAML templates.Each gear's template module (web/template.ex) must use this module as follows:defmodule YourGear.Template do use Antikythera.TemplatePrecompiler endHAML files whose paths match web/template/**/*.html.haml are loaded and converted into function clauses at compile time. To render HAML files in controller actions, use Antikythera.Conn.render/5.As all macro-generated function clauses of content_for/2 reside in YourGear.Template, you can, for example, put alias before use Antikythera.TemplatePrecompiler so that it takes effect in all HAML templates.","ref":"Antikythera.TemplatePrecompiler.html","title":"Antikythera.TemplatePrecompiler","type":"module"},{"doc":"","ref":"Antikythera.TemplateSanitizer.html","title":"Antikythera.TemplateSanitizer","type":"module"},{"doc":"Converts special characters in the given string to character entity references.","ref":"Antikythera.TemplateSanitizer.html#html_escape/1","title":"Antikythera.TemplateSanitizer.html_escape/1","type":"function"},{"doc":"Marks data as HTML safe to avoid double-escaping.","ref":"Antikythera.TemplateSanitizer.html#raw/1","title":"Antikythera.TemplateSanitizer.raw/1","type":"function"},{"doc":"","ref":"Antikythera.TemplateSanitizer.html#t:safe/0","title":"Antikythera.TemplateSanitizer.safe/0","type":"type"},{"doc":"","ref":"Antikythera.TenantId.html","title":"Antikythera.TenantId","type":"module"},{"doc":"","ref":"Antikythera.TenantId.html#notenant/0","title":"Antikythera.TenantId.notenant/0","type":"function"},{"doc":"","ref":"Antikythera.TenantId.html#pattern/0","title":"Antikythera.TenantId.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.TenantId.html#valid?/1","title":"Antikythera.TenantId.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.TenantId.html#t:t/0","title":"Antikythera.TenantId.t/0","type":"type"},{"doc":"Utils for calculating the actual size of terms.These utils traverse terms and accumulate the size of terms including the actual size of binary.","ref":"Antikythera.TermUtil.html","title":"Antikythera.TermUtil","type":"module"},{"doc":"Returns the actual size of term in bytes.","ref":"Antikythera.TermUtil.html#size/1","title":"Antikythera.TermUtil.size/1","type":"function"},{"doc":"Returns whether actual size of term exceeds limit bytes.This is more efficient than deciding by using size/1 because this function returns immediately after exceeding limit, not traverses the entire term.","ref":"Antikythera.TermUtil.html#size_smaller_or_equal?/2","title":"Antikythera.TermUtil.size_smaller_or_equal?/2","type":"function"},{"doc":"Helpers for tests that target async jobs.","ref":"Antikythera.Test.AsyncJobHelper.html","title":"Antikythera.Test.AsyncJobHelper","type":"module"},{"doc":"Resets the token bucket that rate-limits accesses to the specified async job queue.This function is useful when you hit the rate limit in your tests. You can accelerate your test execution by resetting the token bucket. See Antikythera.AsyncJob for more details about rate limiting.","ref":"Antikythera.Test.AsyncJobHelper.html#reset_rate_limit_status/1","title":"Antikythera.Test.AsyncJobHelper.reset_rate_limit_status/1","type":"function"},{"doc":"Helpers to be used in each gear's test/test_helper.exs.At the top of test/test_helper.exs, all gears must place the following line:Antikythera.Test.Config.init()This line will start ExUnit and set configurations for whitebox/blackbox test mode.","ref":"Antikythera.Test.Config.html","title":"Antikythera.Test.Config","type":"module"},{"doc":"","ref":"Antikythera.Test.Config.html#base_url/0","title":"Antikythera.Test.Config.base_url/0","type":"function"},{"doc":"","ref":"Antikythera.Test.Config.html#blackbox_test?/0","title":"Antikythera.Test.Config.blackbox_test?/0","type":"function"},{"doc":"","ref":"Antikythera.Test.Config.html#blackbox_test_secret/0","title":"Antikythera.Test.Config.blackbox_test_secret/0","type":"function"},{"doc":"","ref":"Antikythera.Test.Config.html#init/0","title":"Antikythera.Test.Config.init/0","type":"function"},{"doc":"","ref":"Antikythera.Test.Config.html#test_mode/0","title":"Antikythera.Test.Config.test_mode/0","type":"function"},{"doc":"","ref":"Antikythera.Test.Config.html#whitebox_test_secret/0","title":"Antikythera.Test.Config.whitebox_test_secret/0","type":"function"},{"doc":"Helper functions to construct Antikythera.Conn object, to be used within tests.Typical controller tests are executed as follows:Make a Antikythera.Conn object.Pass the object to the target controller action.Inspect the returned Antikythera.Conn object.You can use make_conn/1 for the step-1 of the above procedure. In controller tests this module is auto-imported by use Antikythera.Test.ControllerTestCase.","ref":"Antikythera.Test.ConnHelper.html","title":"Antikythera.Test.ConnHelper","type":"module"},{"doc":"","ref":"Antikythera.Test.ConnHelper.html#make_conn/1","title":"Antikythera.Test.ConnHelper.make_conn/1","type":"function"},{"doc":"Helper functions to set gear configs from within gears' test code.","ref":"Antikythera.Test.GearConfigHelper.html","title":"Antikythera.Test.GearConfigHelper","type":"module"},{"doc":"","ref":"Antikythera.Test.GearConfigHelper.html#set_config/2","title":"Antikythera.Test.GearConfigHelper.set_config/2","type":"function"},{"doc":"Helpers to work with gear logs within tests.","ref":"Antikythera.Test.GearLogHelper.html","title":"Antikythera.Test.GearLogHelper","type":"module"},{"doc":"Sets a context ID (which is included in gear logs) to process dictionary so that logs can be emitted during test executions.If no argument is given, generates a new context ID and sets it.","ref":"Antikythera.Test.GearLogHelper.html#set_context_id/1","title":"Antikythera.Test.GearLogHelper.set_context_id/1","type":"function"},{"doc":"Helper functions to be used within tests for GenServers.","ref":"Antikythera.Test.GenServerHelper.html","title":"Antikythera.Test.GenServerHelper","type":"module"},{"doc":"","ref":"Antikythera.Test.GenServerHelper.html#receive_cast_message/0","title":"Antikythera.Test.GenServerHelper.receive_cast_message/0","type":"function"},{"doc":"","ref":"Antikythera.Test.GenServerHelper.html#send_message_and_wait/2","title":"Antikythera.Test.GenServerHelper.send_message_and_wait/2","type":"function"},{"doc":"","ref":"Antikythera.Test.HttpClient.html","title":"Antikythera.Test.HttpClient","type":"module"},{"doc":"Helper functions to work with processes in test code.","ref":"Antikythera.Test.ProcessHelper.html","title":"Antikythera.Test.ProcessHelper","type":"module"},{"doc":"","ref":"Antikythera.Test.ProcessHelper.html#flush/0","title":"Antikythera.Test.ProcessHelper.flush/0","type":"function"},{"doc":"","ref":"Antikythera.Test.ProcessHelper.html#monitor_wait/1","title":"Antikythera.Test.ProcessHelper.monitor_wait/1","type":"function"},{"doc":"Websocket client for gear tests.Prepare your client module with:defmodule YourGear.Socket do use Antikythera.Test.WebsocketClient endThen, call YourGear.Socket.spawn_link(&quot;/ws&quot;) to open Websocket connection at &quot;ws(s)://&lt;host_name&gt;/ws&quot; endpoint. It will return pid of Websocket connection handling process if successful.By default, it connects to the server specified by Antikythera.Test.Config.base_url/0, and redirects received frame to the caller (test running) process, in {frame, handler_pid} form.These default behavior can be overridable with two overridable functions:base_url/0handle_received_frame/2","ref":"Antikythera.Test.WebsocketClient.html","title":"Antikythera.Test.WebsocketClient","type":"module"},{"doc":"Data structure to represent date and time in milli-seconds resolution.Note that all values of Antikythera.Time.t are in UTC.Poison.Encoder protocol is implemented for Antikythera.Time.t, so that values of this type can be directly converted to Antikythera.IsoTimestamp.t on Poison.encode/1.iex&gt; Poison.encode(%{time: {Antikythera.Time, {2017, 1, 1}, {0, 0, 0}, 0}}) {:ok, &quot;{&quot;time&quot;:&quot;2017-01-01T00:00:00.000+00:00&quot;}&quot;}See also new/1.","ref":"Antikythera.Time.html","title":"Antikythera.Time","type":"module"},{"doc":"","ref":"Antikythera.Time.html#diff_milliseconds/2","title":"Antikythera.Time.diff_milliseconds/2","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_epoch_milliseconds/1","title":"Antikythera.Time.from_epoch_milliseconds/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_gregorian_milliseconds/1","title":"Antikythera.Time.from_gregorian_milliseconds/1","type":"function"},{"doc":"Parses HTTP-date formats into Antikythera.Time.t.Supports IMF-fixdate format, RFC 850 format and ANSI C's asctime() format for compatibility.Note: An HTTP-date value must represents time in UTC(GMT). Thus timezone string in the end must always be 'GMT'. Any other timezone string (such as 'JST') will actually be ignored and parsed as GMT.https://tools.ietf.org/html/rfc7231#section-7.1.1.1","ref":"Antikythera.Time.html#from_http_date/1","title":"Antikythera.Time.from_http_date/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_http_date!/1","title":"Antikythera.Time.from_http_date!/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_iso_basic/1","title":"Antikythera.Time.from_iso_basic/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_iso_basic!/1","title":"Antikythera.Time.from_iso_basic!/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_iso_timestamp/1","title":"Antikythera.Time.from_iso_timestamp/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#from_iso_timestamp!/1","title":"Antikythera.Time.from_iso_timestamp!/1","type":"function"},{"doc":"Convert timestamps into Antikythera.Time.t, leveraging recursive_new? option of Croma.Struct.Only Antikythera.IsoTimestamp.t can be converted.","ref":"Antikythera.Time.html#new/1","title":"Antikythera.Time.new/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#now/0","title":"Antikythera.Time.now/0","type":"function"},{"doc":"","ref":"Antikythera.Time.html#shift_days/2","title":"Antikythera.Time.shift_days/2","type":"function"},{"doc":"","ref":"Antikythera.Time.html#shift_hours/2","title":"Antikythera.Time.shift_hours/2","type":"function"},{"doc":"","ref":"Antikythera.Time.html#shift_milliseconds/2","title":"Antikythera.Time.shift_milliseconds/2","type":"function"},{"doc":"","ref":"Antikythera.Time.html#shift_minutes/2","title":"Antikythera.Time.shift_minutes/2","type":"function"},{"doc":"","ref":"Antikythera.Time.html#shift_seconds/2","title":"Antikythera.Time.shift_seconds/2","type":"function"},{"doc":"","ref":"Antikythera.Time.html#to_epoch_milliseconds/1","title":"Antikythera.Time.to_epoch_milliseconds/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#to_gregorian_milliseconds/1","title":"Antikythera.Time.to_gregorian_milliseconds/1","type":"function"},{"doc":"Returns date/time in IMF-fixdate format.The format is subset of Internet Message Format (RFC5322, formarly RFC822, RFC1123). Defined as 'preferred' format in RFC7231 and modern web servers or clients should send in this format.https://tools.ietf.org/html/rfc7231#section-7.1.1.1","ref":"Antikythera.Time.html#to_http_date/1","title":"Antikythera.Time.to_http_date/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#to_iso_basic/1","title":"Antikythera.Time.to_iso_basic/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#to_iso_timestamp/1","title":"Antikythera.Time.to_iso_timestamp/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#truncate_to_day/1","title":"Antikythera.Time.truncate_to_day/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#truncate_to_hour/1","title":"Antikythera.Time.truncate_to_hour/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#truncate_to_minute/1","title":"Antikythera.Time.truncate_to_minute/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#truncate_to_second/1","title":"Antikythera.Time.truncate_to_second/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#valid?/1","title":"Antikythera.Time.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Time.html#t:t/0","title":"Antikythera.Time.t/0","type":"type"},{"doc":"","ref":"Antikythera.Tmpdir.html","title":"Antikythera.Tmpdir","type":"module"},{"doc":"Creates a temporary directory which can be used as a working space for the passed function f.This function is basically intended for async jobs which processes large amount of data. For example, an async job that accumulates data into files and upload them to somewhere can utilize this function to obtain a temporary working space.The temporary directory is created before f is invoked. When execution of f is finished (either successfully or by exception) the directory is automatically removed. The function returns the return value of f.Nested calls to this function is not allowed. Instead you can freely make subdirectories of the temporary directory.ExampleAntikythera.Tmpdir.make(context, fn tmpdir -&gt; path = Path.join(tmpdir, &quot;foo&quot;) File.open(path, [:write], fn file -&gt; IO.write(file, &quot;some data 1&quot;) IO.write(file, &quot;some data 2&quot;) end) upload_to_object_storage_service(&quot;object_key&quot;, path) end)","ref":"Antikythera.Tmpdir.html#make/2","title":"Antikythera.Tmpdir.make/2","type":"function"},{"doc":"A thin wrapper around Foretoken to avoid collisions between bucket names by prefixing executor pool IDs.For details, refer to Foretoken's documentation.","ref":"Antikythera.TokenBucket.html","title":"Antikythera.TokenBucket","type":"module"},{"doc":"Takes the specified tokens from the bucket.Internally the actual bucket name is prefixed with the given epool_id. Note that return value on error is slightly different from that of Foretoken.take/5 (for backward compatibility).","ref":"Antikythera.TokenBucket.html#take/5","title":"Antikythera.TokenBucket.take/5","type":"function"},{"doc":"","ref":"Antikythera.UnencodedPath.html","title":"Antikythera.UnencodedPath","type":"module"},{"doc":"","ref":"Antikythera.UnencodedPath.html#pattern/0","title":"Antikythera.UnencodedPath.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.UnencodedPath.html#segment_charclass/0","title":"Antikythera.UnencodedPath.segment_charclass/0","type":"function"},{"doc":"","ref":"Antikythera.UnencodedPath.html#valid?/1","title":"Antikythera.UnencodedPath.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.UnencodedPath.html#t:t/0","title":"Antikythera.UnencodedPath.t/0","type":"type"},{"doc":"URL format, originally defined in RFC1738, and updated in RFC3986 as a subset of URI.Only accepts http or https as scheme.IPv4 addresses in URLs must be 4-part-dotted-decimal formats.e.g. 192.168.0.1See hereIPv6 addresses are not supported currently.","ref":"Antikythera.Url.html","title":"Antikythera.Url","type":"module"},{"doc":"","ref":"Antikythera.Url.html#pattern/0","title":"Antikythera.Url.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.Url.html#valid?/1","title":"Antikythera.Url.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Url.html#t:t/0","title":"Antikythera.Url.t/0","type":"type"},{"doc":"Format of versions of antikythera instances and gears.The format rule is a stricter variant of semantic versioning; pre-release part and build metadata part are filled with information from the current git commit (committer date and commit hash, respectively). This way we always make a new version for each new git commit, which enables both antikythera instances and gears to be deployed on a per-commit basis. The actual version strings are created by Antikythera.MixCommon.version_with_last_commit_info/1 defined in mix_common.exs file.Note that the current format prohibits multi-digits numbers as major/minor/patch version; this is just to simplify deployment and not an intrinsic limitation.","ref":"Antikythera.VersionStr.html","title":"Antikythera.VersionStr","type":"module"},{"doc":"","ref":"Antikythera.VersionStr.html#pattern/0","title":"Antikythera.VersionStr.pattern/0","type":"function"},{"doc":"","ref":"Antikythera.VersionStr.html#valid?/1","title":"Antikythera.VersionStr.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.VersionStr.html#t:t/0","title":"Antikythera.VersionStr.t/0","type":"type"},{"doc":"Functions to convert numeric values into human-readable strings.","ref":"Antikythera.View.Unit.html","title":"Antikythera.View.Unit","type":"module"},{"doc":"","ref":"Antikythera.View.Unit.html#bytes/1","title":"Antikythera.View.Unit.bytes/1","type":"function"},{"doc":"Behaviour module for websocket handlers.Note the naming convention of the websocket-related modules; we use Websocket, WebSocket is not allowed.Websocket module of gears must use this module as in the example below. use Antikythera.Websocket implicitly invokes use Antikythera.Controller, for convenience in implementing connect/1 callback.ExampleThe following example simply echoes back messages from client:defmodule MyGear.Websocket do use Antikythera.Websocket def init(_conn) do {%{}, []} end def handle_client_message(state, _conn, frame) do {state, [frame]} end def handle_server_message(state, _conn, _msg) do {state, []} end endName registrationOnce a websocket connection is established, subsequent bidirectional communication is handled by a dedicated connection process. To send websocket frames to the connected client, you should first be able to send messages to the connection process when a particular event occurs somewhere in the cluster. To this end antikythera provides a process registry mechanism which makes connection processes accessible by &quot;name&quot;s.To register connection processes, call Antikythera.Registry.Unique.register/2 and/or Antikythera.Registry.Group.join/2 in your init/1 implementation. Then, to notify events of connection processes, use Antikythera.Registry.Unique.send_message/3 or Antikythera.Registry.Group.publish/3. Finally to send websocket message from a connection process to client, implement handle_server_message/3 callback so that it returns an appropriate websocket frame using the message.See Antikythera.Registry.Unique and Antikythera.Registry.Group for more detail of the registry.","ref":"Antikythera.Websocket.html","title":"Antikythera.Websocket","type":"behaviour"},{"doc":"Callback function to be used during websocket handshake request.This callback is implemented in basically the same way as ordinary controller actions. You can use plugs and controller helper functions. The only difference is that on success this function returns a Antikythera.Conn.t without setting an HTTP status code.This callback is responsible for authenticating/authorizing the client. If the client is valid and it's OK to start websocket communication, implementation of this callback must return the given Antikythera.Conn.t. On the other hand if the client is not allowed to open websocket connection, this function must return an error as a usual HTTP response.use Antikythera.Websocket generates a default implementation of this callback, which just returns the given Antikythera.Conn.t. Note that you can use plugs without overriding the default.","ref":"Antikythera.Websocket.html#c:connect/1","title":"Antikythera.Websocket.connect/1","type":"callback"},{"doc":"Callback function to be called on receipt of a client message.","ref":"Antikythera.Websocket.html#c:handle_client_message/3","title":"Antikythera.Websocket.handle_client_message/3","type":"callback"},{"doc":"Callback function to be called on receipt of a message from other process in the cluster.","ref":"Antikythera.Websocket.html#c:handle_server_message/3","title":"Antikythera.Websocket.handle_server_message/3","type":"callback"},{"doc":"Callback function to be called right after a connection is established.This callback is responsible for:initialize the process state (1st element of return value)send initial message to client (2nd element of return value)register the process to make it accessible from other processes in the system (see &quot;Name registration&quot; above)","ref":"Antikythera.Websocket.html#c:init/1","title":"Antikythera.Websocket.init/1","type":"callback"},{"doc":"Callback function to clean up resources used by the websocket connection.For typical use cases you don't need to implement this callback; Antikythera.Websocket generates a default implementation (which does nothing) for you.","ref":"Antikythera.Websocket.html#c:terminate/3","title":"Antikythera.Websocket.terminate/3","type":"callback"},{"doc":"Type of return value of init/1, handle_client_message/3 and handle_server_message/3 callbacks. The 1st element of the return value is used as the new state. The 2nd element of the return value is sent to the client.To close the connection, include a :close frame in the 2nd element of the return value. Note that the remaining frames after the close frame will not be sent.","ref":"Antikythera.Websocket.html#t:callback_result/0","title":"Antikythera.Websocket.callback_result/0","type":"type"},{"doc":"","ref":"Antikythera.Websocket.html#t:state/0","title":"Antikythera.Websocket.state/0","type":"type"},{"doc":"","ref":"Antikythera.Websocket.html#t:terminate_reason/0","title":"Antikythera.Websocket.terminate_reason/0","type":"type"},{"doc":"Simplified data type for websocket frames.","ref":"Antikythera.Websocket.Frame.html","title":"Antikythera.Websocket.Frame","type":"module"},{"doc":"","ref":"Antikythera.Websocket.Frame.html#valid?/1","title":"Antikythera.Websocket.Frame.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Websocket.Frame.html#t:close_code/0","title":"Antikythera.Websocket.Frame.close_code/0","type":"type"},{"doc":"","ref":"Antikythera.Websocket.Frame.html#t:close_payload/0","title":"Antikythera.Websocket.Frame.close_payload/0","type":"type"},{"doc":"","ref":"Antikythera.Websocket.Frame.html#t:t/0","title":"Antikythera.Websocket.Frame.t/0","type":"type"},{"doc":"","ref":"Antikythera.Websocket.FrameList.html","title":"Antikythera.Websocket.FrameList","type":"module"},{"doc":"","ref":"Antikythera.Websocket.FrameList.html#valid?/1","title":"Antikythera.Websocket.FrameList.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Websocket.FrameList.html#t:t/0","title":"Antikythera.Websocket.FrameList.t/0","type":"type"},{"doc":"Convenient XML parser module wrapping fast_xml.decode/2 can parse XML into Antikythera.Xml.Element.t, and encode/2 can serialize Antikythera.Xml.Element.t back to XML string.Antikythera.Xml.Element.t is XML element data structure, and it is JSON-convertible struct. You can safely convert them to JSON using Poison.encode/2 while keeping order of appearance of children, and also convert them back to Antikythera.Xml.Element.t with Poison.decode/2 and Antikythera.Xml.Element.new/1.Note that order of attributes will not be preserved, since it is not significant. See hereNamespace of tags (e.g. &quot;ns&quot; in &lt;ns:tag&gt;) are kept as is in :name of elements.Namespace definitions (e.g. xmlns:ns='http://example.com/ns') are treated as plain attributes, and kept as is in :attributes of elements.Access behaviourAntikythera.Xml.Element implements Access behaviour for convenient lookups and updates. Following access patterns are available:element[:name], element[:attributes], element[:children]Fetch values of fields in dynamic lookup style.element[&quot;@some_attr&quot;]Fetch value of &quot;some_attr&quot; in :attributes map.element[:texts]Fetch text (character data) children. It always returns list.element[&quot;some_name&quot;]Fetch child elements with name: &quot;some_name&quot;. It always returns list.You can also use these patterns in Kernel.get_in/2 and its variants.iex&gt; xml = &quot;&lt;a&gt;foo&lt;b&gt;bar&lt;/b&gt;baz&lt;/a&gt;&quot; iex&gt; element = Antikythera.Xml.decode!(xml) %Antikythera.Xml.Element{name: &quot;a&quot;, attributes: %{}, children: [ &quot;foo&quot;, %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [&quot;bar&quot;]}, &quot;baz&quot;, ]} iex&gt; get_in(element, [:texts]) [&quot;foo&quot;, &quot;baz&quot;] iex&gt; get_in(element, [&quot;b&quot;, Access.at(0), :texts]) [&quot;bar&quot;] iex&gt; get_and_update_in(element, [:children, Access.at(0)], fn _ -&gt; :pop end) {&quot;foo&quot;, %Antikythera.Xml.Element{name: &quot;a&quot;, attributes: %{}, children: [ %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [&quot;bar&quot;]}, &quot;baz&quot;, ]}} iex&gt; update_in(element, [:children, Access.all()], fn ...&gt; text when is_binary(text) -&gt; %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [text]} ...&gt; e -&gt; e ...&gt; end) %Antikythera.Xml.Element{name: &quot;a&quot;, attributes: %{}, children: [ %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [&quot;foo&quot;]}, %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [&quot;bar&quot;]}, %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [&quot;baz&quot;]}, ]} iex&gt; update_in(element, [&quot;@id&quot;], fn _ -&gt; &quot;001&quot; end) %Antikythera.Xml.Element{name: &quot;a&quot;, attributes: %{&quot;id&quot; =&gt; &quot;001&quot;}, children: [ &quot;foo&quot;, %Antikythera.Xml.Element{name: &quot;b&quot;, attributes: %{}, children: [&quot;bar&quot;]}, &quot;baz&quot;, ]}Notes on updating with Kernel.get_and_update_in/3 and its variants:Struct fields are static and cannot be popped.Custom access keys except &quot;@some_attr&quot; cannot be used in updating. Use :children instead, in order to update children while preserving order of appearance.","ref":"Antikythera.Xml.html","title":"Antikythera.Xml","type":"module"},{"doc":"Reads an XML string and parses it into Antikythera.Xml.Element.t.Comments and header will be discarded.It can read XHTML document as long as they are well-formatted, though it does not understand Document Type Definition (DTD, header line with &quot;&lt;!DOCTYPE html PUBLIC ...&quot;), so you must remove them.It tries to read a document with UTF-8 encoding, regardless of &quot;encoding&quot; attribute in the header.Options::trim - Drop whitespace-only texts. Default false.There are no universal way to distinguish significant and insignificant whitespaces, so this option may alter the meaning of original document. Use with caution.In W3C recommendation, it is stated that whitespace texts (character data) are basically significant and must be preserved.","ref":"Antikythera.Xml.html#decode/2","title":"Antikythera.Xml.decode/2","type":"function"},{"doc":"","ref":"Antikythera.Xml.html#decode!/1","title":"Antikythera.Xml.decode!/1","type":"function"},{"doc":"","ref":"Antikythera.Xml.html#decode!/2","title":"Antikythera.Xml.decode!/2","type":"function"},{"doc":"Serializes Antikythera.Xml.Element.t into XML string.Specifications:Trailing newline will not be generated.All single- and double-quotations in attribute values or entity values are escaped to &amp;apos; and &amp;quot; respectively.All attribute values are SINGLE-quoted.Does not insert a whitespace before &quot;/&gt;&quot; in element without children.Options::pretty - Pretty print with 2-space indents. Default false.Similar to :trim option in decode/2, inserted whitespaces may be significant, thus it can alter meaning of original document. Use with caution.It does not insert whitespaces to elements with mixed-content and their descendants, in order to reduce probability to alter the meaning of original document.:with_header - Prepend &lt;?xml version='1.0' encoding='UTF-8'?&gt;\\n. Default false.","ref":"Antikythera.Xml.html#encode/2","title":"Antikythera.Xml.encode/2","type":"function"},{"doc":"","ref":"Antikythera.Xml.html#t:decode_option/0","title":"Antikythera.Xml.decode_option/0","type":"type"},{"doc":"","ref":"Antikythera.Xml.html#t:encode_option/0","title":"Antikythera.Xml.encode_option/0","type":"type"},{"doc":"","ref":"Antikythera.Xml.Content.html","title":"Antikythera.Xml.Content","type":"module"},{"doc":"","ref":"Antikythera.Xml.Content.html#new/1","title":"Antikythera.Xml.Content.new/1","type":"function"},{"doc":"","ref":"Antikythera.Xml.Content.html#valid?/1","title":"Antikythera.Xml.Content.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Xml.Content.html#t:t/0","title":"Antikythera.Xml.Content.t/0","type":"type"},{"doc":"","ref":"Antikythera.Xml.Element.html","title":"Antikythera.Xml.Element","type":"module"},{"doc":"Type-aware getter for attributes.","ref":"Antikythera.Xml.Element.html#attributes/1","title":"Antikythera.Xml.Element.attributes/1","type":"function"},{"doc":"Type-aware setter for attributes.","ref":"Antikythera.Xml.Element.html#attributes/2","title":"Antikythera.Xml.Element.attributes/2","type":"function"},{"doc":"Type-aware getter for children.","ref":"Antikythera.Xml.Element.html#children/1","title":"Antikythera.Xml.Element.children/1","type":"function"},{"doc":"Type-aware setter for children.","ref":"Antikythera.Xml.Element.html#children/2","title":"Antikythera.Xml.Element.children/2","type":"function"},{"doc":"Type-aware getter for name.","ref":"Antikythera.Xml.Element.html#name/1","title":"Antikythera.Xml.Element.name/1","type":"function"},{"doc":"Type-aware setter for name.","ref":"Antikythera.Xml.Element.html#name/2","title":"Antikythera.Xml.Element.name/2","type":"function"},{"doc":"Creates a new instance of Antikythera.Xml.Element by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"Antikythera.Xml.Element.html#new/1","title":"Antikythera.Xml.Element.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"Antikythera.Xml.Element.html#new!/1","title":"Antikythera.Xml.Element.new!/1","type":"function"},{"doc":"Updates an existing instance of Antikythera.Xml.Element with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"Antikythera.Xml.Element.html#update/2","title":"Antikythera.Xml.Element.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"Antikythera.Xml.Element.html#update!/2","title":"Antikythera.Xml.Element.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"Antikythera.Xml.Element.html#valid?/1","title":"Antikythera.Xml.Element.valid?/1","type":"function"},{"doc":"","ref":"Antikythera.Xml.Element.html#t:t/0","title":"Antikythera.Xml.Element.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.html","title":"AntikytheraCore","type":"module"},{"doc":"Callback implementation of Application.start/2.Interdependencies between initialization steps here are crucial. See also AntikytheraCore.StartupManager for initializations after construction of the supervision tree.","ref":"AntikytheraCore.html#start/2","title":"AntikytheraCore.start/2","type":"function"},{"doc":":gen_event callback module that reports number of errors to AntikytheraCore.ErrorCountsAccumulator process.This event handler module is installed in all AntikytheraCore.Alert.Manager processes. The received alerts are buffered for 60000 milliseconds and then reported in one batch.","ref":"AntikytheraCore.Alert.ErrorCountReporter.html","title":"AntikytheraCore.Alert.ErrorCountReporter","type":"module"},{"doc":"Behaviour module for alert handlers.Implementations must be prefixed with AntikytheraCore.Alert.Handler, e.g. AntikytheraCore.Alert.Handler.Email. This module also implements :gen_event behaviour and installed as handlers for AntikytheraCore.Alert.Manager processes. Each installed handlers will call callbacks of their corresponding implementation modules (references to those modules are held in handler states).A simple buffering/throttling mechanism is built in.Messages received by handlers will be sent out in &quot;fast-then-delayed&quot; pattern:Occasional messages will be flushed from the buffer and sent out in fast_interval.Messages arriving too frequently will be buffered for delayed_interval until they are sent out.By default, fast_interval is 60 seconds and delayed_interval is 1800 seconds.They can be customized via core/gear configs. Specify fast_interval or delayed_interval for the handler.Customization and installation of handlersThrough validate_config/1 callback, handler_config will be validated whether it includes sufficient information required for the implementation. If the validation passed, a handler, with a reference to the implementation module, will be installed for that OTP application. If the validation failed, the handler will not be installed, and will be uninstalled if it is installed already.This means, customization and installation are purely done via core/gear config.","ref":"AntikytheraCore.Alert.Handler.html","title":"AntikytheraCore.Alert.Handler","type":"behaviour"},{"doc":"Send alert(s) for messages in the buffer, using handler_config. Summarize messages if needed. Must return messages which could not be sent for whatever reason for retry. Oldest message comes first in messages, same goes for returned messages.Note: If the handler is trying to perform alerts which can take some time to finish (e.g. send email), consider dispatching them to a temporary process. In that case though, results of alerts cannot be received ([] should always be returned).","ref":"AntikytheraCore.Alert.Handler.html#c:send_alerts/3","title":"AntikytheraCore.Alert.Handler.send_alerts/3","type":"callback"},{"doc":"Validate handler_config whether it includes sufficient configurations for the handler. Return true when it is valid.","ref":"AntikytheraCore.Alert.Handler.html#c:validate_config/1","title":"AntikytheraCore.Alert.Handler.validate_config/1","type":"callback"},{"doc":"Alert handler implementation that sends an email.This is considered the default alert backend (and also used for testing of AntikytheraCore.Alert.Manager). Email delivery method is provided by a callback module of AntikytheraEal.AlertMailer.Behaviour.Handler configto - Required. List of email addresses to be sent. Must not be an empty list.errors_per_body - Optional. Integer number of errors printed in body of an alert mail. Details of errors beyond this threshold will be omitted. Defaults to 3.","ref":"AntikytheraCore.Alert.Handler.Email.html","title":"AntikytheraCore.Alert.Handler.Email","type":"module"},{"doc":"Type module for map of configurations for a single alert handler.Fields are treated as opaque at this layer; details are defined by each handler implementation.","ref":"AntikytheraCore.Alert.HandlerConfig.html","title":"AntikytheraCore.Alert.HandlerConfig","type":"module"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerConfig.html#get/2","title":"AntikytheraCore.Alert.HandlerConfig.get/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerConfig.html#valid?/1","title":"AntikytheraCore.Alert.HandlerConfig.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerConfig.html#t:t/0","title":"AntikytheraCore.Alert.HandlerConfig.t/0","type":"type"},{"doc":"Type module for map of all alert configurations for a single OTP application (antikythera or a gear).Keys must be snake-cased handler names and values must be maps of each alert handler's configurations. These maps are stored in core/gear configs.","ref":"AntikytheraCore.Alert.HandlerConfigsMap.html","title":"AntikytheraCore.Alert.HandlerConfigsMap","type":"module"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerConfigsMap.html#get/1","title":"AntikytheraCore.Alert.HandlerConfigsMap.get/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerConfigsMap.html#valid?/1","title":"AntikytheraCore.Alert.HandlerConfigsMap.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerConfigsMap.html#t:t/0","title":"AntikytheraCore.Alert.HandlerConfigsMap.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerState.html","title":"AntikytheraCore.Alert.HandlerState","type":"module"},{"doc":"Type-aware getter for busy?.","ref":"AntikytheraCore.Alert.HandlerState.html#busy?/1","title":"AntikytheraCore.Alert.HandlerState.busy?/1","type":"function"},{"doc":"Type-aware setter for busy?.","ref":"AntikytheraCore.Alert.HandlerState.html#busy?/2","title":"AntikytheraCore.Alert.HandlerState.busy?/2","type":"function"},{"doc":"Type-aware getter for handler_module.","ref":"AntikytheraCore.Alert.HandlerState.html#handler_module/1","title":"AntikytheraCore.Alert.HandlerState.handler_module/1","type":"function"},{"doc":"Type-aware setter for handler_module.","ref":"AntikytheraCore.Alert.HandlerState.html#handler_module/2","title":"AntikytheraCore.Alert.HandlerState.handler_module/2","type":"function"},{"doc":"Type-aware getter for message_buffer.","ref":"AntikytheraCore.Alert.HandlerState.html#message_buffer/1","title":"AntikytheraCore.Alert.HandlerState.message_buffer/1","type":"function"},{"doc":"Type-aware setter for message_buffer.","ref":"AntikytheraCore.Alert.HandlerState.html#message_buffer/2","title":"AntikytheraCore.Alert.HandlerState.message_buffer/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.Alert.HandlerState by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.Alert.HandlerState.html#new/1","title":"AntikytheraCore.Alert.HandlerState.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Alert.HandlerState.html#new!/1","title":"AntikytheraCore.Alert.HandlerState.new!/1","type":"function"},{"doc":"Type-aware getter for otp_app_name.","ref":"AntikytheraCore.Alert.HandlerState.html#otp_app_name/1","title":"AntikytheraCore.Alert.HandlerState.otp_app_name/1","type":"function"},{"doc":"Type-aware setter for otp_app_name.","ref":"AntikytheraCore.Alert.HandlerState.html#otp_app_name/2","title":"AntikytheraCore.Alert.HandlerState.otp_app_name/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.Alert.HandlerState with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.Alert.HandlerState.html#update/2","title":"AntikytheraCore.Alert.HandlerState.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Alert.HandlerState.html#update!/2","title":"AntikytheraCore.Alert.HandlerState.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.Alert.HandlerState.html#valid?/1","title":"AntikytheraCore.Alert.HandlerState.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.HandlerState.html#t:t/0","title":"AntikytheraCore.Alert.HandlerState.t/0","type":"type"},{"doc":"Backend handler for Logger, which notifies AntikytheraCore.Alert.Manager of error events.","ref":"AntikytheraCore.Alert.LoggerBackend.html","title":"AntikytheraCore.Alert.LoggerBackend","type":"module"},{"doc":"An event manager hosting multiple AntikytheraCore.Alert.Handlers.Managers are spawned per OTP application (antikythera and each gear). Each handler has its own buffer to store messages before sending them as an alert.","ref":"AntikytheraCore.Alert.Manager.html","title":"AntikytheraCore.Alert.Manager","type":"module"},{"doc":"","ref":"AntikytheraCore.Alert.Manager.html#child_spec/1","title":"AntikytheraCore.Alert.Manager.child_spec/1","type":"function"},{"doc":"Notify a manager process of a message body with optional time.","ref":"AntikytheraCore.Alert.Manager.html#notify/3","title":"AntikytheraCore.Alert.Manager.notify/3","type":"function"},{"doc":"Schedule next flushing from handlers. Assuming the interval is in seconds. Note that handlers are kept as state in gen_event manager process, thus calling self/0 always refers to the manager process which the handler is installed in.","ref":"AntikytheraCore.Alert.Manager.html#schedule_handler_timeout/2","title":"AntikytheraCore.Alert.Manager.schedule_handler_timeout/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.Manager.html#start_link/1","title":"AntikytheraCore.Alert.Manager.start_link/1","type":"function"},{"doc":"Update handler installations according to alert config of an OTP application (antikythera or gear). Handlers will be installed/uninstalled depending on contents of the config. If the config has sufficient information for a handler, it will be installed (noop if already installed). Otherwise, it will not be installed and will be uninstalled if it is already installed.Any errors will be logged but this function always returns :ok.","ref":"AntikytheraCore.Alert.Manager.html#update_handler_installations/2","title":"AntikytheraCore.Alert.Manager.update_handler_installations/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.Message.html","title":"AntikytheraCore.Alert.Message","type":"module"},{"doc":"","ref":"AntikytheraCore.Alert.Message.html#new/1","title":"AntikytheraCore.Alert.Message.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.Message.html#new!/1","title":"AntikytheraCore.Alert.Message.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.Message.html#valid?/1","title":"AntikytheraCore.Alert.Message.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Alert.Message.html#t:t/0","title":"AntikytheraCore.Alert.Message.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.html","title":"AntikytheraCore.AsyncJob","type":"module"},{"doc":"Type-aware getter for attempts.","ref":"AntikytheraCore.AsyncJob.html#attempts/1","title":"AntikytheraCore.AsyncJob.attempts/1","type":"function"},{"doc":"Type-aware setter for attempts.","ref":"AntikytheraCore.AsyncJob.html#attempts/2","title":"AntikytheraCore.AsyncJob.attempts/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.html#compute_retry_interval/1","title":"AntikytheraCore.AsyncJob.compute_retry_interval/1","type":"function"},{"doc":"Type-aware getter for gear_name.","ref":"AntikytheraCore.AsyncJob.html#gear_name/1","title":"AntikytheraCore.AsyncJob.gear_name/1","type":"function"},{"doc":"Type-aware setter for gear_name.","ref":"AntikytheraCore.AsyncJob.html#gear_name/2","title":"AntikytheraCore.AsyncJob.gear_name/2","type":"function"},{"doc":"Type-aware getter for max_duration.","ref":"AntikytheraCore.AsyncJob.html#max_duration/1","title":"AntikytheraCore.AsyncJob.max_duration/1","type":"function"},{"doc":"Type-aware setter for max_duration.","ref":"AntikytheraCore.AsyncJob.html#max_duration/2","title":"AntikytheraCore.AsyncJob.max_duration/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.html#max_start_time_from_now/0","title":"AntikytheraCore.AsyncJob.max_start_time_from_now/0","type":"function"},{"doc":"Type-aware getter for module.","ref":"AntikytheraCore.AsyncJob.html#module/1","title":"AntikytheraCore.AsyncJob.module/1","type":"function"},{"doc":"Type-aware setter for module.","ref":"AntikytheraCore.AsyncJob.html#module/2","title":"AntikytheraCore.AsyncJob.module/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.AsyncJob by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.AsyncJob.html#new/1","title":"AntikytheraCore.AsyncJob.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.AsyncJob.html#new!/1","title":"AntikytheraCore.AsyncJob.new!/1","type":"function"},{"doc":"Type-aware getter for payload.","ref":"AntikytheraCore.AsyncJob.html#payload/1","title":"AntikytheraCore.AsyncJob.payload/1","type":"function"},{"doc":"Type-aware setter for payload.","ref":"AntikytheraCore.AsyncJob.html#payload/2","title":"AntikytheraCore.AsyncJob.payload/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.html#register/5","title":"AntikytheraCore.AsyncJob.register/5","type":"function"},{"doc":"Type-aware getter for remaining_attempts.","ref":"AntikytheraCore.AsyncJob.html#remaining_attempts/1","title":"AntikytheraCore.AsyncJob.remaining_attempts/1","type":"function"},{"doc":"Type-aware setter for remaining_attempts.","ref":"AntikytheraCore.AsyncJob.html#remaining_attempts/2","title":"AntikytheraCore.AsyncJob.remaining_attempts/2","type":"function"},{"doc":"Type-aware getter for retry_interval.","ref":"AntikytheraCore.AsyncJob.html#retry_interval/1","title":"AntikytheraCore.AsyncJob.retry_interval/1","type":"function"},{"doc":"Type-aware setter for retry_interval.","ref":"AntikytheraCore.AsyncJob.html#retry_interval/2","title":"AntikytheraCore.AsyncJob.retry_interval/2","type":"function"},{"doc":"Type-aware getter for schedule.","ref":"AntikytheraCore.AsyncJob.html#schedule/1","title":"AntikytheraCore.AsyncJob.schedule/1","type":"function"},{"doc":"Type-aware setter for schedule.","ref":"AntikytheraCore.AsyncJob.html#schedule/2","title":"AntikytheraCore.AsyncJob.schedule/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.AsyncJob with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.AsyncJob.html#update/2","title":"AntikytheraCore.AsyncJob.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.AsyncJob.html#update!/2","title":"AntikytheraCore.AsyncJob.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.AsyncJob.html#valid?/1","title":"AntikytheraCore.AsyncJob.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.html#t:t/0","title":"AntikytheraCore.AsyncJob.t/0","type":"type"},{"doc":"A queue-like data structure, replicated using RaftedValue, to store AntikytheraCore.AsyncJob structs.","ref":"AntikytheraCore.AsyncJob.Queue.html","title":"AntikytheraCore.AsyncJob.Queue","type":"module"},{"doc":"Type-aware getter for abandoned_jobs.","ref":"AntikytheraCore.AsyncJob.Queue.html#abandoned_jobs/1","title":"AntikytheraCore.AsyncJob.Queue.abandoned_jobs/1","type":"function"},{"doc":"Type-aware setter for abandoned_jobs.","ref":"AntikytheraCore.AsyncJob.Queue.html#abandoned_jobs/2","title":"AntikytheraCore.AsyncJob.Queue.abandoned_jobs/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#add_job/5","title":"AntikytheraCore.AsyncJob.Queue.add_job/5","type":"function"},{"doc":"Type-aware getter for brokers_to_notify.","ref":"AntikytheraCore.AsyncJob.Queue.html#brokers_to_notify/1","title":"AntikytheraCore.AsyncJob.Queue.brokers_to_notify/1","type":"function"},{"doc":"Type-aware setter for brokers_to_notify.","ref":"AntikytheraCore.AsyncJob.Queue.html#brokers_to_notify/2","title":"AntikytheraCore.AsyncJob.Queue.brokers_to_notify/2","type":"function"},{"doc":"Type-aware getter for brokers_waiting.","ref":"AntikytheraCore.AsyncJob.Queue.html#brokers_waiting/1","title":"AntikytheraCore.AsyncJob.Queue.brokers_waiting/1","type":"function"},{"doc":"Type-aware setter for brokers_waiting.","ref":"AntikytheraCore.AsyncJob.Queue.html#brokers_waiting/2","title":"AntikytheraCore.AsyncJob.Queue.brokers_waiting/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#cancel/2","title":"AntikytheraCore.AsyncJob.Queue.cancel/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#fetch_job/1","title":"AntikytheraCore.AsyncJob.Queue.fetch_job/1","type":"function"},{"doc":"Type-aware getter for index_runnable.","ref":"AntikytheraCore.AsyncJob.Queue.html#index_runnable/1","title":"AntikytheraCore.AsyncJob.Queue.index_runnable/1","type":"function"},{"doc":"Type-aware setter for index_runnable.","ref":"AntikytheraCore.AsyncJob.Queue.html#index_runnable/2","title":"AntikytheraCore.AsyncJob.Queue.index_runnable/2","type":"function"},{"doc":"Type-aware getter for index_running.","ref":"AntikytheraCore.AsyncJob.Queue.html#index_running/1","title":"AntikytheraCore.AsyncJob.Queue.index_running/1","type":"function"},{"doc":"Type-aware setter for index_running.","ref":"AntikytheraCore.AsyncJob.Queue.html#index_running/2","title":"AntikytheraCore.AsyncJob.Queue.index_running/2","type":"function"},{"doc":"Type-aware getter for index_waiting.","ref":"AntikytheraCore.AsyncJob.Queue.html#index_waiting/1","title":"AntikytheraCore.AsyncJob.Queue.index_waiting/1","type":"function"},{"doc":"Type-aware setter for index_waiting.","ref":"AntikytheraCore.AsyncJob.Queue.html#index_waiting/2","title":"AntikytheraCore.AsyncJob.Queue.index_waiting/2","type":"function"},{"doc":"Type-aware getter for jobs.","ref":"AntikytheraCore.AsyncJob.Queue.html#jobs/1","title":"AntikytheraCore.AsyncJob.Queue.jobs/1","type":"function"},{"doc":"Type-aware setter for jobs.","ref":"AntikytheraCore.AsyncJob.Queue.html#jobs/2","title":"AntikytheraCore.AsyncJob.Queue.jobs/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#list/1","title":"AntikytheraCore.AsyncJob.Queue.list/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#make_rv_config/1","title":"AntikytheraCore.AsyncJob.Queue.make_rv_config/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#max_jobs/0","title":"AntikytheraCore.AsyncJob.Queue.max_jobs/0","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.AsyncJob.Queue by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.AsyncJob.Queue.html#new/1","title":"AntikytheraCore.AsyncJob.Queue.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.AsyncJob.Queue.html#new!/1","title":"AntikytheraCore.AsyncJob.Queue.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#remove_broker_from_waiting_list/1","title":"AntikytheraCore.AsyncJob.Queue.remove_broker_from_waiting_list/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#remove_locked_job/2","title":"AntikytheraCore.AsyncJob.Queue.remove_locked_job/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#start_jobs_and_get_metrics/1","title":"AntikytheraCore.AsyncJob.Queue.start_jobs_and_get_metrics/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#status/2","title":"AntikytheraCore.AsyncJob.Queue.status/2","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#unlock_job_for_retry/2","title":"AntikytheraCore.AsyncJob.Queue.unlock_job_for_retry/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.AsyncJob.Queue with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.AsyncJob.Queue.html#update/2","title":"AntikytheraCore.AsyncJob.Queue.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.AsyncJob.Queue.html#update!/2","title":"AntikytheraCore.AsyncJob.Queue.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.AsyncJob.Queue.html#valid?/1","title":"AntikytheraCore.AsyncJob.Queue.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.html#t:t/0","title":"AntikytheraCore.AsyncJob.Queue.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.Hook.html","title":"AntikytheraCore.AsyncJob.Queue.Hook","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.IdJobPair.html","title":"AntikytheraCore.AsyncJob.Queue.IdJobPair","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.IdJobPair.html#new/1","title":"AntikytheraCore.AsyncJob.Queue.IdJobPair.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.IdJobPair.html#new!/1","title":"AntikytheraCore.AsyncJob.Queue.IdJobPair.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.IdJobPair.html#valid?/1","title":"AntikytheraCore.AsyncJob.Queue.IdJobPair.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.IdJobPair.html#t:t/0","title":"AntikytheraCore.AsyncJob.Queue.IdJobPair.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobKey.html","title":"AntikytheraCore.AsyncJob.Queue.JobKey","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobKey.html#valid?/1","title":"AntikytheraCore.AsyncJob.Queue.JobKey.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobKey.html#t:t/0","title":"AntikytheraCore.AsyncJob.Queue.JobKey.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.html","title":"AntikytheraCore.AsyncJob.Queue.JobsMap","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.html#new/1","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.html#new!/1","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.html#valid?/1","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.html#t:t/0","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.html","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.html#new/1","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.html#new!/1","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.html#valid?/1","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.html#t:t/0","title":"AntikytheraCore.AsyncJob.Queue.JobsMap.Triplet.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.SecondaryIndex.html","title":"AntikytheraCore.AsyncJob.Queue.SecondaryIndex","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.SecondaryIndex.html#valid?/1","title":"AntikytheraCore.AsyncJob.Queue.SecondaryIndex.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.Queue.SecondaryIndex.html#t:t/0","title":"AntikytheraCore.AsyncJob.Queue.SecondaryIndex.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RaftPerMemberOptionsMaker.html","title":"AntikytheraCore.AsyncJob.RaftPerMemberOptionsMaker","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RaftedValueConfigMaker.html","title":"AntikytheraCore.AsyncJob.RaftedValueConfigMaker","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RaftedValueConfigMaker.html#options/0","title":"AntikytheraCore.AsyncJob.RaftedValueConfigMaker.options/0","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RateLimit.html","title":"AntikytheraCore.AsyncJob.RateLimit","type":"module"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RateLimit.html#check_for_command/1","title":"AntikytheraCore.AsyncJob.RateLimit.check_for_command/1","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RateLimit.html#check_with_retry_for_query/3","title":"AntikytheraCore.AsyncJob.RateLimit.check_with_retry_for_query/3","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RateLimit.html#max_tokens/0","title":"AntikytheraCore.AsyncJob.RateLimit.max_tokens/0","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RateLimit.html#milliseconds_per_token/0","title":"AntikytheraCore.AsyncJob.RateLimit.milliseconds_per_token/0","type":"function"},{"doc":"","ref":"AntikytheraCore.AsyncJob.RateLimit.html#tokens_per_command/0","title":"AntikytheraCore.AsyncJob.RateLimit.tokens_per_command/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Cluster.html","title":"AntikytheraCore.Cluster","type":"module"},{"doc":"","ref":"AntikytheraCore.Cluster.html#connect_to_other_nodes/1","title":"AntikytheraCore.Cluster.connect_to_other_nodes/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Cluster.html#connect_to_other_nodes_on_start/0","title":"AntikytheraCore.Cluster.connect_to_other_nodes_on_start/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Cluster.html#node_to_host/1","title":"AntikytheraCore.Cluster.node_to_host/1","type":"function"},{"doc":"ID of instance that is visible to gear developers.Note that the ID string here uses short hostname (hostname -s) instead of fully-qualified one (hostname -f) in order to make it short by truncating common parts.","ref":"AntikytheraCore.Cluster.NodeId.html","title":"AntikytheraCore.Cluster.NodeId","type":"module"},{"doc":"","ref":"AntikytheraCore.Cluster.NodeId.html#get/0","title":"AntikytheraCore.Cluster.NodeId.get/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Cluster.NodeId.html#init/0","title":"AntikytheraCore.Cluster.NodeId.init/0","type":"function"},{"doc":"A GenServer that periodically fetches current members of the cluster (all existing hostnames and their lifecycle states) from underlying infrastructure.In rare occasions fetching hosts information may take longer than 5 seconds; we spawn dedicated process in order to keep this GenServer responsive to calls from other processes.","ref":"AntikytheraCore.ClusterHostsPoller.html","title":"AntikytheraCore.ClusterHostsPoller","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ClusterHostsPoller.html#child_spec/1","title":"AntikytheraCore.ClusterHostsPoller.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ClusterHostsPoller.html#current_hosts/0","title":"AntikytheraCore.ClusterHostsPoller.current_hosts/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ClusterHostsPoller.html#start_link/1","title":"AntikytheraCore.ClusterHostsPoller.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ClusterHostsPoller.Fetcher.html","title":"AntikytheraCore.ClusterHostsPoller.Fetcher","type":"module"},{"doc":"","ref":"AntikytheraCore.ClusterHostsPoller.Fetcher.html#run/0","title":"AntikytheraCore.ClusterHostsPoller.Fetcher.run/0","type":"function"},{"doc":"A GenServer that tries to keep connections to other known nodes.Depends on AntikytheraCore.ClusterHostsPoller.","ref":"AntikytheraCore.ClusterNodesConnector.html","title":"AntikytheraCore.ClusterNodesConnector","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ClusterNodesConnector.html#child_spec/1","title":"AntikytheraCore.ClusterNodesConnector.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ClusterNodesConnector.html#start_link/1","title":"AntikytheraCore.ClusterNodesConnector.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Cmd.html","title":"AntikytheraCore.Cmd","type":"module"},{"doc":"","ref":"AntikytheraCore.Cmd.html#hostname/0","title":"AntikytheraCore.Cmd.hostname/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Core.html","title":"AntikytheraCore.Config.Core","type":"module"},{"doc":"","ref":"AntikytheraCore.Config.Core.html#dump_from_env_to_file/0","title":"AntikytheraCore.Config.Core.dump_from_env_to_file/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Core.html#load/1","title":"AntikytheraCore.Config.Core.load/1","type":"function"},{"doc":"Writes a map to antikythera's config file.Currently this function is intended to be used within remote_console.","ref":"AntikytheraCore.Config.Core.html#write/1","title":"AntikytheraCore.Config.Core.write/1","type":"function"},{"doc":"Utility functions to handle secret key which is used to encrypt/decrypt config files.","ref":"AntikytheraCore.Config.EncryptionKey.html","title":"AntikytheraCore.Config.EncryptionKey","type":"module"},{"doc":"","ref":"AntikytheraCore.Config.EncryptionKey.html#get/0","title":"AntikytheraCore.Config.EncryptionKey.get/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.EncryptionKey.html#init/0","title":"AntikytheraCore.Config.EncryptionKey.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.EncryptionKey.html#t:t/0","title":"AntikytheraCore.Config.EncryptionKey.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html","title":"AntikytheraCore.Config.Gear","type":"module"},{"doc":"Type-aware getter for alerts.","ref":"AntikytheraCore.Config.Gear.html#alerts/1","title":"AntikytheraCore.Config.Gear.alerts/1","type":"function"},{"doc":"Type-aware setter for alerts.","ref":"AntikytheraCore.Config.Gear.html#alerts/2","title":"AntikytheraCore.Config.Gear.alerts/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#default/0","title":"AntikytheraCore.Config.Gear.default/0","type":"function"},{"doc":"Type-aware getter for domains.","ref":"AntikytheraCore.Config.Gear.html#domains/1","title":"AntikytheraCore.Config.Gear.domains/1","type":"function"},{"doc":"Type-aware setter for domains.","ref":"AntikytheraCore.Config.Gear.html#domains/2","title":"AntikytheraCore.Config.Gear.domains/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#dump_all_from_env_to_file/0","title":"AntikytheraCore.Config.Gear.dump_all_from_env_to_file/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#ensure_loaded/1","title":"AntikytheraCore.Config.Gear.ensure_loaded/1","type":"function"},{"doc":"Type-aware getter for kv.","ref":"AntikytheraCore.Config.Gear.html#kv/1","title":"AntikytheraCore.Config.Gear.kv/1","type":"function"},{"doc":"Type-aware setter for kv.","ref":"AntikytheraCore.Config.Gear.html#kv/2","title":"AntikytheraCore.Config.Gear.kv/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#load_all/1","title":"AntikytheraCore.Config.Gear.load_all/1","type":"function"},{"doc":"Type-aware getter for log_level.","ref":"AntikytheraCore.Config.Gear.html#log_level/1","title":"AntikytheraCore.Config.Gear.log_level/1","type":"function"},{"doc":"Type-aware setter for log_level.","ref":"AntikytheraCore.Config.Gear.html#log_level/2","title":"AntikytheraCore.Config.Gear.log_level/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.Config.Gear by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.Config.Gear.html#new/1","title":"AntikytheraCore.Config.Gear.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Config.Gear.html#new!/1","title":"AntikytheraCore.Config.Gear.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#read/1","title":"AntikytheraCore.Config.Gear.read/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#read_all/0","title":"AntikytheraCore.Config.Gear.read_all/0","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.Config.Gear with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.Config.Gear.html#update/2","title":"AntikytheraCore.Config.Gear.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Config.Gear.html#update!/2","title":"AntikytheraCore.Config.Gear.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.Config.Gear.html#valid?/1","title":"AntikytheraCore.Config.Gear.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#write/2","title":"AntikytheraCore.Config.Gear.write/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Config.Gear.html#t:t/0","title":"AntikytheraCore.Config.Gear.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Conn.html","title":"AntikytheraCore.Conn","type":"module"},{"doc":"","ref":"AntikytheraCore.Conn.html#gear_name/1","title":"AntikytheraCore.Conn.gear_name/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Conn.html#make_from_cowboy_req/4","title":"AntikytheraCore.Conn.make_from_cowboy_req/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Conn.html#make_from_g2g_req_and_context/6","title":"AntikytheraCore.Conn.make_from_g2g_req_and_context/6","type":"function"},{"doc":"","ref":"AntikytheraCore.Conn.html#reply_as_cowboy_res/2","title":"AntikytheraCore.Conn.reply_as_cowboy_res/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Conn.html#reply_as_g2g_res/1","title":"AntikytheraCore.Conn.reply_as_g2g_res/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Conn.html#request_info/1","title":"AntikytheraCore.Conn.request_info/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Conn.html#run_before_send/2","title":"AntikytheraCore.Conn.run_before_send/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Context.html","title":"AntikytheraCore.Context","type":"module"},{"doc":"","ref":"AntikytheraCore.Context.html#make/4","title":"AntikytheraCore.Context.make/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Context.html#make_context_id/1","title":"AntikytheraCore.Context.make_context_id/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Context.html#make_context_id/2","title":"AntikytheraCore.Context.make_context_id/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Cookies.html","title":"AntikytheraCore.Cookies","type":"module"},{"doc":"","ref":"AntikytheraCore.Cookies.html#make_from_cowboy_req/1","title":"AntikytheraCore.Cookies.make_from_cowboy_req/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Cookies.html#merge_cookies_to_cowboy_req/2","title":"AntikytheraCore.Cookies.merge_cookies_to_cowboy_req/2","type":"function"},{"doc":"Periodically polls antikythera's config file and apply changes to the cache (in ETS table).Note that core config is loaded in AntikytheraCore.start/2 and thus this GenServer's responsibility is to keep up with the latest changes.","ref":"AntikytheraCore.CoreConfigPoller.html","title":"AntikytheraCore.CoreConfigPoller","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.CoreConfigPoller.html#child_spec/1","title":"AntikytheraCore.CoreConfigPoller.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.CoreConfigPoller.html#start_link/1","title":"AntikytheraCore.CoreConfigPoller.start_link/1","type":"function"},{"doc":"Translator for Logger, installed via application config.Most of translations are delegated to Logger.Translator; this translator neglects messages of the following types:SASL progress reporterror log emitted by syn about mnesia down event (when a node in the cluster is terminated)supervisor report on brutal kill of a worker process in PoolSup (when a too-long-running worker is stopped)","ref":"AntikytheraCore.ErlangLogTranslator.html","title":"AntikytheraCore.ErlangLogTranslator","type":"module"},{"doc":"","ref":"AntikytheraCore.ErlangLogTranslator.html#translate/4","title":"AntikytheraCore.ErlangLogTranslator.translate/4","type":"function"},{"doc":"A GenServer to hold number of errors reported to each OTP application's alert manager process (implemented by AntikytheraCore.Alert.Manager).Error counts are reported by AntikytheraCore.Alert.ErrorCountReporter installed in AntikytheraCore.Alert.Manager. The received error counts are stored with otp_app_name and the timestamp (in minute). Error counts accumulated in this GenServer can be fetched via HTTP: see AntikytheraCore.Handler.SystemInfoExporter.ErrorCount.At the beginning of each minute,newly-received error counts become visible from get/1 and get_total/0, anderror counts having too old timestamps are cleaned up from the process state.","ref":"AntikytheraCore.ErrorCountsAccumulator.html","title":"AntikytheraCore.ErrorCountsAccumulator","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ErrorCountsAccumulator.html#child_spec/1","title":"AntikytheraCore.ErrorCountsAccumulator.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.html#get/1","title":"AntikytheraCore.ErrorCountsAccumulator.get/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.html#get_total/0","title":"AntikytheraCore.ErrorCountsAccumulator.get_total/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.html#start_link/1","title":"AntikytheraCore.ErrorCountsAccumulator.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.html#submit/2","title":"AntikytheraCore.ErrorCountsAccumulator.submit/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.html#t:results/0","title":"AntikytheraCore.ErrorCountsAccumulator.results/0","type":"type"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html","title":"AntikytheraCore.ErrorCountsAccumulator.State","type":"module"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#add/3","title":"AntikytheraCore.ErrorCountsAccumulator.State.add/3","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#advance_to_next_minute/2","title":"AntikytheraCore.ErrorCountsAccumulator.State.advance_to_next_minute/2","type":"function"},{"doc":"Type-aware getter for counts.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#counts/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.counts/1","type":"function"},{"doc":"Type-aware setter for counts.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#counts/2","title":"AntikytheraCore.ErrorCountsAccumulator.State.counts/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#get/2","title":"AntikytheraCore.ErrorCountsAccumulator.State.get/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#get_total/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.get_total/1","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.ErrorCountsAccumulator.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#new/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#new!/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.new!/1","type":"function"},{"doc":"Type-aware getter for now_minute.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#now_minute/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.now_minute/1","type":"function"},{"doc":"Type-aware setter for now_minute.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#now_minute/2","title":"AntikytheraCore.ErrorCountsAccumulator.State.now_minute/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.ErrorCountsAccumulator.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#update/2","title":"AntikytheraCore.ErrorCountsAccumulator.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#update!/2","title":"AntikytheraCore.ErrorCountsAccumulator.State.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#valid?/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#t:results/0","title":"AntikytheraCore.ErrorCountsAccumulator.State.results/0","type":"type"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.html#t:t/0","title":"AntikytheraCore.ErrorCountsAccumulator.State.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.html","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute","type":"module"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.html#new/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.html#new!/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.html#valid?/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.html#t:t/0","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinute.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.html","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp","type":"module"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.html#new/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.html#new!/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.html#valid?/1","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.html#t:t/0","title":"AntikytheraCore.ErrorCountsAccumulator.State.CountByMinuteByApp.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Ets.html","title":"AntikytheraCore.Ets","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.html#create_read_optimized_table/1","title":"AntikytheraCore.Ets.create_read_optimized_table/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.html#init_all/0","title":"AntikytheraCore.Ets.init_all/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.html","title":"AntikytheraCore.Ets.ConfigCache","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.html#init/0","title":"AntikytheraCore.Ets.ConfigCache.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.html#table_name/0","title":"AntikytheraCore.Ets.ConfigCache.table_name/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.Core.html","title":"AntikytheraCore.Ets.ConfigCache.Core","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.Core.html#read/0","title":"AntikytheraCore.Ets.ConfigCache.Core.read/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.Core.html#write/1","title":"AntikytheraCore.Ets.ConfigCache.Core.write/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.Gear.html","title":"AntikytheraCore.Ets.ConfigCache.Gear","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.Gear.html#read/1","title":"AntikytheraCore.Ets.ConfigCache.Gear.read/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.ConfigCache.Gear.html#write/2","title":"AntikytheraCore.Ets.ConfigCache.Gear.write/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.GearActionRunnerPools.html","title":"AntikytheraCore.Ets.GearActionRunnerPools","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.GearActionRunnerPools.html#init/0","title":"AntikytheraCore.Ets.GearActionRunnerPools.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.GearActionRunnerPools.html#table_name/0","title":"AntikytheraCore.Ets.GearActionRunnerPools.table_name/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.Memcache.html","title":"AntikytheraCore.Ets.Memcache","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.Memcache.html#delete/2","title":"AntikytheraCore.Ets.Memcache.delete/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.Memcache.html#init/0","title":"AntikytheraCore.Ets.Memcache.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.Memcache.html#read/2","title":"AntikytheraCore.Ets.Memcache.read/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.Memcache.html#table_name/0","title":"AntikytheraCore.Ets.Memcache.table_name/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.Memcache.html#write/5","title":"AntikytheraCore.Ets.Memcache.write/5","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.SystemCache.html","title":"AntikytheraCore.Ets.SystemCache","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.SystemCache.html#init/0","title":"AntikytheraCore.Ets.SystemCache.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.SystemCache.html#table_name/0","title":"AntikytheraCore.Ets.SystemCache.table_name/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.TenantToGearsMapping.html","title":"AntikytheraCore.Ets.TenantToGearsMapping","type":"module"},{"doc":"","ref":"AntikytheraCore.Ets.TenantToGearsMapping.html#associated?/2","title":"AntikytheraCore.Ets.TenantToGearsMapping.associated?/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.TenantToGearsMapping.html#init/0","title":"AntikytheraCore.Ets.TenantToGearsMapping.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.TenantToGearsMapping.html#set/2","title":"AntikytheraCore.Ets.TenantToGearsMapping.set/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.TenantToGearsMapping.html#table_name/0","title":"AntikytheraCore.Ets.TenantToGearsMapping.table_name/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Ets.TenantToGearsMapping.html#unset/1","title":"AntikytheraCore.Ets.TenantToGearsMapping.unset/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html","title":"AntikytheraCore.ExecutorPool","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html#apply_setting/2","title":"AntikytheraCore.ExecutorPool.apply_setting/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html#kill_executor_pool/1","title":"AntikytheraCore.ExecutorPool.kill_executor_pool/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html#start_executor_pool/2","title":"AntikytheraCore.ExecutorPool.start_executor_pool/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html#start_link/3","title":"AntikytheraCore.ExecutorPool.start_link/3","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.html#start_per_gear_executor_pool/1","title":"AntikytheraCore.ExecutorPool.start_per_gear_executor_pool/1","type":"function"},{"doc":"A GenServer (whose lifecycle is managed by PoolSup.Multi) that executes gears' controller actions.","ref":"AntikytheraCore.ExecutorPool.ActionRunner.html","title":"AntikytheraCore.ExecutorPool.ActionRunner","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.ActionRunner.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.ActionRunner.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.ActionRunner.html#run/3","title":"AntikytheraCore.ExecutorPool.ActionRunner.run/3","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.ActionRunner.html#start_link/1","title":"AntikytheraCore.ExecutorPool.ActionRunner.start_link/1","type":"function"},{"doc":"A broker that finds a pair of &quot;a runnable job in job queue&quot; and &quot;an available AsyncJobRunner process in worker pool&quot;.This GenServer becomes :active when both antikythera and the job queue for the same executor pool are ready. When entering :active phase it notifies AntikytheraCore.TerminationManager of the pid so that it will be notified afterward. Before host termination it becomes :inactive on receipt of a message from AntikytheraCore.TerminationManager; from then on it won't start new jobs.During :active phase it checks out a process from the async job worker pool of the same executor pool, fetches a job from the job queue, and tells the process to run the job.Communications between broker and job queue are basically event-driven, i.e., no polling mechanism is needed for them to work, most of the time. However, in rare occasions, messages between them may be lost due to e.g. failure of majority members in the job queue's consensus group. Therefore we also use periodic polling to recover from this kind of troubles.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.html","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.html#deactivate/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.deactivate/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.html#notify_job_registered/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.notify_job_registered/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.html#notify_pool_capacity_may_have_changed/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.notify_pool_capacity_may_have_changed/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.html#start_link/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.html","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.html#new/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.html#new!/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.html#valid?/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.html#values/0","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.values/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.html#t:t/0","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.Phase.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State","type":"module"},{"doc":"Creates a new instance of AntikytheraCore.ExecutorPool.AsyncJobBroker.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#new/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#new!/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.new!/1","type":"function"},{"doc":"Type-aware getter for phase.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#phase/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.phase/1","type":"function"},{"doc":"Type-aware setter for phase.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#phase/2","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.phase/2","type":"function"},{"doc":"Type-aware getter for pool_name.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#pool_name/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.pool_name/1","type":"function"},{"doc":"Type-aware setter for pool_name.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#pool_name/2","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.pool_name/2","type":"function"},{"doc":"Type-aware getter for queue_name.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#queue_name/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.queue_name/1","type":"function"},{"doc":"Type-aware setter for queue_name.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#queue_name/2","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.queue_name/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.ExecutorPool.AsyncJobBroker.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#update/2","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#update!/2","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#valid?/1","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.html#t:t/0","title":"AntikytheraCore.ExecutorPool.AsyncJobBroker.State.t/0","type":"type"},{"doc":"A GenServer for logging, which is used in AntikytheraCore.ExecutorPool.AsyncJobRunner.","ref":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.html","title":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.html#info/1","title":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.info/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.html#start_link/1","title":"AntikytheraCore.ExecutorPool.AsyncJobLog.Writer.start_link/1","type":"function"},{"doc":"An ephemeral GenServer process under PoolSup that manages an execution of an async job.Actual execution of gear's code is done within a separate process for the following reasons:for cleaner error handlingto introduce timeout of job executionto be responsive to system messagesWhen the separate process terminates, this GenServer updates/deletes the locked job in the queue depending on the result of the execution.Note that when no job is registered in the job queue, successfully checked-out process is immediately checked in. See implementation of AntikytheraCore.ExecutorPool.AsyncJobBroker.","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html#abandon_callback_max_duration/0","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner.abandon_callback_max_duration/0","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html#do_abandon/4","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner.do_abandon/4","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html#do_run/4","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner.do_run/4","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html#run/4","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner.run/4","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.AsyncJobRunner.html#start_link/1","title":"AntikytheraCore.ExecutorPool.AsyncJobRunner.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Id.html","title":"AntikytheraCore.ExecutorPool.Id","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Id.html#validate_association/2","title":"AntikytheraCore.ExecutorPool.Id.validate_association/2","type":"function"},{"doc":"A GenServer to manage memcache for each executor pool.","ref":"AntikytheraCore.ExecutorPool.MemcacheWriter.html","title":"AntikytheraCore.ExecutorPool.MemcacheWriter","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.MemcacheWriter.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.MemcacheWriter.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.MemcacheWriter.html#max_records/0","title":"AntikytheraCore.ExecutorPool.MemcacheWriter.max_records/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.MemcacheWriter.html#start_link/1","title":"AntikytheraCore.ExecutorPool.MemcacheWriter.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.MemcacheWriter.html#write/5","title":"AntikytheraCore.ExecutorPool.MemcacheWriter.write/5","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html","title":"AntikytheraCore.ExecutorPool.RegisteredName","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#action_runner_pool_multi/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.action_runner_pool_multi/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#action_runner_pool_multi_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.action_runner_pool_multi_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#async_job_broker/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.async_job_broker/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#async_job_broker_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.async_job_broker_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#async_job_queue/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.async_job_queue/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#async_job_queue_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.async_job_queue_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#async_job_runner_pool/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.async_job_runner_pool/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#async_job_runner_pool_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.async_job_runner_pool_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#memcache_writer/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.memcache_writer/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#memcache_writer_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.memcache_writer_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#supervisor/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.supervisor/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#supervisor_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.supervisor_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#websocket_connections_counter/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.websocket_connections_counter/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.RegisteredName.html#websocket_connections_counter_unsafe/1","title":"AntikytheraCore.ExecutorPool.RegisteredName.websocket_connections_counter_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Setting.html","title":"AntikytheraCore.ExecutorPool.Setting","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Setting.html#all/0","title":"AntikytheraCore.ExecutorPool.Setting.all/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Setting.html#default/0","title":"AntikytheraCore.ExecutorPool.Setting.default/0","type":"function"},{"doc":"Type-aware getter for n_pools_a.","ref":"AntikytheraCore.ExecutorPool.Setting.html#n_pools_a/1","title":"AntikytheraCore.ExecutorPool.Setting.n_pools_a/1","type":"function"},{"doc":"Type-aware setter for n_pools_a.","ref":"AntikytheraCore.ExecutorPool.Setting.html#n_pools_a/2","title":"AntikytheraCore.ExecutorPool.Setting.n_pools_a/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.ExecutorPool.Setting by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.ExecutorPool.Setting.html#new/1","title":"AntikytheraCore.ExecutorPool.Setting.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ExecutorPool.Setting.html#new!/1","title":"AntikytheraCore.ExecutorPool.Setting.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Setting.html#of_gear/1","title":"AntikytheraCore.ExecutorPool.Setting.of_gear/1","type":"function"},{"doc":"Type-aware getter for pool_size_a.","ref":"AntikytheraCore.ExecutorPool.Setting.html#pool_size_a/1","title":"AntikytheraCore.ExecutorPool.Setting.pool_size_a/1","type":"function"},{"doc":"Type-aware setter for pool_size_a.","ref":"AntikytheraCore.ExecutorPool.Setting.html#pool_size_a/2","title":"AntikytheraCore.ExecutorPool.Setting.pool_size_a/2","type":"function"},{"doc":"Type-aware getter for pool_size_j.","ref":"AntikytheraCore.ExecutorPool.Setting.html#pool_size_j/1","title":"AntikytheraCore.ExecutorPool.Setting.pool_size_j/1","type":"function"},{"doc":"Type-aware setter for pool_size_j.","ref":"AntikytheraCore.ExecutorPool.Setting.html#pool_size_j/2","title":"AntikytheraCore.ExecutorPool.Setting.pool_size_j/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.ExecutorPool.Setting with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.ExecutorPool.Setting.html#update/2","title":"AntikytheraCore.ExecutorPool.Setting.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ExecutorPool.Setting.html#update!/2","title":"AntikytheraCore.ExecutorPool.Setting.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.ExecutorPool.Setting.html#valid?/1","title":"AntikytheraCore.ExecutorPool.Setting.valid?/1","type":"function"},{"doc":"Type-aware getter for ws_max_connections.","ref":"AntikytheraCore.ExecutorPool.Setting.html#ws_max_connections/1","title":"AntikytheraCore.ExecutorPool.Setting.ws_max_connections/1","type":"function"},{"doc":"Type-aware setter for ws_max_connections.","ref":"AntikytheraCore.ExecutorPool.Setting.html#ws_max_connections/2","title":"AntikytheraCore.ExecutorPool.Setting.ws_max_connections/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Setting.html#t:t/0","title":"AntikytheraCore.ExecutorPool.Setting.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Sup.html","title":"AntikytheraCore.ExecutorPool.Sup","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.Sup.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.Sup.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.Sup.html#start_link/1","title":"AntikytheraCore.ExecutorPool.Sup.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html","title":"AntikytheraCore.ExecutorPool.TenantSetting","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#associate_with_gear/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.associate_with_gear/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#default/0","title":"AntikytheraCore.ExecutorPool.TenantSetting.default/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#disassociate_from_gear/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.disassociate_from_gear/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#fetch_all_modified/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.fetch_all_modified/1","type":"function"},{"doc":"Type-aware getter for gears.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#gears/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.gears/1","type":"function"},{"doc":"Type-aware setter for gears.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#gears/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.gears/2","type":"function"},{"doc":"Type-aware getter for n_pools_a.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#n_pools_a/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.n_pools_a/1","type":"function"},{"doc":"Type-aware setter for n_pools_a.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#n_pools_a/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.n_pools_a/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.ExecutorPool.TenantSetting by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#new/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#new!/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#persist_new_tenant_and_broadcast/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.persist_new_tenant_and_broadcast/2","type":"function"},{"doc":"Type-aware getter for pool_size_a.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#pool_size_a/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.pool_size_a/1","type":"function"},{"doc":"Type-aware setter for pool_size_a.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#pool_size_a/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.pool_size_a/2","type":"function"},{"doc":"Type-aware getter for pool_size_j.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#pool_size_j/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.pool_size_j/1","type":"function"},{"doc":"Type-aware setter for pool_size_j.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#pool_size_j/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.pool_size_j/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.ExecutorPool.TenantSetting with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#update/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#update!/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#valid?/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.valid?/1","type":"function"},{"doc":"Type-aware getter for ws_max_connections.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#ws_max_connections/1","title":"AntikytheraCore.ExecutorPool.TenantSetting.ws_max_connections/1","type":"function"},{"doc":"Type-aware setter for ws_max_connections.","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#ws_max_connections/2","title":"AntikytheraCore.ExecutorPool.TenantSetting.ws_max_connections/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TenantSetting.html#t:t/0","title":"AntikytheraCore.ExecutorPool.TenantSetting.t/0","type":"type"},{"doc":"A GenServer to periodically send command to the leader process of the corresponding async job queue.Purposes of the command are twofold:to trigger executions of scheduled jobs that have become runnable, andto get metrics from the queue.The interaction between this GenServer and the leader is meaningful only when the leader resides in the same node.","ref":"AntikytheraCore.ExecutorPool.TimedJobStarter.html","title":"AntikytheraCore.ExecutorPool.TimedJobStarter","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.TimedJobStarter.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.TimedJobStarter.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.TimedJobStarter.html#start_link/1","title":"AntikytheraCore.ExecutorPool.TimedJobStarter.start_link/1","type":"function"},{"doc":"A GenServer that periodically fetches usage of executor pool and submits it.Depends onAntikytheraCore.MetricsUploader process for antikytheraPoolSup.Multi process for action runners in the same executor poolPoolSup process for async job runners in the same executor poolAntikytheraCore.ExecutorPool.WebsocketConnectionsCounter process in the same executor pool","ref":"AntikytheraCore.ExecutorPool.UsageReporter.html","title":"AntikytheraCore.ExecutorPool.UsageReporter","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.UsageReporter.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.UsageReporter.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.UsageReporter.html#start_link/1","title":"AntikytheraCore.ExecutorPool.UsageReporter.start_link/1","type":"function"},{"doc":"A GenServer to count number of websocket connections that belong to the executor pool.Before termination of the current host, all monitored websocket connections will be disconnected in order to prompt clients to reconnect to other active nodes (this is executed within temporary processes but uses monitors created by this GenServer).","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#child_spec/1","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#gradually_terminate_all_ws_connections/0","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.gradually_terminate_all_ws_connections/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#increment/2","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.increment/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#set_max/2","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.set_max/2","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#start_link/1","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#start_terminating_all_ws_connections/0","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.start_terminating_all_ws_connections/0","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.html#stats/1","title":"AntikytheraCore.ExecutorPool.WebsocketConnectionsCounter.stats/1","type":"function"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WsConnectionsCapping.html","title":"AntikytheraCore.ExecutorPool.WsConnectionsCapping","type":"module"},{"doc":"","ref":"AntikytheraCore.ExecutorPool.WsConnectionsCapping.html#cap_based_on_available_memory/1","title":"AntikytheraCore.ExecutorPool.WsConnectionsCapping.cap_based_on_available_memory/1","type":"function"},{"doc":"","ref":"AntikytheraCore.FileSetup.html","title":"AntikytheraCore.FileSetup","type":"module"},{"doc":"","ref":"AntikytheraCore.FileSetup.html#setup_files_and_ets_tables/0","title":"AntikytheraCore.FileSetup.setup_files_and_ets_tables/0","type":"function"},{"doc":"","ref":"AntikytheraCore.FileSetup.html#write_initial_antikythera_instance_version_to_history_if_non_cloud/1","title":"AntikytheraCore.FileSetup.write_initial_antikythera_instance_version_to_history_if_non_cloud/1","type":"function"},{"doc":"Periodically polls changes in gear configs.Gear configs are persisted in a shared data storage (e.g. NFS) and are cached in ETS in each erlang node. Note that gear configs are loaded (cached into ETS) at each step ofAntikytheraCore.start/2: all existing gear configs are loadedeach gear's start/2: the gear's gear config is loadedThus this GenServer's responsibility is just to keep up with changes in the shared data storage.Depends on AntikytheraCore.GearManager (when applying changes in gear configs results in update of cowboy routing).","ref":"AntikytheraCore.GearConfigPoller.html","title":"AntikytheraCore.GearConfigPoller","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.GearConfigPoller.html#child_spec/1","title":"AntikytheraCore.GearConfigPoller.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearConfigPoller.html#start_link/1","title":"AntikytheraCore.GearConfigPoller.start_link/1","type":"function"},{"doc":"Periodically polls gears' executor pool settings and apply changes.Settings of gear executor pools are embedded in antikythera core config. Loading core config file and caching into ETS is done by CoreConfigPoller; this GenServer watches for the cache.","ref":"AntikytheraCore.GearExecutorPoolsManager.html","title":"AntikytheraCore.GearExecutorPoolsManager","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.GearExecutorPoolsManager.html#child_spec/1","title":"AntikytheraCore.GearExecutorPoolsManager.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearExecutorPoolsManager.html#start_link/1","title":"AntikytheraCore.GearExecutorPoolsManager.start_link/1","type":"function"},{"doc":"Helpers to get/set context ID.Context IDs are mainly to be used for logging. In order to keep Logger's interface clean (i.e. not to make context_id trump data solely for logging purpose), context ID is stored in each process's process dictionary and fetched when a process emits a log message.","ref":"AntikytheraCore.GearLog.ContextHelper.html","title":"AntikytheraCore.GearLog.ContextHelper","type":"module"},{"doc":"","ref":"AntikytheraCore.GearLog.ContextHelper.html#get!/0","title":"AntikytheraCore.GearLog.ContextHelper.get!/0","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.ContextHelper.html#set/1","title":"AntikytheraCore.GearLog.ContextHelper.set/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.html","title":"AntikytheraCore.GearLog.FileHandle","type":"module"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.html#close/1","title":"AntikytheraCore.GearLog.FileHandle.close/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.html#open/2","title":"AntikytheraCore.GearLog.FileHandle.open/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.html#rotate/1","title":"AntikytheraCore.GearLog.FileHandle.rotate/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.html#write/2","title":"AntikytheraCore.GearLog.FileHandle.write/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.html#t:t/0","title":"AntikytheraCore.GearLog.FileHandle.t/0","type":"opaque"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.SizeCheck.html","title":"AntikytheraCore.GearLog.FileHandle.SizeCheck","type":"module"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.SizeCheck.html#check_now?/2","title":"AntikytheraCore.GearLog.FileHandle.SizeCheck.check_now?/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.FileHandle.SizeCheck.html#exceeds_limit?/1","title":"AntikytheraCore.GearLog.FileHandle.SizeCheck.exceeds_limit?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html","title":"AntikytheraCore.GearLog.Level","type":"module"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#default/0","title":"AntikytheraCore.GearLog.Level.default/0","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#from_string/1","title":"AntikytheraCore.GearLog.Level.from_string/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#new/1","title":"AntikytheraCore.GearLog.Level.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#new!/1","title":"AntikytheraCore.GearLog.Level.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#valid?/1","title":"AntikytheraCore.GearLog.Level.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#values/0","title":"AntikytheraCore.GearLog.Level.values/0","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#write_to_log?/2","title":"AntikytheraCore.GearLog.Level.write_to_log?/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Level.html#t:t/0","title":"AntikytheraCore.GearLog.Level.t/0","type":"type"},{"doc":"A Module to write and rotate a log file using AntikytheraCore.GearLog.FileHandle.","ref":"AntikytheraCore.GearLog.LogRotation.html","title":"AntikytheraCore.GearLog.LogRotation","type":"module"},{"doc":"","ref":"AntikytheraCore.GearLog.LogRotation.html#init/3","title":"AntikytheraCore.GearLog.LogRotation.init/3","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.LogRotation.html#rotate/1","title":"AntikytheraCore.GearLog.LogRotation.rotate/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.LogRotation.html#terminate/1","title":"AntikytheraCore.GearLog.LogRotation.terminate/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.LogRotation.html#write_log/2","title":"AntikytheraCore.GearLog.LogRotation.write_log/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.LogRotation.State.html","title":"AntikytheraCore.GearLog.LogRotation.State","type":"module"},{"doc":"Type-aware getter for empty?.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#empty?/1","title":"AntikytheraCore.GearLog.LogRotation.State.empty?/1","type":"function"},{"doc":"Type-aware setter for empty?.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#empty?/2","title":"AntikytheraCore.GearLog.LogRotation.State.empty?/2","type":"function"},{"doc":"Type-aware getter for file_handle.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#file_handle/1","title":"AntikytheraCore.GearLog.LogRotation.State.file_handle/1","type":"function"},{"doc":"Type-aware setter for file_handle.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#file_handle/2","title":"AntikytheraCore.GearLog.LogRotation.State.file_handle/2","type":"function"},{"doc":"Type-aware getter for interval.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#interval/1","title":"AntikytheraCore.GearLog.LogRotation.State.interval/1","type":"function"},{"doc":"Type-aware setter for interval.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#interval/2","title":"AntikytheraCore.GearLog.LogRotation.State.interval/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.GearLog.LogRotation.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.GearLog.LogRotation.State.html#new/1","title":"AntikytheraCore.GearLog.LogRotation.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#new!/1","title":"AntikytheraCore.GearLog.LogRotation.State.new!/1","type":"function"},{"doc":"Type-aware getter for timer.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#timer/1","title":"AntikytheraCore.GearLog.LogRotation.State.timer/1","type":"function"},{"doc":"Type-aware setter for timer.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#timer/2","title":"AntikytheraCore.GearLog.LogRotation.State.timer/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.GearLog.LogRotation.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#update/2","title":"AntikytheraCore.GearLog.LogRotation.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#update!/2","title":"AntikytheraCore.GearLog.LogRotation.State.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.GearLog.LogRotation.State.html#valid?/1","title":"AntikytheraCore.GearLog.LogRotation.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.LogRotation.State.html#t:t/0","title":"AntikytheraCore.GearLog.LogRotation.State.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.GearLog.Message.html","title":"AntikytheraCore.GearLog.Message","type":"module"},{"doc":"","ref":"AntikytheraCore.GearLog.Message.html#t:t/0","title":"AntikytheraCore.GearLog.Message.t/0","type":"type"},{"doc":"A GenServer that writes log messages from each gear's Logger process into a gzipped file.This GenServer is spawned per gear; each of which resides in the gear's supervision tree.Although opened log files are regularly rotated, this GenServer also supports on-demand log rotation. After each successful log rotation, old log file is uploaded to cloud storage.","ref":"AntikytheraCore.GearLog.Writer.html","title":"AntikytheraCore.GearLog.Writer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.GearLog.Writer.html#child_spec/1","title":"AntikytheraCore.GearLog.Writer.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#debug/2","title":"AntikytheraCore.GearLog.Writer.debug/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#debug/4","title":"AntikytheraCore.GearLog.Writer.debug/4","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#error/2","title":"AntikytheraCore.GearLog.Writer.error/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#error/4","title":"AntikytheraCore.GearLog.Writer.error/4","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#info/2","title":"AntikytheraCore.GearLog.Writer.info/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#info/4","title":"AntikytheraCore.GearLog.Writer.info/4","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#rotate/1","title":"AntikytheraCore.GearLog.Writer.rotate/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#rotate_and_start_upload_in_all_nodes/1","title":"AntikytheraCore.GearLog.Writer.rotate_and_start_upload_in_all_nodes/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#set_min_level/2","title":"AntikytheraCore.GearLog.Writer.set_min_level/2","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.html#start_link/1","title":"AntikytheraCore.GearLog.Writer.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.State.html","title":"AntikytheraCore.GearLog.Writer.State","type":"module"},{"doc":"Type-aware getter for log_state.","ref":"AntikytheraCore.GearLog.Writer.State.html#log_state/1","title":"AntikytheraCore.GearLog.Writer.State.log_state/1","type":"function"},{"doc":"Type-aware setter for log_state.","ref":"AntikytheraCore.GearLog.Writer.State.html#log_state/2","title":"AntikytheraCore.GearLog.Writer.State.log_state/2","type":"function"},{"doc":"Type-aware getter for min_level.","ref":"AntikytheraCore.GearLog.Writer.State.html#min_level/1","title":"AntikytheraCore.GearLog.Writer.State.min_level/1","type":"function"},{"doc":"Type-aware setter for min_level.","ref":"AntikytheraCore.GearLog.Writer.State.html#min_level/2","title":"AntikytheraCore.GearLog.Writer.State.min_level/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.GearLog.Writer.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.GearLog.Writer.State.html#new/1","title":"AntikytheraCore.GearLog.Writer.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.GearLog.Writer.State.html#new!/1","title":"AntikytheraCore.GearLog.Writer.State.new!/1","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.GearLog.Writer.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.GearLog.Writer.State.html#update/2","title":"AntikytheraCore.GearLog.Writer.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.GearLog.Writer.State.html#update!/2","title":"AntikytheraCore.GearLog.Writer.State.update!/2","type":"function"},{"doc":"Type-aware getter for uploader.","ref":"AntikytheraCore.GearLog.Writer.State.html#uploader/1","title":"AntikytheraCore.GearLog.Writer.State.uploader/1","type":"function"},{"doc":"Type-aware setter for uploader.","ref":"AntikytheraCore.GearLog.Writer.State.html#uploader/2","title":"AntikytheraCore.GearLog.Writer.State.uploader/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.GearLog.Writer.State.html#valid?/1","title":"AntikytheraCore.GearLog.Writer.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearLog.Writer.State.html#t:t/0","title":"AntikytheraCore.GearLog.Writer.State.t/0","type":"type"},{"doc":"A GenServer to keep track of names of currently running gears.","ref":"AntikytheraCore.GearManager.html","title":"AntikytheraCore.GearManager","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.GearManager.html#child_spec/1","title":"AntikytheraCore.GearManager.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearManager.html#gear_started/1","title":"AntikytheraCore.GearManager.gear_started/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearManager.html#gear_stopped/1","title":"AntikytheraCore.GearManager.gear_stopped/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearManager.html#running_gear_names/0","title":"AntikytheraCore.GearManager.running_gear_names/0","type":"function"},{"doc":"","ref":"AntikytheraCore.GearManager.html#start_link/1","title":"AntikytheraCore.GearManager.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html","title":"AntikytheraCore.GearModule","type":"module"},{"doc":"","ref":"AntikytheraCore.GearModule.html#alert_manager/1","title":"AntikytheraCore.GearModule.alert_manager/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#alert_manager_unsafe/1","title":"AntikytheraCore.GearModule.alert_manager_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#error_handler/1","title":"AntikytheraCore.GearModule.error_handler/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#error_handler_unsafe/1","title":"AntikytheraCore.GearModule.error_handler_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#logger/1","title":"AntikytheraCore.GearModule.logger/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#logger_unsafe/1","title":"AntikytheraCore.GearModule.logger_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#metrics_uploader/1","title":"AntikytheraCore.GearModule.metrics_uploader/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#metrics_uploader_unsafe/1","title":"AntikytheraCore.GearModule.metrics_uploader_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#request_helper_modules/1","title":"AntikytheraCore.GearModule.request_helper_modules/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#root_supervisor_unsafe/1","title":"AntikytheraCore.GearModule.root_supervisor_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#router/1","title":"AntikytheraCore.GearModule.router/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#router_unsafe/1","title":"AntikytheraCore.GearModule.router_unsafe/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#template_module_from_context/1","title":"AntikytheraCore.GearModule.template_module_from_context/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearModule.html#top/1","title":"AntikytheraCore.GearModule.top/1","type":"function"},{"doc":"","ref":"AntikytheraCore.GearProcess.html","title":"AntikytheraCore.GearProcess","type":"module"},{"doc":"","ref":"AntikytheraCore.GearProcess.html#max_heap_size/0","title":"AntikytheraCore.GearProcess.max_heap_size/0","type":"function"},{"doc":"","ref":"AntikytheraCore.GearProcess.html#set_max_heap_size/0","title":"AntikytheraCore.GearProcess.set_max_heap_size/0","type":"function"},{"doc":"","ref":"AntikytheraCore.GearProcess.html#spawn_monitor/3","title":"AntikytheraCore.GearProcess.spawn_monitor/3","type":"function"},{"doc":"A much simplified version of Task module defined in the elixir standard library.While the standard Task requires the invoker to trap exit in order to handle errors (as it uses spawn_link), this module doesn't link the invoker with the worker (uses spawn_monitor instead). Also this version does not send stacktrace to error_logger (since it doesn't use :proc_lib functions to start child process).","ref":"AntikytheraCore.GearTask.html","title":"AntikytheraCore.GearTask","type":"module"},{"doc":"","ref":"AntikytheraCore.GearTask.html#exec_wait/4","title":"AntikytheraCore.GearTask.exec_wait/4","type":"function"},{"doc":"","ref":"AntikytheraCore.GearTask.html#t:mod_fun_args/0","title":"AntikytheraCore.GearTask.mod_fun_args/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.BodyParser.html","title":"AntikytheraCore.Handler.BodyParser","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.BodyParser.html#parse/1","title":"AntikytheraCore.Handler.BodyParser.parse/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html","title":"AntikytheraCore.Handler.CowboyReq","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#method/1","title":"AntikytheraCore.Handler.CowboyReq.method/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#path_info/1","title":"AntikytheraCore.Handler.CowboyReq.path_info/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#query_params/2","title":"AntikytheraCore.Handler.CowboyReq.query_params/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#request_body_pair/4","title":"AntikytheraCore.Handler.CowboyReq.request_body_pair/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#with_conn/5","title":"AntikytheraCore.Handler.CowboyReq.with_conn/5","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#t:result/1","title":"AntikytheraCore.Handler.CowboyReq.result/1","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyReq.html#t:routing_info/0","title":"AntikytheraCore.Handler.CowboyReq.routing_info/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyRouting.html","title":"AntikytheraCore.Handler.CowboyRouting","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyRouting.html#compiled_routes/2","title":"AntikytheraCore.Handler.CowboyRouting.compiled_routes/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyRouting.html#default_domain/2","title":"AntikytheraCore.Handler.CowboyRouting.default_domain/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.CowboyRouting.html#update_routing/2","title":"AntikytheraCore.Handler.CowboyRouting.update_routing/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.ExecutorPoolHelper.html","title":"AntikytheraCore.Handler.ExecutorPoolHelper","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.ExecutorPoolHelper.html#increment_ws_count/4","title":"AntikytheraCore.Handler.ExecutorPoolHelper.increment_ws_count/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.ExecutorPoolHelper.html#with_executor/4","title":"AntikytheraCore.Handler.ExecutorPoolHelper.with_executor/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.html","title":"AntikytheraCore.Handler.GearAction","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.html#split_path_to_segments/1","title":"AntikytheraCore.Handler.GearAction.split_path_to_segments/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.html#with_logging_and_metrics_reporting/3","title":"AntikytheraCore.Handler.GearAction.with_logging_and_metrics_reporting/3","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.G2g.html","title":"AntikytheraCore.Handler.GearAction.G2g","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.G2g.html#handle/3","title":"AntikytheraCore.Handler.GearAction.G2g.handle/3","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.Web.html","title":"AntikytheraCore.Handler.GearAction.Web","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.Web.html#t:http_reply/0","title":"AntikytheraCore.Handler.GearAction.Web.http_reply/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.GearAction.Web.html#t:ws_upgrade/0","title":"AntikytheraCore.Handler.GearAction.Web.ws_upgrade/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html","title":"AntikytheraCore.Handler.GearError","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html#bad_executor_pool_id/2","title":"AntikytheraCore.Handler.GearError.bad_executor_pool_id/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html#bad_request/1","title":"AntikytheraCore.Handler.GearError.bad_request/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html#error/3","title":"AntikytheraCore.Handler.GearError.error/3","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html#internal_error_body/3","title":"AntikytheraCore.Handler.GearError.internal_error_body/3","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html#no_route/1","title":"AntikytheraCore.Handler.GearError.no_route/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.GearError.html#ws_too_many_connections/1","title":"AntikytheraCore.Handler.GearError.ws_too_many_connections/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.Healthcheck.html","title":"AntikytheraCore.Handler.Healthcheck","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.Healthcheck.Initialized.html","title":"AntikytheraCore.Handler.Healthcheck.Initialized","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.Healthcheck.Uninitialized.html","title":"AntikytheraCore.Handler.Healthcheck.Uninitialized","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.HelperModules.html","title":"AntikytheraCore.Handler.HelperModules","type":"module"},{"doc":"Type-aware getter for logger.","ref":"AntikytheraCore.Handler.HelperModules.html#logger/1","title":"AntikytheraCore.Handler.HelperModules.logger/1","type":"function"},{"doc":"Type-aware setter for logger.","ref":"AntikytheraCore.Handler.HelperModules.html#logger/2","title":"AntikytheraCore.Handler.HelperModules.logger/2","type":"function"},{"doc":"Type-aware getter for metrics_uploader.","ref":"AntikytheraCore.Handler.HelperModules.html#metrics_uploader/1","title":"AntikytheraCore.Handler.HelperModules.metrics_uploader/1","type":"function"},{"doc":"Type-aware setter for metrics_uploader.","ref":"AntikytheraCore.Handler.HelperModules.html#metrics_uploader/2","title":"AntikytheraCore.Handler.HelperModules.metrics_uploader/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.Handler.HelperModules by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.Handler.HelperModules.html#new/1","title":"AntikytheraCore.Handler.HelperModules.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Handler.HelperModules.html#new!/1","title":"AntikytheraCore.Handler.HelperModules.new!/1","type":"function"},{"doc":"Type-aware getter for router.","ref":"AntikytheraCore.Handler.HelperModules.html#router/1","title":"AntikytheraCore.Handler.HelperModules.router/1","type":"function"},{"doc":"Type-aware setter for router.","ref":"AntikytheraCore.Handler.HelperModules.html#router/2","title":"AntikytheraCore.Handler.HelperModules.router/2","type":"function"},{"doc":"Type-aware getter for top.","ref":"AntikytheraCore.Handler.HelperModules.html#top/1","title":"AntikytheraCore.Handler.HelperModules.top/1","type":"function"},{"doc":"Type-aware setter for top.","ref":"AntikytheraCore.Handler.HelperModules.html#top/2","title":"AntikytheraCore.Handler.HelperModules.top/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.Handler.HelperModules with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.Handler.HelperModules.html#update/2","title":"AntikytheraCore.Handler.HelperModules.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Handler.HelperModules.html#update!/2","title":"AntikytheraCore.Handler.HelperModules.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.Handler.HelperModules.html#valid?/1","title":"AntikytheraCore.Handler.HelperModules.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.HelperModules.html#t:t/0","title":"AntikytheraCore.Handler.HelperModules.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.html","title":"AntikytheraCore.Handler.SystemInfoExporter","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.html","title":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.html#get/0","title":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.get/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.html#init/0","title":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.html#with_valid_token/2","title":"AntikytheraCore.Handler.SystemInfoExporter.AccessToken.with_valid_token/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.ErrorCount.html","title":"AntikytheraCore.Handler.SystemInfoExporter.ErrorCount","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.ErrorCount.html#init/2","title":"AntikytheraCore.Handler.SystemInfoExporter.ErrorCount.init/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.Versions.html","title":"AntikytheraCore.Handler.SystemInfoExporter.Versions","type":"module"},{"doc":"","ref":"AntikytheraCore.Handler.SystemInfoExporter.Versions.html#init/2","title":"AntikytheraCore.Handler.SystemInfoExporter.Versions.init/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html","title":"AntikytheraCore.Handler.WebsocketState","type":"module"},{"doc":"Type-aware getter for conn.","ref":"AntikytheraCore.Handler.WebsocketState.html#conn/1","title":"AntikytheraCore.Handler.WebsocketState.conn/1","type":"function"},{"doc":"Type-aware setter for conn.","ref":"AntikytheraCore.Handler.WebsocketState.html#conn/2","title":"AntikytheraCore.Handler.WebsocketState.conn/2","type":"function"},{"doc":"Type-aware getter for error_reason.","ref":"AntikytheraCore.Handler.WebsocketState.html#error_reason/1","title":"AntikytheraCore.Handler.WebsocketState.error_reason/1","type":"function"},{"doc":"Type-aware setter for error_reason.","ref":"AntikytheraCore.Handler.WebsocketState.html#error_reason/2","title":"AntikytheraCore.Handler.WebsocketState.error_reason/2","type":"function"},{"doc":"Type-aware getter for frames_received.","ref":"AntikytheraCore.Handler.WebsocketState.html#frames_received/1","title":"AntikytheraCore.Handler.WebsocketState.frames_received/1","type":"function"},{"doc":"Type-aware setter for frames_received.","ref":"AntikytheraCore.Handler.WebsocketState.html#frames_received/2","title":"AntikytheraCore.Handler.WebsocketState.frames_received/2","type":"function"},{"doc":"Type-aware getter for frames_sent.","ref":"AntikytheraCore.Handler.WebsocketState.html#frames_sent/1","title":"AntikytheraCore.Handler.WebsocketState.frames_sent/1","type":"function"},{"doc":"Type-aware setter for frames_sent.","ref":"AntikytheraCore.Handler.WebsocketState.html#frames_sent/2","title":"AntikytheraCore.Handler.WebsocketState.frames_sent/2","type":"function"},{"doc":"Type-aware getter for gear_impl_state.","ref":"AntikytheraCore.Handler.WebsocketState.html#gear_impl_state/1","title":"AntikytheraCore.Handler.WebsocketState.gear_impl_state/1","type":"function"},{"doc":"Type-aware setter for gear_impl_state.","ref":"AntikytheraCore.Handler.WebsocketState.html#gear_impl_state/2","title":"AntikytheraCore.Handler.WebsocketState.gear_impl_state/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#handle_client_message/2","title":"AntikytheraCore.Handler.WebsocketState.handle_client_message/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#handle_server_message/2","title":"AntikytheraCore.Handler.WebsocketState.handle_server_message/2","type":"function"},{"doc":"Type-aware getter for helper_modules.","ref":"AntikytheraCore.Handler.WebsocketState.html#helper_modules/1","title":"AntikytheraCore.Handler.WebsocketState.helper_modules/1","type":"function"},{"doc":"Type-aware setter for helper_modules.","ref":"AntikytheraCore.Handler.WebsocketState.html#helper_modules/2","title":"AntikytheraCore.Handler.WebsocketState.helper_modules/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#init/1","title":"AntikytheraCore.Handler.WebsocketState.init/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#make/3","title":"AntikytheraCore.Handler.WebsocketState.make/3","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.Handler.WebsocketState by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.Handler.WebsocketState.html#new/1","title":"AntikytheraCore.Handler.WebsocketState.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Handler.WebsocketState.html#new!/1","title":"AntikytheraCore.Handler.WebsocketState.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#terminate/2","title":"AntikytheraCore.Handler.WebsocketState.terminate/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.Handler.WebsocketState with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.Handler.WebsocketState.html#update/2","title":"AntikytheraCore.Handler.WebsocketState.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Handler.WebsocketState.html#update!/2","title":"AntikytheraCore.Handler.WebsocketState.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.Handler.WebsocketState.html#valid?/1","title":"AntikytheraCore.Handler.WebsocketState.valid?/1","type":"function"},{"doc":"Type-aware getter for ws_module.","ref":"AntikytheraCore.Handler.WebsocketState.html#ws_module/1","title":"AntikytheraCore.Handler.WebsocketState.ws_module/1","type":"function"},{"doc":"Type-aware setter for ws_module.","ref":"AntikytheraCore.Handler.WebsocketState.html#ws_module/2","title":"AntikytheraCore.Handler.WebsocketState.ws_module/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#t:callback_result/0","title":"AntikytheraCore.Handler.WebsocketState.callback_result/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#t:cowboy_ws_terminate_reason/0","title":"AntikytheraCore.Handler.WebsocketState.cowboy_ws_terminate_reason/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Handler.WebsocketState.html#t:t/0","title":"AntikytheraCore.Handler.WebsocketState.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Logger.html","title":"AntikytheraCore.Logger","type":"module"},{"doc":"","ref":"AntikytheraCore.Logger.html#error/1","title":"AntikytheraCore.Logger.error/1","type":"macro"},{"doc":"","ref":"AntikytheraCore.Logger.html#info/1","title":"AntikytheraCore.Logger.info/1","type":"macro"},{"doc":"Defines (1) a behaviour to compute metrics results from raw metrics data and (2) some implementations of the behaviour. &quot;Raw metrics data&quot; is values reported from other components (e.g. response time values). &quot;Metrics results&quot; are values that summarize characteristics of &quot;raw metrics data&quot; (e.g. average response time).Antikythera gear implementations must specify name of one of the strategies when submitting raw metric data. For available name see the type definition in AntikytheraCore.Metrics.AggregateStrategy.Name. For detailed information about each strategy refer to each module's documentation.","ref":"AntikytheraCore.Metrics.AggregateStrategy.html","title":"AntikytheraCore.Metrics.AggregateStrategy","type":"module"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#name_to_module/1","title":"AntikytheraCore.Metrics.AggregateStrategy.name_to_module/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#new/1","title":"AntikytheraCore.Metrics.AggregateStrategy.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#new!/1","title":"AntikytheraCore.Metrics.AggregateStrategy.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#valid?/1","title":"AntikytheraCore.Metrics.AggregateStrategy.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#values/0","title":"AntikytheraCore.Metrics.AggregateStrategy.values/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#t:data_t/0","title":"AntikytheraCore.Metrics.AggregateStrategy.data_t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#t:results_t/0","title":"AntikytheraCore.Metrics.AggregateStrategy.results_t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.html#t:t/0","title":"AntikytheraCore.Metrics.AggregateStrategy.t/0","type":"type"},{"doc":"Aggregate strategy that calculates the average value of incoming raw metrics data.","ref":"AntikytheraCore.Metrics.AggregateStrategy.Average.html","title":"AntikytheraCore.Metrics.AggregateStrategy.Average","type":"module"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.html","title":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour","type":"behaviour"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.html#c:init/1","title":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.init/1","type":"callback"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.html#c:merge/2","title":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.merge/2","type":"callback"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.html#c:results/1","title":"AntikytheraCore.Metrics.AggregateStrategy.Behaviour.results/1","type":"callback"},{"doc":"Aggregate strategy that simply takes the last value within each time window.","ref":"AntikytheraCore.Metrics.AggregateStrategy.Gauge.html","title":"AntikytheraCore.Metrics.AggregateStrategy.Gauge","type":"module"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Name.html","title":"AntikytheraCore.Metrics.AggregateStrategy.Name","type":"module"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Name.html#new/1","title":"AntikytheraCore.Metrics.AggregateStrategy.Name.new/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Name.html#new!/1","title":"AntikytheraCore.Metrics.AggregateStrategy.Name.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Name.html#valid?/1","title":"AntikytheraCore.Metrics.AggregateStrategy.Name.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Name.html#values/0","title":"AntikytheraCore.Metrics.AggregateStrategy.Name.values/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.AggregateStrategy.Name.html#t:t/0","title":"AntikytheraCore.Metrics.AggregateStrategy.Name.t/0","type":"type"},{"doc":"Aggregate strategy for request counts. This calculates the following values from HTTP status codes of responses within a time window:total number of requestsnumber of requests that result in 4XX response (client error)number of requests that result in 5XX response (server error)Note that, strictly speaking, numbers generated by this aggreagate strategy do not include invalid requests that are rejected by antikythera before arriving at gear's controller action, i.e. requests which do not match any of the defined routes, requests with malformed body, etc.","ref":"AntikytheraCore.Metrics.AggregateStrategy.RequestCount.html","title":"AntikytheraCore.Metrics.AggregateStrategy.RequestCount","type":"module"},{"doc":"Aggregate strategy that computes the sum of all values generated within each time window.","ref":"AntikytheraCore.Metrics.AggregateStrategy.Sum.html","title":"AntikytheraCore.Metrics.AggregateStrategy.Sum","type":"module"},{"doc":"Aggregate strategy for time distribution (such as response times). This calculates the following values from time durations generated within a time window:averagemaximum95-percentile","ref":"AntikytheraCore.Metrics.AggregateStrategy.TimeDistribution.html","title":"AntikytheraCore.Metrics.AggregateStrategy.TimeDistribution","type":"module"},{"doc":"A bin-like data structure to hold per-minute, per-epool metrics data.%{ {time_minute, epool_id} =&gt; %{ {metrics_type, strategy} =&gt; data_in_processing, {metrics_type, strategy} =&gt; data_in_processing, ... }, ... }","ref":"AntikytheraCore.Metrics.Buffer.html","title":"AntikytheraCore.Metrics.Buffer","type":"module"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#add/4","title":"AntikytheraCore.Metrics.Buffer.add/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#new/0","title":"AntikytheraCore.Metrics.Buffer.new/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#partition_ongoing_and_past/2","title":"AntikytheraCore.Metrics.Buffer.partition_ongoing_and_past/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:epool_id/0","title":"AntikytheraCore.Metrics.Buffer.epool_id/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:metrics_data_map/0","title":"AntikytheraCore.Metrics.Buffer.metrics_data_map/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:metrics_type/0","title":"AntikytheraCore.Metrics.Buffer.metrics_type/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:metrics_unit/0","title":"AntikytheraCore.Metrics.Buffer.metrics_unit/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:metrics_value/0","title":"AntikytheraCore.Metrics.Buffer.metrics_value/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:minute/0","title":"AntikytheraCore.Metrics.Buffer.minute/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Buffer.html#t:t/0","title":"AntikytheraCore.Metrics.Buffer.t/0","type":"type"},{"doc":"Data structure to represent metrics results computed from raw metrics data. Results are map of metrics data by minute-epool.%{ {time_minute, epool_id} =&gt; %{ metrics_label =&gt; metrics_value, metrics_label =&gt; metrics_value, ... }, ... }","ref":"AntikytheraCore.Metrics.Results.html","title":"AntikytheraCore.Metrics.Results","type":"module"},{"doc":"","ref":"AntikytheraCore.Metrics.Results.html#compute_results/1","title":"AntikytheraCore.Metrics.Results.compute_results/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.Results.html#merge/2","title":"AntikytheraCore.Metrics.Results.merge/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.Results.html#new/0","title":"AntikytheraCore.Metrics.Results.new/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Metrics.Results.html#t:metrics_label/0","title":"AntikytheraCore.Metrics.Results.metrics_label/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Results.html#t:per_unit_results_map/0","title":"AntikytheraCore.Metrics.Results.per_unit_results_map/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Metrics.Results.html#t:t/0","title":"AntikytheraCore.Metrics.Results.t/0","type":"type"},{"doc":"A GenServer which buffers metrics data and periodically flushes the aggregated results to stable storage.","ref":"AntikytheraCore.MetricsUploader.html","title":"AntikytheraCore.MetricsUploader","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.MetricsUploader.html#child_spec/1","title":"AntikytheraCore.MetricsUploader.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.MetricsUploader.html#start_link/1","title":"AntikytheraCore.MetricsUploader.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.MetricsUploader.html#submit/3","title":"AntikytheraCore.MetricsUploader.submit/3","type":"function"},{"doc":"","ref":"AntikytheraCore.MetricsUploader.html#submit_custom_metrics/3","title":"AntikytheraCore.MetricsUploader.submit_custom_metrics/3","type":"function"},{"doc":"","ref":"AntikytheraCore.MetricsUploader.html#submit_with_time/4","title":"AntikytheraCore.MetricsUploader.submit_with_time/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Mix.AssetList.html","title":"AntikytheraCore.Mix.AssetList","type":"module"},{"doc":"","ref":"AntikytheraCore.Mix.AssetList.html#load_all/2","title":"AntikytheraCore.Mix.AssetList.load_all/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Mix.AssetList.html#write!/2","title":"AntikytheraCore.Mix.AssetList.write!/2","type":"function"},{"doc":"A GenServer that periodically removes extra nodes from mnesia schema.When a new node is started it automatically starts to sync both mnesia schema and data with other participating nodes. On the other hand when a node is terminated it's not automatically removed from mnesia schema (because mnesia has no idea whether the node will re-join the cluster or not).This GenServer periodically cleans up any already-terminated nodes from mnesia schema by using hosts information from the underlying infrastructure. Without this cleanup the &quot;already terminated nodes&quot; would accumulate in mnesia schema and make startup of new nodes really slow (new node tries to sync with nonexisting nodes until timeout).Depends on AntikytheraCore.ClusterHostsPoller.","ref":"AntikytheraCore.MnesiaNodesCleaner.html","title":"AntikytheraCore.MnesiaNodesCleaner","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.MnesiaNodesCleaner.html#child_spec/1","title":"AntikytheraCore.MnesiaNodesCleaner.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.MnesiaNodesCleaner.html#start_link/1","title":"AntikytheraCore.MnesiaNodesCleaner.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.OsUtil.html","title":"AntikytheraCore.OsUtil","type":"module"},{"doc":"","ref":"AntikytheraCore.OsUtil.html#init/0","title":"AntikytheraCore.OsUtil.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.OsUtil.html#total_memory_size_in_bytes/0","title":"AntikytheraCore.OsUtil.total_memory_size_in_bytes/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html","title":"AntikytheraCore.Path","type":"module"},{"doc":"","ref":"AntikytheraCore.Path.html#antikythera_root_dir/0","title":"AntikytheraCore.Path.antikythera_root_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#changed?/2","title":"AntikytheraCore.Path.changed?/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#compiled_core_dir/0","title":"AntikytheraCore.Path.compiled_core_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#compiled_gears_dir/0","title":"AntikytheraCore.Path.compiled_gears_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#config_encryption_key_path/0","title":"AntikytheraCore.Path.config_encryption_key_path/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#core_config_file_path/0","title":"AntikytheraCore.Path.core_config_file_path/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#core_log_file_path/1","title":"AntikytheraCore.Path.core_log_file_path/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#gear_config_dir/0","title":"AntikytheraCore.Path.gear_config_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#gear_config_file_path/1","title":"AntikytheraCore.Path.gear_config_file_path/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#gear_log_dir/1","title":"AntikytheraCore.Path.gear_log_dir/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#gear_log_file_path/1","title":"AntikytheraCore.Path.gear_log_file_path/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#gear_tmp_dir/0","title":"AntikytheraCore.Path.gear_tmp_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#history_dir/0","title":"AntikytheraCore.Path.history_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#list_modified_files/2","title":"AntikytheraCore.Path.list_modified_files/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#raft_persistence_dir_parent/0","title":"AntikytheraCore.Path.raft_persistence_dir_parent/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#system_info_access_token_path/0","title":"AntikytheraCore.Path.system_info_access_token_path/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#tenant_ids_file_path/0","title":"AntikytheraCore.Path.tenant_ids_file_path/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#tenant_setting_dir/0","title":"AntikytheraCore.Path.tenant_setting_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Path.html#tenant_setting_file_path/1","title":"AntikytheraCore.Path.tenant_setting_file_path/1","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.MessageBuilder.html","title":"AntikytheraCore.PeriodicLog.MessageBuilder","type":"module"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.MessageBuilder.html#build_log/1","title":"AntikytheraCore.PeriodicLog.MessageBuilder.build_log/1","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.MessageBuilder.html#init/0","title":"AntikytheraCore.PeriodicLog.MessageBuilder.init/0","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.ReductionBuilder.html","title":"AntikytheraCore.PeriodicLog.ReductionBuilder","type":"module"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.ReductionBuilder.html#build_log/1","title":"AntikytheraCore.PeriodicLog.ReductionBuilder.build_log/1","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.ReductionBuilder.html#init/0","title":"AntikytheraCore.PeriodicLog.ReductionBuilder.init/0","type":"function"},{"doc":"A GenServer that logs periodically","ref":"AntikytheraCore.PeriodicLog.Writer.html","title":"AntikytheraCore.PeriodicLog.Writer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.PeriodicLog.Writer.html#child_spec/1","title":"AntikytheraCore.PeriodicLog.Writer.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.Writer.html#start_link/1","title":"AntikytheraCore.PeriodicLog.Writer.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.Writer.State.html","title":"AntikytheraCore.PeriodicLog.Writer.State","type":"module"},{"doc":"Type-aware getter for build_mod.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#build_mod/1","title":"AntikytheraCore.PeriodicLog.Writer.State.build_mod/1","type":"function"},{"doc":"Type-aware setter for build_mod.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#build_mod/2","title":"AntikytheraCore.PeriodicLog.Writer.State.build_mod/2","type":"function"},{"doc":"Type-aware getter for build_state.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#build_state/1","title":"AntikytheraCore.PeriodicLog.Writer.State.build_state/1","type":"function"},{"doc":"Type-aware setter for build_state.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#build_state/2","title":"AntikytheraCore.PeriodicLog.Writer.State.build_state/2","type":"function"},{"doc":"Type-aware getter for log_state.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#log_state/1","title":"AntikytheraCore.PeriodicLog.Writer.State.log_state/1","type":"function"},{"doc":"Type-aware setter for log_state.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#log_state/2","title":"AntikytheraCore.PeriodicLog.Writer.State.log_state/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.PeriodicLog.Writer.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#new/1","title":"AntikytheraCore.PeriodicLog.Writer.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#new!/1","title":"AntikytheraCore.PeriodicLog.Writer.State.new!/1","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.PeriodicLog.Writer.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#update/2","title":"AntikytheraCore.PeriodicLog.Writer.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#update!/2","title":"AntikytheraCore.PeriodicLog.Writer.State.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#valid?/1","title":"AntikytheraCore.PeriodicLog.Writer.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.PeriodicLog.Writer.State.html#t:t/0","title":"AntikytheraCore.PeriodicLog.Writer.State.t/0","type":"type"},{"doc":"Generates a .appup file for the given application, start version, and upgrade version.The appup file generated by make/5 is much simpler than that by similar appup generation tools, as make/5 does not use update instruction (which is called &quot;synchronized code replacement&quot;). Synchronized code replacement (which uses code_change/3) is risky becauseIt's difficult to get it right, difficult to test.Suspending target processes entails traversing the whole supervision tree. All processes in the tree must respond to system messages in a timely manner.Processes governed by some libraries might not properly handle system messages; if it's the case all OTP applications will be restarted by :init.restart().Some process might not respond in a timely fashion; resulting in brutal kill of the unresponsive process.Suspending handling of non-system messages might cause performance issues.Therefore we simply don't use OTP's code change mechanism; to change data format of process state weimplement callbacks to check/convert the data format version, oravoid hot code upgrade and replace the working instances with new ones.On the other hand, make/5 automatically resolves interdependencies between changed modules (which other tools don't).Parameters for make/5name : the application name as an atomv1 : the start version, such as &quot;0.0.1&quot;v2 : the upgrade version, such as &quot;0.0.2&quot;v1_dir: the path to the v1 artifacts (rel/&lt;app&gt;/lib/&lt;app&gt;-0.0.1)v2_dir: the path to the v2 artifacts (_build/prod/lib/&lt;app&gt;)","ref":"AntikytheraCore.Release.Appup.html","title":"AntikytheraCore.Release.Appup","type":"module"},{"doc":"","ref":"AntikytheraCore.Release.Appup.html#make/5","title":"AntikytheraCore.Release.Appup.make/5","type":"function"},{"doc":"","ref":"AntikytheraCore.Request.html","title":"AntikytheraCore.Request","type":"module"},{"doc":"","ref":"AntikytheraCore.Request.html#make_from_cowboy_req/6","title":"AntikytheraCore.Request.make_from_cowboy_req/6","type":"function"},{"doc":"A GenServer which periodically removes already unused artifact files for running gears.&quot;Artifact files&quot; here means files created by unpacking OTP application tarballs of gears. Since gears as OTP applications are not included in OTP releases of antikythera instances, we can remove the artifact files directly; no coordination with :release_handler is required.Depends on AntikytheraCore.GearManager.","ref":"AntikytheraCore.StaleGearArtifactCleaner.html","title":"AntikytheraCore.StaleGearArtifactCleaner","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.StaleGearArtifactCleaner.html#child_spec/1","title":"AntikytheraCore.StaleGearArtifactCleaner.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.StaleGearArtifactCleaner.html#start_link/1","title":"AntikytheraCore.StaleGearArtifactCleaner.start_link/1","type":"function"},{"doc":"Manages progress of startup procedure of antikythera.Most of initialization steps are done within AntikytheraCore.start/2. However, the following step is not done in AntikytheraCore.start/2 and delayed:Installing gears: Starting a gear requires that the antikythera instance (as an OTP application) has started; this step is delegated to AntikytheraCore.VersionSynchronizer.This GenServer waits for the above procedures to complete and then changes the cowboy routing rules so that the current node can receive web requests from its upstream load balancer.","ref":"AntikytheraCore.StartupManager.html","title":"AntikytheraCore.StartupManager","type":"module"},{"doc":"","ref":"AntikytheraCore.StartupManager.html#all_gears_installed/0","title":"AntikytheraCore.StartupManager.all_gears_installed/0","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.StartupManager.html#child_spec/1","title":"AntikytheraCore.StartupManager.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.StartupManager.html#initialized?/0","title":"AntikytheraCore.StartupManager.initialized?/0","type":"function"},{"doc":"","ref":"AntikytheraCore.StartupManager.html#start_link/1","title":"AntikytheraCore.StartupManager.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.StartupManager.html#update_routing/1","title":"AntikytheraCore.StartupManager.update_routing/1","type":"function"},{"doc":"A GenServer that periodically submit metrics about the ErlangVM.Note that some values obtained from :erlang.statistics/1 are cumulative; we have to take diff from the previous values.reductionsbytes_inbytes_outgc_countgc_words_reclaimed","ref":"AntikytheraCore.SystemMetricsReporter.html","title":"AntikytheraCore.SystemMetricsReporter","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.SystemMetricsReporter.html#child_spec/1","title":"AntikytheraCore.SystemMetricsReporter.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.SystemMetricsReporter.html#start_link/1","title":"AntikytheraCore.SystemMetricsReporter.start_link/1","type":"function"},{"doc":"This is an implementation of EEx.Engine that auto-escape dynamic parts within HAML templates.","ref":"AntikytheraCore.TemplateEngine.html","title":"AntikytheraCore.TemplateEngine","type":"module"},{"doc":"","ref":"AntikytheraCore.TemplateEngine.html#to_safe_iodata/1","title":"AntikytheraCore.TemplateEngine.to_safe_iodata/1","type":"function"},{"doc":"A GenServer that caches tenant settings and apply changes to tenant executor pools.Original information of tenant settings is (typically) stored in a slow file storage. As reading many files may take long, such kind of file operations are done by one-off processes.Note that init/1 callback fetches all tenant settings and applies them in a blocking manner.Note also that there are two sources of tenant setting information that this GenServer receives:periodic scanning of filesnotification by GenServer.call(server, {:apply, tenant_id, tenant_setting}) (may be called using multi_call)Information given by the two sources may have conflicts, i.e. results from (1) may not include the latest info given by (2). In order not to kill working tenant executor pools, we don't immediately remove/disassociate executor pool that is not included in (1); those operations are delayed to the next :check.","ref":"AntikytheraCore.TenantExecutorPoolsManager.html","title":"AntikytheraCore.TenantExecutorPoolsManager","type":"module"},{"doc":"","ref":"AntikytheraCore.TenantExecutorPoolsManager.html#all/0","title":"AntikytheraCore.TenantExecutorPoolsManager.all/0","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.TenantExecutorPoolsManager.html#child_spec/1","title":"AntikytheraCore.TenantExecutorPoolsManager.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TenantExecutorPoolsManager.html#polling_interval/0","title":"AntikytheraCore.TenantExecutorPoolsManager.polling_interval/0","type":"function"},{"doc":"","ref":"AntikytheraCore.TenantExecutorPoolsManager.html#start_link/1","title":"AntikytheraCore.TenantExecutorPoolsManager.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TenantExecutorPoolsManager.OneOffFetcher.html","title":"AntikytheraCore.TenantExecutorPoolsManager.OneOffFetcher","type":"module"},{"doc":"","ref":"AntikytheraCore.TenantExecutorPoolsManager.OneOffFetcher.html#run/1","title":"AntikytheraCore.TenantExecutorPoolsManager.OneOffFetcher.run/1","type":"function"},{"doc":"A GenServer that periodically checks the status of Node.self/0.When this GenServer notices that this host is going to be terminated, it prepares for termination:deactivate RaftFleet so that all consensus members in this node will be migrated to other active nodesdeactivate AntikytheraCore.ExecutorPool.AsyncJobBrokers so that they don't start new async jobsDepends on AntikytheraCore.ClusterHostsPoller.","ref":"AntikytheraCore.TerminationManager.html","title":"AntikytheraCore.TerminationManager","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.TerminationManager.html#child_spec/1","title":"AntikytheraCore.TerminationManager.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TerminationManager.html#register_broker/0","title":"AntikytheraCore.TerminationManager.register_broker/0","type":"function"},{"doc":"","ref":"AntikytheraCore.TerminationManager.html#start_link/1","title":"AntikytheraCore.TerminationManager.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TerminationManager.State.html","title":"AntikytheraCore.TerminationManager.State","type":"module"},{"doc":"Type-aware getter for brokers.","ref":"AntikytheraCore.TerminationManager.State.html#brokers/1","title":"AntikytheraCore.TerminationManager.State.brokers/1","type":"function"},{"doc":"Type-aware setter for brokers.","ref":"AntikytheraCore.TerminationManager.State.html#brokers/2","title":"AntikytheraCore.TerminationManager.State.brokers/2","type":"function"},{"doc":"Type-aware getter for in_service?.","ref":"AntikytheraCore.TerminationManager.State.html#in_service?/1","title":"AntikytheraCore.TerminationManager.State.in_service?/1","type":"function"},{"doc":"Type-aware setter for in_service?.","ref":"AntikytheraCore.TerminationManager.State.html#in_service?/2","title":"AntikytheraCore.TerminationManager.State.in_service?/2","type":"function"},{"doc":"Type-aware getter for log_flushed?.","ref":"AntikytheraCore.TerminationManager.State.html#log_flushed?/1","title":"AntikytheraCore.TerminationManager.State.log_flushed?/1","type":"function"},{"doc":"Type-aware setter for log_flushed?.","ref":"AntikytheraCore.TerminationManager.State.html#log_flushed?/2","title":"AntikytheraCore.TerminationManager.State.log_flushed?/2","type":"function"},{"doc":"","ref":"AntikytheraCore.TerminationManager.State.html#new/0","title":"AntikytheraCore.TerminationManager.State.new/0","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.TerminationManager.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.TerminationManager.State.html#new/1","title":"AntikytheraCore.TerminationManager.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.TerminationManager.State.html#new!/1","title":"AntikytheraCore.TerminationManager.State.new!/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TerminationManager.State.html#next/2","title":"AntikytheraCore.TerminationManager.State.next/2","type":"function"},{"doc":"Type-aware getter for not_in_service_count.","ref":"AntikytheraCore.TerminationManager.State.html#not_in_service_count/1","title":"AntikytheraCore.TerminationManager.State.not_in_service_count/1","type":"function"},{"doc":"Type-aware setter for not_in_service_count.","ref":"AntikytheraCore.TerminationManager.State.html#not_in_service_count/2","title":"AntikytheraCore.TerminationManager.State.not_in_service_count/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.TerminationManager.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.TerminationManager.State.html#update/2","title":"AntikytheraCore.TerminationManager.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.TerminationManager.State.html#update!/2","title":"AntikytheraCore.TerminationManager.State.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.TerminationManager.State.html#valid?/1","title":"AntikytheraCore.TerminationManager.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TerminationManager.State.html#t:t/0","title":"AntikytheraCore.TerminationManager.State.t/0","type":"type"},{"doc":"A GenServer that keeps track of user pids of temporary directories.Temporary directories are created via calls to Antikythera.Tmpdir.make/2. This GenServer communicates with the caller process and monitors its death to make sure that the directories are eventually deleted.Currently we do not impose upper limit on volume and I/O usage since number of concurrently running processes is capped by executor pools. As a result we also skip checking association of &quot;executor pool&quot; and &quot;calling code (gear)&quot;.","ref":"AntikytheraCore.TmpdirTracker.html","title":"AntikytheraCore.TmpdirTracker","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.TmpdirTracker.html#child_spec/1","title":"AntikytheraCore.TmpdirTracker.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.html#finished/0","title":"AntikytheraCore.TmpdirTracker.finished/0","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.html#get/1","title":"AntikytheraCore.TmpdirTracker.get/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.html#request/1","title":"AntikytheraCore.TmpdirTracker.request/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.html#start_link/1","title":"AntikytheraCore.TmpdirTracker.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.State.html","title":"AntikytheraCore.TmpdirTracker.State","type":"module"},{"doc":"Type-aware getter for gear_tmp_dir.","ref":"AntikytheraCore.TmpdirTracker.State.html#gear_tmp_dir/1","title":"AntikytheraCore.TmpdirTracker.State.gear_tmp_dir/1","type":"function"},{"doc":"Type-aware setter for gear_tmp_dir.","ref":"AntikytheraCore.TmpdirTracker.State.html#gear_tmp_dir/2","title":"AntikytheraCore.TmpdirTracker.State.gear_tmp_dir/2","type":"function"},{"doc":"Type-aware getter for map.","ref":"AntikytheraCore.TmpdirTracker.State.html#map/1","title":"AntikytheraCore.TmpdirTracker.State.map/1","type":"function"},{"doc":"Type-aware setter for map.","ref":"AntikytheraCore.TmpdirTracker.State.html#map/2","title":"AntikytheraCore.TmpdirTracker.State.map/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.TmpdirTracker.State by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.TmpdirTracker.State.html#new/1","title":"AntikytheraCore.TmpdirTracker.State.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.TmpdirTracker.State.html#new!/1","title":"AntikytheraCore.TmpdirTracker.State.new!/1","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.TmpdirTracker.State with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.TmpdirTracker.State.html#update/2","title":"AntikytheraCore.TmpdirTracker.State.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.TmpdirTracker.State.html#update!/2","title":"AntikytheraCore.TmpdirTracker.State.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.TmpdirTracker.State.html#valid?/1","title":"AntikytheraCore.TmpdirTracker.State.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.State.html#t:t/0","title":"AntikytheraCore.TmpdirTracker.State.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.State.Map.html","title":"AntikytheraCore.TmpdirTracker.State.Map","type":"module"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.State.Map.html#valid?/1","title":"AntikytheraCore.TmpdirTracker.State.Map.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraCore.TmpdirTracker.State.Map.html#t:t/0","title":"AntikytheraCore.TmpdirTracker.State.Map.t/0","type":"type"},{"doc":"","ref":"AntikytheraCore.Version.html","title":"AntikytheraCore.Version","type":"module"},{"doc":"","ref":"AntikytheraCore.Version.html#current_version/1","title":"AntikytheraCore.Version.current_version/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.html#read_from_app_file/2","title":"AntikytheraCore.Version.read_from_app_file/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Artifact.html","title":"AntikytheraCore.Version.Artifact","type":"module"},{"doc":"","ref":"AntikytheraCore.Version.Artifact.html#copy_core_release_tgz/1","title":"AntikytheraCore.Version.Artifact.copy_core_release_tgz/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Artifact.html#gears_dir/0","title":"AntikytheraCore.Version.Artifact.gears_dir/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Artifact.html#unpack_gear_tgz/2","title":"AntikytheraCore.Version.Artifact.unpack_gear_tgz/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Core.html","title":"AntikytheraCore.Version.Core","type":"module"},{"doc":"","ref":"AntikytheraCore.Version.Core.html#upgrade_to_next_version/0","title":"AntikytheraCore.Version.Core.upgrade_to_next_version/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Gear.html","title":"AntikytheraCore.Version.Gear","type":"module"},{"doc":"","ref":"AntikytheraCore.Version.Gear.html#gear_dependencies_from_app_file/2","title":"AntikytheraCore.Version.Gear.gear_dependencies_from_app_file/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Gear.html#install_gears_at_startup/1","title":"AntikytheraCore.Version.Gear.install_gears_at_startup/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Gear.html#install_gears_whose_deps_met/4","title":"AntikytheraCore.Version.Gear.install_gears_whose_deps_met/4","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.Gear.html#install_or_upgrade_to_next_version/1","title":"AntikytheraCore.Version.Gear.install_or_upgrade_to_next_version/1","type":"function"},{"doc":"Functions to get information from &quot;history&quot; files.Antikythera uses history files to detect new deployable versions of antikythera instance and gears. Each of antikythera instance and gears has its own history file. The files reside in AntikytheraCore.Path.history_dir/0.When deploying a new version, after successfully generated a compiled artifact (tarball), antikythera's deploy script instructs the ErlangVM nodes by appending a line to the history file of the target OTP application. Each line takes either of the following forms:format of lineinstallableupgradabledeploy with hot code upgrade&lt;version&gt;truetruedeploy with hot code upgrade (canary)&lt;version&gt; canary=&lt;hosts&gt;falsehost in hostsdeploy without hot code upgrade&lt;version&gt; noupgradetruefalsedeploy without hot code upgrade (canary)&lt;version&gt; noupgrade_canary=&lt;deadline&gt;now &lt; deadlinefalse&quot;installable&quot; means that the version can be installed into a node that doesn't have the OTP application.See also script/in_cloud/erl/boot_impl.sh, which chooses an appropriate version of OTP release of the antikythera instance at startup of a newly created host.&quot;upgradable&quot; means that the version can be applied by hot code upgrade to a node that has a previous version of the OTP application.Versions in a history file are expected to monotonically increase.","ref":"AntikytheraCore.Version.History.html","title":"AntikytheraCore.Version.History","type":"module"},{"doc":"","ref":"AntikytheraCore.Version.History.html#all_deployable_gear_names/0","title":"AntikytheraCore.Version.History.all_deployable_gear_names/0","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.html#find_all_modified_history_files/1","title":"AntikytheraCore.Version.History.find_all_modified_history_files/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.html#latest_installable_gear_version/1","title":"AntikytheraCore.Version.History.latest_installable_gear_version/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.html#next_upgradable_version/2","title":"AntikytheraCore.Version.History.next_upgradable_version/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.Entry.html","title":"AntikytheraCore.Version.History.Entry","type":"module"},{"doc":"","ref":"AntikytheraCore.Version.History.Entry.html#canary?/1","title":"AntikytheraCore.Version.History.Entry.canary?/1","type":"function"},{"doc":"Type-aware getter for canary_target_hosts.","ref":"AntikytheraCore.Version.History.Entry.html#canary_target_hosts/1","title":"AntikytheraCore.Version.History.Entry.canary_target_hosts/1","type":"function"},{"doc":"Type-aware setter for canary_target_hosts.","ref":"AntikytheraCore.Version.History.Entry.html#canary_target_hosts/2","title":"AntikytheraCore.Version.History.Entry.canary_target_hosts/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.Entry.html#from_line/1","title":"AntikytheraCore.Version.History.Entry.from_line/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.Entry.html#installable?/1","title":"AntikytheraCore.Version.History.Entry.installable?/1","type":"function"},{"doc":"Type-aware getter for installable_until.","ref":"AntikytheraCore.Version.History.Entry.html#installable_until/1","title":"AntikytheraCore.Version.History.Entry.installable_until/1","type":"function"},{"doc":"Type-aware setter for installable_until.","ref":"AntikytheraCore.Version.History.Entry.html#installable_until/2","title":"AntikytheraCore.Version.History.Entry.installable_until/2","type":"function"},{"doc":"Creates a new instance of AntikytheraCore.Version.History.Entry by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraCore.Version.History.Entry.html#new/1","title":"AntikytheraCore.Version.History.Entry.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Version.History.Entry.html#new!/1","title":"AntikytheraCore.Version.History.Entry.new!/1","type":"function"},{"doc":"Type-aware getter for noupgrade.","ref":"AntikytheraCore.Version.History.Entry.html#noupgrade/1","title":"AntikytheraCore.Version.History.Entry.noupgrade/1","type":"function"},{"doc":"Type-aware setter for noupgrade.","ref":"AntikytheraCore.Version.History.Entry.html#noupgrade/2","title":"AntikytheraCore.Version.History.Entry.noupgrade/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraCore.Version.History.Entry with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraCore.Version.History.Entry.html#update/2","title":"AntikytheraCore.Version.History.Entry.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraCore.Version.History.Entry.html#update!/2","title":"AntikytheraCore.Version.History.Entry.update!/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.Entry.html#upgradable?/1","title":"AntikytheraCore.Version.History.Entry.upgradable?/1","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraCore.Version.History.Entry.html#valid?/1","title":"AntikytheraCore.Version.History.Entry.valid?/1","type":"function"},{"doc":"Type-aware getter for version.","ref":"AntikytheraCore.Version.History.Entry.html#version/1","title":"AntikytheraCore.Version.History.Entry.version/1","type":"function"},{"doc":"Type-aware setter for version.","ref":"AntikytheraCore.Version.History.Entry.html#version/2","title":"AntikytheraCore.Version.History.Entry.version/2","type":"function"},{"doc":"","ref":"AntikytheraCore.Version.History.Entry.html#t:t/0","title":"AntikytheraCore.Version.History.Entry.t/0","type":"type"},{"doc":"A GenServer which periodically polls deployable versions of antikythera instance and gears.On startup of antikythera, this GenServer waits for completion of AntikytheraCore.start/2, installs all available gears, notifies to StartupManager, and then starts periodic polling. Depends on StartupManager and VersionUpgradeTaskQueue.","ref":"AntikytheraCore.VersionSynchronizer.html","title":"AntikytheraCore.VersionSynchronizer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.VersionSynchronizer.html#child_spec/1","title":"AntikytheraCore.VersionSynchronizer.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.VersionSynchronizer.html#start_link/1","title":"AntikytheraCore.VersionSynchronizer.start_link/1","type":"function"},{"doc":"A GenServer to serialize tasks to &quot;upgrade of antikythera instance&quot; and &quot;installation or upgrade of gears&quot;.This is implemented as a GenServer for the purpose of preventing multiple install/upgrade from running concurrently. As each installation/upgrade can take much longer than 5-seconds timeout of system messages, the actual task is delegated to one-off processes.","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html","title":"AntikytheraCore.VersionUpgradeTaskQueue","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html#child_spec/1","title":"AntikytheraCore.VersionUpgradeTaskQueue.child_spec/1","type":"function"},{"doc":"","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html#core_updated/0","title":"AntikytheraCore.VersionUpgradeTaskQueue.core_updated/0","type":"function"},{"doc":"","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html#disable/0","title":"AntikytheraCore.VersionUpgradeTaskQueue.disable/0","type":"function"},{"doc":"","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html#enable/0","title":"AntikytheraCore.VersionUpgradeTaskQueue.enable/0","type":"function"},{"doc":"","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html#gear_updated/1","title":"AntikytheraCore.VersionUpgradeTaskQueue.gear_updated/1","type":"function"},{"doc":"","ref":"AntikytheraCore.VersionUpgradeTaskQueue.html#start_link/1","title":"AntikytheraCore.VersionUpgradeTaskQueue.start_link/1","type":"function"},{"doc":"","ref":"AntikytheraCore.Vm.html","title":"AntikytheraCore.Vm","type":"module"},{"doc":"","ref":"AntikytheraCore.Vm.html#count_messages_in_all_mailboxes/0","title":"AntikytheraCore.Vm.count_messages_in_all_mailboxes/0","type":"function"},{"doc":"Environment abstraction layer: pluggable interfaces defined in antikythera.(This module exists solely for documentation purpose and thus contains only this @moduledoc.)Some of antikythera's features are pluggable so that one can use environment-specific implementations. For example, in order to maintain cluster membership, list of currently running ErlangVM nodes may be obtained from the IaaS platform API.Administrators of an antikythera instance must provide the set of concrete callback modules suitable for their environments. The callback modules to be used by antikythera must be specified as :eal_impl_modules key in mix configs. Note that :eal_impl_modules are resolved at compile time. This means:compiling antikythera requires the callback modules for all behaviours, andto change any of the callback modules you have to recompile antikythera.Module naming scheme for each interfaceAll pluggable interfaces are defined as behaviour modules and named as AntikytheraEal.SomeFeature.Behaviour (e.g. AntikytheraEal.ClusterConfiguration.Behaviour). Each behaviour comes with a concrete callback module which is used for tests of antikythera (e.g. AntikytheraEal.ClusterConfiguration.StandAlone). The parent module (e.g. AntikytheraEal.ClusterConfiguration) works as a proxy module when invoking the callback functions of the module specified in mix config (see also AntikytheraEal.ImplChooser).","ref":"AntikytheraEal.html","title":"AntikytheraEal","type":"module"},{"doc":"","ref":"AntikytheraEal.AlertMailer.html","title":"AntikytheraEal.AlertMailer","type":"module"},{"doc":"Interface to email delivery backend for core/gear alerts.See AntikytheraEal for common information about pluggable interfaces defined in antikythera.","ref":"AntikytheraEal.AlertMailer.Behaviour.html","title":"AntikytheraEal.AlertMailer.Behaviour","type":"behaviour"},{"doc":"Sends an alert email.CC/BCC and HTML mail is omitted for simplicity.This callback is called in AntikytheraCore.Alert.Handler.Email, that is, when an alert email about error(s) in either antikythera core or gear is sent.","ref":"AntikytheraEal.AlertMailer.Behaviour.html#c:deliver/1","title":"AntikytheraEal.AlertMailer.Behaviour.deliver/1","type":"callback"},{"doc":"","ref":"AntikytheraEal.AlertMailer.Mail.html","title":"AntikytheraEal.AlertMailer.Mail","type":"module"},{"doc":"Type-aware getter for body.","ref":"AntikytheraEal.AlertMailer.Mail.html#body/1","title":"AntikytheraEal.AlertMailer.Mail.body/1","type":"function"},{"doc":"Type-aware setter for body.","ref":"AntikytheraEal.AlertMailer.Mail.html#body/2","title":"AntikytheraEal.AlertMailer.Mail.body/2","type":"function"},{"doc":"Type-aware getter for from.","ref":"AntikytheraEal.AlertMailer.Mail.html#from/1","title":"AntikytheraEal.AlertMailer.Mail.from/1","type":"function"},{"doc":"Type-aware setter for from.","ref":"AntikytheraEal.AlertMailer.Mail.html#from/2","title":"AntikytheraEal.AlertMailer.Mail.from/2","type":"function"},{"doc":"Creates a new instance of AntikytheraEal.AlertMailer.Mail by using the given dict.Returns {:ok, valid_struct} or {:error, reason}.The values in the dict are validated by each field's valid?/1 function. If the value was invalid, it will be passed to new/1 of the fieldFor missing fields, followings will be tried:default/0 of each field typenew/1 of each field type, with empty map as input","ref":"AntikytheraEal.AlertMailer.Mail.html#new/1","title":"AntikytheraEal.AlertMailer.Mail.new/1","type":"function"},{"doc":"A variant of new/1 which returns t or raise if validation fails.In other words, new/1 followed by Croma.Result.get!/1.","ref":"AntikytheraEal.AlertMailer.Mail.html#new!/1","title":"AntikytheraEal.AlertMailer.Mail.new!/1","type":"function"},{"doc":"Type-aware getter for subject.","ref":"AntikytheraEal.AlertMailer.Mail.html#subject/1","title":"AntikytheraEal.AlertMailer.Mail.subject/1","type":"function"},{"doc":"Type-aware setter for subject.","ref":"AntikytheraEal.AlertMailer.Mail.html#subject/2","title":"AntikytheraEal.AlertMailer.Mail.subject/2","type":"function"},{"doc":"Type-aware getter for to.","ref":"AntikytheraEal.AlertMailer.Mail.html#to/1","title":"AntikytheraEal.AlertMailer.Mail.to/1","type":"function"},{"doc":"Type-aware setter for to.","ref":"AntikytheraEal.AlertMailer.Mail.html#to/2","title":"AntikytheraEal.AlertMailer.Mail.to/2","type":"function"},{"doc":"Updates an existing instance of AntikytheraEal.AlertMailer.Mail with the given dict. The values in the dict are validated by each field's valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}.","ref":"AntikytheraEal.AlertMailer.Mail.html#update/2","title":"AntikytheraEal.AlertMailer.Mail.update/2","type":"function"},{"doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1.","ref":"AntikytheraEal.AlertMailer.Mail.html#update!/2","title":"AntikytheraEal.AlertMailer.Mail.update!/2","type":"function"},{"doc":"Checks if the given value belongs to t/0 or not.","ref":"AntikytheraEal.AlertMailer.Mail.html#valid?/1","title":"AntikytheraEal.AlertMailer.Mail.valid?/1","type":"function"},{"doc":"","ref":"AntikytheraEal.AlertMailer.Mail.html#t:t/0","title":"AntikytheraEal.AlertMailer.Mail.t/0","type":"type"},{"doc":"","ref":"AntikytheraEal.AlertMailer.MemoryInbox.html","title":"AntikytheraEal.AlertMailer.MemoryInbox","type":"module"},{"doc":"","ref":"AntikytheraEal.AlertMailer.MemoryInbox.html#clean/0","title":"AntikytheraEal.AlertMailer.MemoryInbox.clean/0","type":"function"},{"doc":"","ref":"AntikytheraEal.AlertMailer.MemoryInbox.html#get/0","title":"AntikytheraEal.AlertMailer.MemoryInbox.get/0","type":"function"},{"doc":"","ref":"AntikytheraEal.AssetStorage.html","title":"AntikytheraEal.AssetStorage","type":"module"},{"doc":"Interface to work with storage of asset files.See AntikytheraEal for common information about pluggable interfaces defined in antikythera.All callbacks defined in this behaviour are called only within operational mix tasks; they are not used at runtime.Asset files stored in the storage may be delivered via CDN. It's the callback module's responsibility to properly set headers such as cache-control for each asset file.","ref":"AntikytheraEal.AssetStorage.Behaviour.html","title":"AntikytheraEal.AssetStorage.Behaviour","type":"behaviour"},{"doc":"Deletes an asset file identified by the given key.","ref":"AntikytheraEal.AssetStorage.Behaviour.html#c:delete/1","title":"AntikytheraEal.AssetStorage.Behaviour.delete/1","type":"callback"},{"doc":"Lists all already-stored asset files for the specified gear.","ref":"AntikytheraEal.AssetStorage.Behaviour.html#c:list/1","title":"AntikytheraEal.AssetStorage.Behaviour.list/1","type":"callback"},{"doc":"Lists common key prefixes of all already-stored asset files for all gears.Based on the key format defined in Antikythera.Asset, the prefixes are expected to be the list of gear names which have already-stored asset files.","ref":"AntikytheraEal.AssetStorage.Behaviour.html#c:list_toplevel_prefixes/0","title":"AntikytheraEal.AssetStorage.Behaviour.list_toplevel_prefixes/0","type":"callback"},{"doc":"Uploads the given asset file to the storage.Parameters:path : File path of the asset file to upload.key : Upload location (typically path part of URL) for the asset file (computed by Antikythera.Asset).mime : MIME type of the asset file.gzip?: Whether gzip compression is beneficial for the asset file.","ref":"AntikytheraEal.AssetStorage.Behaviour.html#c:upload/4","title":"AntikytheraEal.AssetStorage.Behaviour.upload/4","type":"callback"},{"doc":"","ref":"AntikytheraEal.AssetStorage.NoOp.html","title":"AntikytheraEal.AssetStorage.NoOp","type":"module"},{"doc":"","ref":"AntikytheraEal.ClusterConfiguration.html","title":"AntikytheraEal.ClusterConfiguration","type":"module"},{"doc":"Interface for cluster membership.See AntikytheraEal for common information about pluggable interfaces defined in antikythera.","ref":"AntikytheraEal.ClusterConfiguration.Behaviour.html","title":"AntikytheraEal.ClusterConfiguration.Behaviour","type":"behaviour"},{"doc":"Returns the number of seconds for which the initial health check to this host is delayed to provide ample warm-up time for the host.This callback is called only at startup and the return value is used to calculate the trial count for establishing connections to other nodes.","ref":"AntikytheraEal.ClusterConfiguration.Behaviour.html#c:health_check_grace_period_in_seconds/0","title":"AntikytheraEal.ClusterConfiguration.Behaviour.health_check_grace_period_in_seconds/0","type":"callback"},{"doc":"Lists running ErlangVM nodes for the current deployment.On success this callback must return a map where each key is hostname (String.t) of a running node and each value is a boolean value representing whether the node is &quot;active&quot; or not. &quot;Inactive&quot; node is treated as during decommission process.This callback is at the startup of each node in order to join the existing cluster. After successful startup, this callback is called periodically so thatall running nodes in the cluster maintain connections to each other, andeach node can notice and cleanup when it is about to be terminated.","ref":"AntikytheraEal.ClusterConfiguration.Behaviour.html#c:running_hosts/0","title":"AntikytheraEal.ClusterConfiguration.Behaviour.running_hosts/0","type":"callback"},{"doc":"Returns identifier of the data center zone in which current node is running.This callback is called only at startup and the return value is passed to RaftFleet.activate/1.","ref":"AntikytheraEal.ClusterConfiguration.Behaviour.html#c:zone_of_this_host/0","title":"AntikytheraEal.ClusterConfiguration.Behaviour.zone_of_this_host/0","type":"callback"},{"doc":"","ref":"AntikytheraEal.ClusterConfiguration.StandAlone.html","title":"AntikytheraEal.ClusterConfiguration.StandAlone","type":"module"},{"doc":"","ref":"AntikytheraEal.ImplChooser.html","title":"AntikytheraEal.ImplChooser","type":"module"},{"doc":"","ref":"AntikytheraEal.ImplChooser.html#extract_impl_module/1","title":"AntikytheraEal.ImplChooser.extract_impl_module/1","type":"function"},{"doc":"","ref":"AntikytheraEal.ImplChooser.html#make_vars/2","title":"AntikytheraEal.ImplChooser.make_vars/2","type":"function"},{"doc":"","ref":"AntikytheraEal.LogStorage.html","title":"AntikytheraEal.LogStorage","type":"module"},{"doc":"Interface to work with storage of gear log files.See AntikytheraEal for common information about pluggable interfaces defined in antikythera.Gear's log messages are written to a file in local filesystem (by AntikytheraCore.GearLog.Writer). Log files are then rotated after certain times and then uploaded to log storage.Typically rotated log files are uploaded by a script that runs outside of antikythera, in order to correctly upload logs even after ErlangVM crashes. upload_rotated_logs/1 can also be used to upload logs to the storage, but this callback is basically intended for on-demand (i.e. gear administrator initiated) uploads.","ref":"AntikytheraEal.LogStorage.Behaviour.html","title":"AntikytheraEal.LogStorage.Behaviour","type":"behaviour"},{"doc":"Generates download URLs of multiple log files specified by list of keys.Keys can be obtained by list/2.","ref":"AntikytheraEal.LogStorage.Behaviour.html#c:download_urls/1","title":"AntikytheraEal.LogStorage.Behaviour.download_urls/1","type":"callback"},{"doc":"Lists already-uploaded log files, whose last log messages are generated on the specified date, of a gear.date_str is of the form of &quot;20180101&quot;.Returns list of pairs, where each pair consists ofkey which identifies the log filesize of the log file","ref":"AntikytheraEal.LogStorage.Behaviour.html#c:list/2","title":"AntikytheraEal.LogStorage.Behaviour.list/2","type":"callback"},{"doc":"Upload all log files which have already been rotated but not yet uploaded.","ref":"AntikytheraEal.LogStorage.Behaviour.html#c:upload_rotated_logs/1","title":"AntikytheraEal.LogStorage.Behaviour.upload_rotated_logs/1","type":"callback"},{"doc":"","ref":"AntikytheraEal.LogStorage.FileSystem.html","title":"AntikytheraEal.LogStorage.FileSystem","type":"module"},{"doc":"","ref":"AntikytheraEal.MetricsStorage.html","title":"AntikytheraEal.MetricsStorage","type":"module"},{"doc":"","ref":"AntikytheraEal.MetricsStorage.html#save/2","title":"AntikytheraEal.MetricsStorage.save/2","type":"function"},{"doc":"","ref":"AntikytheraEal.MetricsStorage.html#t:metrics_per_unit/0","title":"AntikytheraEal.MetricsStorage.metrics_per_unit/0","type":"type"},{"doc":"Interface to storage for metrics data.See AntikytheraEal for common information about pluggable interfaces defined in antikythera.Metrics data generated during runtime is buffered for a while by AntikytheraCore.MetricsUploader processes and then transferred to metrics storage using upload/3 callback.","ref":"AntikytheraEal.MetricsStorage.Behaviour.html","title":"AntikytheraEal.MetricsStorage.Behaviour","type":"behaviour"},{"doc":"Uploads the metrics data to the metrics storage.otp_app_name is either a gear name or :antikythera. node_id is the name of the current node and callback implementation may include node_id in the body of the upload.","ref":"AntikytheraEal.MetricsStorage.Behaviour.html#c:upload/3","title":"AntikytheraEal.MetricsStorage.Behaviour.upload/3","type":"callback"},{"doc":"","ref":"AntikytheraEal.MetricsStorage.Memory.html","title":"AntikytheraEal.MetricsStorage.Memory","type":"module"},{"doc":"Retrieve metrics in memory for testing.","ref":"AntikytheraEal.MetricsStorage.Memory.html#download/4","title":"AntikytheraEal.MetricsStorage.Memory.download/4","type":"function"},{"doc":"","ref":"AntikytheraLocal.Cmd.html","title":"AntikytheraLocal.Cmd","type":"module"},{"doc":"","ref":"AntikytheraLocal.Cmd.html#exec_and_output_log!/3","title":"AntikytheraLocal.Cmd.exec_and_output_log!/3","type":"function"},{"doc":"","ref":"AntikytheraLocal.NodeName.html","title":"AntikytheraLocal.NodeName","type":"module"},{"doc":"","ref":"AntikytheraLocal.NodeName.html#get/0","title":"AntikytheraLocal.NodeName.get/0","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html","title":"AntikytheraLocal.RunningEnvironment","type":"module"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#currently_running_os_process_ids/0","title":"AntikytheraLocal.RunningEnvironment.currently_running_os_process_ids/0","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#prepare_new_version_of_core/1","title":"AntikytheraLocal.RunningEnvironment.prepare_new_version_of_core/1","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#prepare_new_version_of_gear/2","title":"AntikytheraLocal.RunningEnvironment.prepare_new_version_of_gear/2","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#setup/1","title":"AntikytheraLocal.RunningEnvironment.setup/1","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#teardown/0","title":"AntikytheraLocal.RunningEnvironment.teardown/0","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#unpacked_gears_dir/0","title":"AntikytheraLocal.RunningEnvironment.unpacked_gears_dir/0","type":"function"},{"doc":"","ref":"AntikytheraLocal.RunningEnvironment.html#wait_until_upgrade_applied/2","title":"AntikytheraLocal.RunningEnvironment.wait_until_upgrade_applied/2","type":"function"},{"doc":"","ref":"AntikytheraLocal.StartScript.html","title":"AntikytheraLocal.StartScript","type":"module"},{"doc":"","ref":"AntikytheraLocal.StartScript.html#run/2","title":"AntikytheraLocal.StartScript.run/2","type":"function"},{"doc":"Generates a mix project for a new gear application.UsageThis mix task must be run from a mix project directory of either your antikythera instance or one of gears in your antikythera instance.mix antikythera.gear.new PATHBasename of PATH becomes the name of your gear. For example, if ~/workspace/my_gear is used, my_gear becomes your gear name.Newly generated gear automatically belongs to an antikythera instance inferred from the mix project you are currently in.You can also manually specify your antikythera instance via ANTIKYTHERA_INSTANCE_DEP environment variable like so:ANTIKYTHERA_INSTANCE_DEP=&#39;{:instance_name, [git: &quot;git@github.com:your-organization/instance_name.git&quot;]}&#39; mix antikythera.gear.new PATHANTIKYTHERA_INSTANCE_DEP must be a valid dependency tuple used in mix.exs files. See mix deps doc for available options.Symbolic links to files in your antikythera instanceIn order to sync development environment configurations with your antikythera instance and other gears, this generator creates symbolic links to these files, if they exist in the current directory:.credo.exsConfiguration file for static code analysis tool Credo.tool-versionsLocal versions file for version manager tool asdf","ref":"Mix.Tasks.Antikythera.Gear.New.html","title":"Mix.Tasks.Antikythera.Gear.New","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Antikythera.Gear.New.html#run/1","title":"Mix.Tasks.Antikythera.Gear.New.run/1","type":"function"},{"doc":"Prepares static assets for your gear.This mix task is called right before compilations of the gear in antikythera's auto-deploy script. It ensures all static assets of your gear reside in priv/static/ directory before compilations of YourGear.Asset module. Assets in priv/static/ directory will then be uploaded to cloud storage for serving via CDN. See Antikythera.Asset for details.If your gear uses some kind of preprocessing tools to generate asset files (JS, CSS, etc.), you have to set up the supported asset preparation method described in the next section.Normally you do not have to invoke this mix task when you locally develop your assets. Though you may do so in order to confirm asset preparation is working as you intended.This mix task invokes the preprocessing tools with ANTIKYTHERA_COMPILE_ENV environment variable (see also Antikythera.Env). You can use this environment variable to distinguish for which environment current script is running.Supported Asset Preparation MethodAsset preparation process is split into two steps: package installation step and build step. If any part of the preparation process resulted in failure (non-zero exit code), the whole task will abort and thus auto-deploy will fail.Prerequisite: package.json file and antikythera_prepare_assets script in itNote that if the above prerequisite is not present, the whole asset preparation process will be skipped since package installation is unnecessary.Package InstallationUse yarn if yarn.lock file exists, otherwise use npm install.Build using npm-scriptsCommand: npm run antikythera_prepare_assetsWithin antikythera_prepare_assets script, you may execute any asset-related actions such as:LintingType CheckingTestingCompiling/TranspilingUglifying/Minifyingetc...How to organize these actions is up to you. You may use whatever tools available in npm, such as webpack or browserify.Note on implementationThis step is responsible for placing finalized static assets into priv/static/ directory.In old versions of gear_generator, Node.js packages that depend on compass was used by default in generated gear. compass gem was (and is) globally installed on antikythera jenkins server to enable them.However, compass is no longer maintained. We recommend you to consider using alternative SASS/SCSS processor. compass gem will be kept installed for backward compatibility.","ref":"Mix.Tasks.Antikythera.PrepareAssets.html","title":"Mix.Tasks.Antikythera.PrepareAssets","type":"task"},{"doc":"","ref":"Mix.Tasks.Antikythera.PrepareAssets.html#dump_asset_file_paths/0","title":"Mix.Tasks.Antikythera.PrepareAssets.dump_asset_file_paths/0","type":"function"},{"doc":"","ref":"Mix.Tasks.Antikythera.PrepareAssets.html#run_command/3","title":"Mix.Tasks.Antikythera.PrepareAssets.run_command/3","type":"function"},{"doc":"","ref":"Mix.Tasks.Antikythera.PrepareAssets.html#run_command!/3","title":"Mix.Tasks.Antikythera.PrepareAssets.run_command!/3","type":"function"},{"doc":"","ref":"Mix.Tasks.Antikythera.PrintVersion.html","title":"Mix.Tasks.Antikythera.PrintVersion","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Antikythera.PrintVersion.html#run/1","title":"Mix.Tasks.Antikythera.PrintVersion.run/1","type":"function"},{"doc":"Deletes obsolete asset files in asset storage.To judge whether each asset file should be kept or deleted we use &quot;asset list file&quot;s. Each asset list file is created during deployment of a gear version (see Mix.Tasks.AntikytheraCore.UploadNewAssetVersions).Based on the asset retention policy described in the moduledoc of Antikythera.Asset, it can be seen that, within all existing asset list files, only the following ones are relevant:asset list files created within the latest 90 daysthe latest asset list file among ones created up to 90 days beforeAssets included in any of the relevant asset list files should be kept. Assets not included in all of the relevant asset list files are &quot;obsolete&quot;; they should be deleted.","ref":"Mix.Tasks.AntikytheraCore.DeleteObsoleteAssets.html","title":"Mix.Tasks.AntikytheraCore.DeleteObsoleteAssets","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraCore.DeleteObsoleteAssets.html#run/1","title":"Mix.Tasks.AntikytheraCore.DeleteObsoleteAssets.run/1","type":"function"},{"doc":"Generates an appup file using the previous version located at the specified directory.This task is invoked during gear deployments.","ref":"Mix.Tasks.AntikytheraCore.GenerateAppup.html","title":"Mix.Tasks.AntikytheraCore.GenerateAppup","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraCore.GenerateAppup.html#run/1","title":"Mix.Tasks.AntikytheraCore.GenerateAppup.run/1","type":"function"},{"doc":"Generates a new release tarball for antikythera instance using relx.Notes on the implementation details of this task:Release generation is basically done under rel_erlang-*/. During tests (i.e. when ANTIKYTHERA_COMPILE_ENV=local), files are generated under rel_local_erlang-*/.Erlang/OTP major version number is included in the path in order to distinguish artifacts generated by different OTP releases. No binary compatibility is maintained by major version release of Erlang/OTP due to precompilation of Elixir's regex sigils. For more details see documentation for Regex module.Generated releases are placed under rel(_local)_erlang-*/&lt;antikythera_instance&gt;/releases/.If no previous releases found, this task generates a new release from scratch (i.e. without relup). If any previous releases exist, relup file to upgrade from the latest existing release to the current release is also generated.Making a new release tarball consists of the following steps:Preparation.beam and .app files.vm.args: resides in the git repository and is copied to the release by relx's overlay mechanism.sys.config: generated from mix config and then copied to the release by relx's overlay mechanism.relx.config: generated from relx.config.eex.Release generationIf needed, generate .appup files and relup file.Generate a new release from the input files by :relx.do/2.CleanupMove some files and apply patch to boot script, in order to suit our needs.Make a tarball. This step also uses :relx.do/2.Remove temporary files.","ref":"Mix.Tasks.AntikytheraCore.GenerateRelease.html","title":"Mix.Tasks.AntikytheraCore.GenerateRelease","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraCore.GenerateRelease.html#run/1","title":"Mix.Tasks.AntikytheraCore.GenerateRelease.run/1","type":"function"},{"doc":"Uploads assets to asset storage so that they can be delivered via CDN.This mix task is invoked during gear deployment from within each gear project.","ref":"Mix.Tasks.AntikytheraCore.UploadNewAssetVersions.html","title":"Mix.Tasks.AntikytheraCore.UploadNewAssetVersions","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraCore.UploadNewAssetVersions.html#run/1","title":"Mix.Tasks.AntikytheraCore.UploadNewAssetVersions.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.PrepareCore.html","title":"Mix.Tasks.AntikytheraLocal.PrepareCore","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraLocal.PrepareCore.html#run/1","title":"Mix.Tasks.AntikytheraLocal.PrepareCore.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.PrepareGear.html","title":"Mix.Tasks.AntikytheraLocal.PrepareGear","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraLocal.PrepareGear.html#run/1","title":"Mix.Tasks.AntikytheraLocal.PrepareGear.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.Start.html","title":"Mix.Tasks.AntikytheraLocal.Start","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraLocal.Start.html#run/1","title":"Mix.Tasks.AntikytheraLocal.Start.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.Stop.html","title":"Mix.Tasks.AntikytheraLocal.Stop","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraLocal.Stop.html#run/1","title":"Mix.Tasks.AntikytheraLocal.Stop.run/1","type":"function"},{"doc":"Runs tests to ensure that antikythera's upgrade doesn't break backward-compatibility.It works in the following sequence:Starts an antikythera instance of a version specified by a git ref, with gears in specified directories installed(If testgear is used, establishes websocket connection to testgear. Periodically sends echo requests)Upgrades the antikythera instance to new version specified by another git refRun blackbox tests defined in each gear, checking whether their external behaviors are kept intact(Raises if the websocket connection established above was abnormally closed before here)Usage$ mix antikythera_local.upgrade_compatibility_test &lt;comma_separated_gear_directories&gt; [git_ref_from[ git_ref_to]]comma_separated_gear_directories can be absolute or relative paths to directories, such as ../testgear,/path/to/another_gear.It assumes basenames of paths exactly match gear_names, for testgear detection.git_ref_from defaults to HEAD^. git_ref_to defaults to HEAD.","ref":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.html","title":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.html#run/1","title":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.WS.html","title":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.WS","type":"task"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.WS.html#send_loop/0","title":"Mix.Tasks.AntikytheraLocal.UpgradeCompatibilityTest.WS.send_loop/0","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest","type":"task"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_application_configs/0","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_application_configs/0","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_healthcheck_and_gear_endpoints/0","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_healthcheck_and_gear_endpoints/0","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_new_version_is_applied/4","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_new_version_is_applied/4","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_new_version_with_noupgrade_is_not_applied/4","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_new_version_with_noupgrade_is_not_applied/4","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_repository_is_clean/1","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_repository_is_clean/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_testgear_artifact_dirs/1","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_testgear_artifact_dirs/1","type":"function"},{"doc":"","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#check_version/2","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.check_version/2","type":"function"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.html#run/1","title":"Mix.Tasks.AntikytheraLocal.VersionUpgradeTest.run/1","type":"function"},{"doc":"Ensures only gear applications are specifed in gear_deps/0.","ref":"Mix.Tasks.Compile.EnsureGearDependencies.html","title":"Mix.Tasks.Compile.EnsureGearDependencies","type":"task"},{"doc":"Statically checks issues in gear's source code.Since antikythera is designed to run multiple gears within an ErlangVM, it assumes that each gearis implemented so that it can run side-by-side with other gears, anddoes not disturb resource allocation controlled by antikythera.This task is integrated into mix compile command so that these issues are detected each time gear's source code is compiled.","ref":"Mix.Tasks.Compile.GearStaticAnalysis.html","title":"Mix.Tasks.Compile.GearStaticAnalysis","type":"task"},{"doc":"Callback implementation for Mix.Task.Compiler.run/1.","ref":"Mix.Tasks.Compile.GearStaticAnalysis.html#run/1","title":"Mix.Tasks.Compile.GearStaticAnalysis.run/1","type":"function"},{"doc":"Touches source files that need to be recompiled.Normally mix automatically resolves which source files to recompile based on file modification times. However some macro-related code modifications do not trigger recompilation. This mix task finds those kinds of modifications and touch files to compile so that subsequent task recompiles them.Note that @external_resource module attribute does not support directory as external dependency of a module. For a module that depends on all files under a directory, we have to manually check the latest modification time of the whole directory tree.Current targets of this task are:mix.exs files in gear projects depend on mix_common.exs in the antikythera repository. Mix assumes that project configurations reside only in mix.exs and config/*.exs, so even if mix_common.exs has been modified mix does not notice. Note that antikythera's mix.exs also depends on mix_common.exs but it's handled differently (at the beginning of mix.exs), because we can't run mix tasks before it's compiled!SomeGear.Template module depends on all existing HAML templates in web/template/.Similarly, SomeGear.Asset module depends on all asset files in priv/static/. Although SomeGear.Asset is recompiled after modifying an asset file, it doesn't automatically trigger recompilation/reload in iex session because priv/static/** is not monitored by :exsync (in current configuration).","ref":"Mix.Tasks.Compile.PropagateFileModifications.html","title":"Mix.Tasks.Compile.PropagateFileModifications","type":"task"},{"doc":"Callback implementation for Mix.Task.Compiler.run/1.","ref":"Mix.Tasks.Compile.PropagateFileModifications.html#run/1","title":"Mix.Tasks.Compile.PropagateFileModifications.run/1","type":"function"},{"doc":"Antikythera FrameworkAntikythera is an Elixir framework to build your own in-house PaaS (Platform as a Service).You can run multiple web services while managing only a single cluster of ErlangVM nodes. From the viewpoint of service developers antikythera provides FaaS(Function as a Service)-like development experiences.Note: Antikythera is already used in production at ACCESS, though as an OSS, it is still in early development stage and missing many components. Please be aware of that, and stay tuned for further additions!","ref":"readme.html","title":"Antikythera Framework","type":"extras"},{"doc":"As a platform for multiple services:Resource control for multi-service and multi-tenant use casesAutomated deployment without affecting other running servicesBuilt-in logging, monitoring and configuration managementService-to-service communications without network overheadAs a web framework:HTTP request processing with arbitrary Elixir code with WebSocket supportDomain-based routing for multiple services; path-based routing within single serviceCDN support for static contents, HAML template for dynamic web pagesAs an asynchronous job executor:Built-in distributed job queuesRunning arbitrary Elixir code for each job","ref":"readme.html#features","title":"Antikythera Framework - Features","type":"extras"},{"doc":"We refer to each antikythera cluster as an &quot;antikythera instance&quot;, and each web service running within an antikythera instance as a &quot;gear&quot;.Antikythera Instance example: antikythera_instance_exampleGear example: testgearThese two projects are also used for antikythera's test.Antikythera is heavily dependent on the power of ErlangVM.Antikythera is written in Elixir, and all gears must also be written in Elixir.Multiple gears are co-located and executed within the same ErlangVMs of an antikythera instance.This type of co-location of multiple applications are sometimes referred to as &quot;nano-services architecture&quot;.This way we can eliminate the infrastructure/operational cost for having multiple web application stacks.Also, inter-service communications in a micro-services architecture become gear-to-gear communications in this nano-services architecture. Unlike micro-services architecture, it doesn't require network roundtrip as all gears are running within a single ErlangVM, resulting in lower communication overhead.Although gears share the same computing resources, they are executed in an independent manner thanks to the Erlang's process model.Antikythera instance and its gears are all separate mix projects.Developers of different gears can work on their own projects, independently.Library dependencies are defined per-antikythera-instance, and all gears inherit those dependencies.","ref":"readme.html#basic-architecture","title":"Antikythera Framework - Basic architecture","type":"extras"},{"doc":"See our Getting Started guide!","ref":"readme.html#getting-started","title":"Antikythera Framework - Getting Started","type":"extras"},{"doc":"For antikythera instance administrators (TBD)For gear developers (i.e. developers of web services)API Reference","ref":"readme.html#documentation","title":"Antikythera Framework - Documentation","type":"extras"},{"doc":"We encourage you to contribute to antikythera! Please check out our Contributing Guide.For both core and gear development, please make use of our Style Guide.Issue TrackerUsers Mailing List","ref":"readme.html#contributing","title":"Antikythera Framework - Contributing","type":"extras"},{"doc":"Copyright(c) 2015-2021 ACCESS CO., LTD. All rights reserved.Antikythera source code is licensed under the Apache License version 2.0.","ref":"readme.html#copyright-and-license","title":"Antikythera Framework - Copyright and License","type":"extras"},{"doc":"Antikythera Style GuideOverall policy:Be consistent within a chunk of your changes.Be consistent with surrounding code.Make use of this (and linked) Style Guides when in doubt.Ask and discuss!","ref":"style_guide.html","title":"Antikythera Style Guide","type":"extras"},{"doc":"We are mostly following Credo's Elixir Style Guide.Styles marked as preferred in the Credo's guide are mostly used.If you find yourself lost about coding style, always search in existing code for similarities. Or just ask in a Pull Request or Users ML.As a side-reading, A community driven style guide for Elixir is also available. We are not compliant with all of it, but it provides good advices.Note: Although we are mostly following its style guide, we are not completely relying on Credo static analysis.","ref":"style_guide.html#guidelines","title":"Antikythera Style Guide - Guidelines","type":"extras"},{"doc":"Typespecs are useful for both documentation purpose and success typing analysis (dialyzer). So it's preferred to explicitly declare typespecs of functions, especially for public ones.We are utilizing Croma.Defun series for easy typespec notations.Example:@type timed_id_t :: {pos_integer, reference} defun five_params_fun(key :: v[atom], some_str :: v[String.t], key_list :: [atom], timed_id :: timed_id_t, state :: v[map]) :: :ok | {:error, term} do # Do something endAlso, use v[] validation where applicable. See Croma.Defun for details. Note that validations of arguments by v[] are disabled when compiling for production environment.Do not hesitate to put typespecs on complicated private functions too.","ref":"style_guide.html#typespec","title":"Antikythera Style Guide - Typespec","type":"extras"},{"doc":"For module names we simply use CamelCase even if they contain acronyms. For instance we use Antikythera.Url, not Antikythera.URL. This is to eliminate exceptional case in our naming rules, which leads to easier conversions between module aliases and strings.","ref":"style_guide.html#module-names","title":"Antikythera Style Guide - Module names","type":"extras"},{"doc":"Module aliases MUST be ordered in their generality; modules with general use cases MUST come above modules with limited use cases.External modulesAntikytheraAntikytheraCoreAntikytheraEalFor sub-modules under namespaces listed above, there is no specific order defined.You SHOULD bundle modules of the same level:alias Antikythera.{GearName, GearNameStr}","ref":"style_guide.html#order-of-module-aliases","title":"Antikythera Style Guide - Order of module aliases","type":"extras"},{"doc":"importing a module will allow you to use its functions without SomeModule. prefix. However it SHOULD NOT be abused because it can lead to name conflicts.Use only when you are absolutely sure it is safe and useful there.Limit its targets with :only option.Consider limiting its scope by placing it inside a specific scope.","ref":"style_guide.html#do-not-abuse-import","title":"Antikythera Style Guide - Do not abuse import","type":"extras"},{"doc":"You MUST NOT omit parentheses in function calls.# Okay result = zero_arity_function() result = one_arity_function(arg1) # Not okay as it gets warned by elixir compiler result = zero_arity_function # Not okay (less readable especially when some args are long and not pipe-ready) result = some_function arg1, arg2, arg3, arg4 # Okay result = some_function(arg1, arg2, arg3, arg4)Also you MUST NOT omit parentheses when you define functions. Note that you MAY omit parentheses when invoking macros.","ref":"style_guide.html#function-calling-syntax","title":"Antikythera Style Guide - Function calling syntax","type":"extras"},{"doc":"Pipe operator improves code readability when 1st argument is a complex expression because it reorders expressions in the evaluation order.# You have to read inside-out, as function arguments are evaluated before function invocation Enum.sort(Enum.filter(list, &amp;some_predicate/1)) # Much readable as you can now naturally follow the evaluation order from left to right Enum.filter(list, &amp;some_predicate/1) |&gt; Enum.sort()Also pipe operator makes separation between &quot;data&quot; and &quot;its transformation&quot; clearer.list |&gt; Enum.map(some_func) |&gt; Enum.filter(some_predicate) |&gt; Enum.reduce(acc0, some_reducer)If you have neither of the above benefits in mind, you SHOULD NOT use pipe operator.# absurd keys = some_map |&gt; Map.keys() # simple enough keys = Map.keys(some_map)","ref":"style_guide.html#using-operator","title":"Antikythera Style Guide - Using |&gt; operator","type":"extras"},{"doc":"Contributing GuideAs an ever-expanding application platform, antikythera is always accepting contributions.Here, contributions can be of several forms:Asking questionsFinding bugsMaking feature suggestionsCommitting codeImproving documentationsAll of them are helpful! Follow the guidelines provided here.","ref":"contributing.html","title":"Contributing Guide","type":"extras"},{"doc":"First, read up documentations before asking questions/making suggestions.Also, search in antikythera API reference to find detailed information about modules/functions.Make sure you are using latest antikythera with latest supported Erlang/Elixir version.Refresh dependencies if dependency/compile related error occurred:$ mix deps.clean $ mix deps.update --all $ mix deps.getIf you need further help, found bug in antikythera code, or came up with feature suggestions, follow the steps below.Post in Antikythera Framework Users Mailing List (Users ML)Your problem might already be encountered and solved by other developers, and they could offer you a help.Even if they have not solved the problem, they may still be able to provide additional information, which can be quite useful for bug fixes.If your problem is just an oversight or an error, it can be solved here.Discussions in the Users ML can be referenced in the future, making it an effective knowledge base.If the problem is reported to ML first, other developers can recognize the problem and reduce their cognitive load.For feature suggestions:Other developers can agree/disagree/reinforce/provide additional points to your suggestions.Core developers can respond with design philosophies/decisions behind antikythera development, and provide proper directions to your suggestion:Implement it as a new featureAchieve it with existing featuresNot going to support as an antikythera featureIf you think your mail is not getting attentions, reply to the thread to request answers. People just might have overlooked the mail.Or, your post might be too trivial to get answered. Make sure you check out documentations mentioned in the previous section.If you are working closely to the core developer team, you MAY just tell your concern to them and open an issue.But, as described above, posting a mail to Users ML is itself beneficial to the whole antikythera community, so it is preferred.Report in Issue TrackerIf your problem is indeed marked as a bug, or your feature suggestions are accepted, you or one of core developers can open issues.If you are absolutely certain that you found a bug, you MAY just report an issue directly.However, dropping a descriptive mail in Users ML is always helpful and preferred.DO NOT make feature issues directly. Discuss in ML first.This is to keep backlog as small and manageable as possible.If feature issues are randomly opened, core developers must periodically review and organize them, which is costly.Mail and Issue mannersTry to be as descriptive as possible.NOT just &quot;I can not do XXX&quot; or &quot;It says YYY on compile&quot;.These information are essential:What are you going to achieve? (And Why?)What changes/circumstances cause the problem?What does the compiler/log say?Which version(commit hash) of antikythera you use?Can you reproduce it and how?(Not all of them are always required, but they surely make your posts more descriptive)","ref":"contributing.html#surveying-and-discussions","title":"Contributing Guide - Surveying and Discussions","type":"extras"},{"doc":"Reported issues are evaluated by their urgency and assigned/tagged appropriately.Basically those issues are assigned to core developers and implemented. However, it is welcomed to make your own effort to pick up one of them and implement it.Just drop comments in the issue you are willing to tackle with. Then the core team will assign it to you.If you try to implement features, follow the instruction explained in this section.DevelopingFork this repository and setup antikythera project:$ cd path/to/antikythera/ $ mix deps.get $ mix testAfter you have made sure that you can run antikythera tests, check out a feature branch from master branch.Antikythera and its related projects use GitHub-flow; anything on master are automatically tested (though it is not actually &quot;deployed&quot; to somewhere).For branch name and commit messages, look up recent branches/commits and follow their conventions (be sufficiently descriptive and simple).Implement the feature with tests.At least, test behavior of public interfaces of the modules, as advised by Elixir author, José Valim.Always confirm that the whole test passes. mix test.watch is useful to monitor file changes and automatically run the test.If your change requires an actual gear for testing, see the next section.Implement by a (relatively) small chunk.Your feature might require quite a large addition or changes.Such a large patch is hard to read and review, leads to blocking of reviewers' activities.Keep your components (modules/functions) loosely-coupled and follow the single responsibility principle, so that they can be implemented/tested separately, thus can be reviewed/merged steadily.Make use of our style guide.Use testgear for testing antikythera's featuresSometimes it is essential to test features through an actual gear.For example, when you implement a new Plug.Or, your implementation touches existing codes and might break current functionalities.In such cases, we use testgear and antikythera_instance_exampleSince these are separate projects, you will likely write tests using testgear as a separate step from implementing features in antikythera.Fork testgear repository and setup like the following:$ cd path/to/testgear/ $ export ANTIKYTHERA_INSTANCE_DEP=&#39;{:antikythera_instance_example, [git: &quot;git@github.com:access-company/antikythera_instance_example.git&quot;]}&#39; $ mix deps.get $ mix deps.get # Fetch dev/test-only dependencies declared in antikythera_instance_example $ mix test # Whitebox test $ iex -S mix (from another terminal) $ export ANTIKYTHERA_INSTANCE_DEP=&#39;{:antikythera_instance_example, [git: &quot;git@github.com:access-company/antikythera_instance_example.git&quot;]}&#39; $ TEST_MODE=blackbox_local mix test # Blackbox testThen, you set up a controller that uses new feature, and test its integrity via request and response.Consult the document for testing in gears as a reference.Pull RequestBranches are Pull Requested against (mostly) master branch, then reviewed by core team, and merged when approved by ALL MEMBERS.When you are confident about your development chunk, prepare your Pull Request.First, you MUST self-review the changes you made in the branch. This is particularly important.Follow the coding conventions described in the style guide.Make sure your code fit in existing antikythera code.Provide sufficient @moduledoc, @doc and @typedoc, especially if it is publicly available.If your code contains workaround or hacky solution, put an explanation comments.Check typo and format the code.($ mix format)Run the Dialyzer ($ mix dialyzer) and fix any errors reported.If reviewers deemed the Pull Request is not self-reviewed well, it CAN be rejected.When you are confident on your branch, push it to your fork repository, then open Pull Request.Pull Request title can be just branch name, or summarized description.Make sure the Pull Request and the issue are mutually linked.When your Pull Request is ready, you MUST post description either in the Pull Request itself, or in the issue.In the description:Briefly state what is implemented in the patch (no need to explain procedures step by step, just outline).If the patch is incomplete and a part of the whole feature, make sure what part of the feature is implemented and how it works in the whole picture (and optionally, what is not yet implemented and what comes in next chunk).If you think some part of the patch is hard to understand, any additional notes will be helpful for reviewers.Review and MergeFor each comments made by reviewers, you MUST:Fix the specified error/style/logic/etc..., OR,Explain decision factor/reason behind code, and discuss, THEN,Fix, leave as-is or put comments on that part, AND FINALLY,Reply to the comments with fixing commit hash, or closing words (e.g. &quot;Addressed in \\&lt;commit hash&gt;&quot; or &quot;As discussed above, we keep this as-is&quot;).When all reviewers approved the Pull Request, one of core developers will take care of the rest:The branch will be merged with &quot;squash&quot; (in most cases from GitHub UI, i.e. &quot;button merge&quot;).In squash merge commit, Author is the contributor, and Committer is a member who performed the merge. So be assured that your contributions are always properly counted!When successfully merged, remote branch can be safely deleted (for your fork repository branches, it is up you).When the new master is successfully tested:If the issue is solved/the feature is fully implemented, it will be closed. Thanks for your contribution!If the issue is still in progress, you resume your development.Sometimes tests can fail due to unexpected side effects or errors.You can tackle with fixing it, but in most cases core team will take care of such complicated failures.","ref":"contributing.html#contributing-to-the-antikythera-code","title":"Contributing Guide - Contributing to the antikythera code","type":"extras"},{"doc":"Getting StartedSet up your development environment.Basically you need to (1) install Erlang and Elixir, and (2) prepare for domain-based routing.Then, you need your own antikythera instance.Documentation about this part is in preparation. Please be patient!If you don't have one yet, you can start by using antikythera_instance_example.$ git clone https://github.com/access-company/antikythera_instance_example.git $ cd antikythera_instance_example $ mix deps.get (If you encountered an error complaining about required Erlang and/or Elixir versions, run `asdf install` here) $ mix deps.get # fetch additional dependencies declared in antikythera_instance_example $ mix compileNow you can generate your own gear project using your antikythera instance.From local clone of your antikythera instance:$ mix antikythera.gear.new ~/path/to/my_gear $ cd ~/path/to/my_gear # In order for versioning utility of antikythera to work, git repository and an initial commit are necessary. $ git init $ git add . $ git commit -m &#39;Initial commit&#39; $ mix deps.get $ mix deps.get # fetch additional dependencies declared in your antikythera instance $ iex -S mixOpen http://my-gear.localhost:8080/hello in web browser, see if it is working.Congratulations! Now your first gear is up and running.Take a look around and play around with it.Check out documentations and see what you can do with antikythera and gears.Guide for instance administrators (TBD)Guide for gear developers (i.e. developers of web services)API References (To be published)","ref":"getting_started.html","title":"Getting Started","type":"extras"},{"doc":"Development Environment","ref":"development_environment.html","title":"Development Environment","type":"extras"},{"doc":"Before anything else, do note that an antikythera instance and its gears run in the same ErlangVM cluster. Therefore, obviously, all development AND deployment environments must have the same Erlang and Elixir versions!We strongly recommend asdf to manage this synchronization.Antikythera itself doesn't impose any version restrictions other than the one specified in mix.exs. Individual antikythera instance project may enforce a more fine-grained restrictions on language versions.Other requirements:Some dependencies contain C source code and thus a reasonably new C compiler is required.In macOS you may be warned by outdated GNU make version during compiling antikythera's dependencies. In that case install GNU make using e.g. homebrew. The installed executable is gmake; create a symlink named make in somewhere in your $PATH so that the desired version of make command is selected.Install development header of Expat, which is required by fast_xml library.In macOS this should be already installed. If not, install expat with homebrew.On Linux you have to install inotify-tools to enable file system watching tools such as exsync and mix_test_watch.Install asdf as explained in the official README.mdInstall asdf plugins$ asdf plugin-add erlang$ asdf plugin-add elixir$ asdf plugin-add nodejsNode.js installation is optional. You do not need it if you are not using asset-related features.Install language versionsIn order to invoke initial mix deps.get, you need to globally install reasonably new Erlang and Elixir versions.$ asdf install erlang x.y.z &amp;&amp; asdf global erlang x.y.z$ asdf install elixir x.y.z &amp;&amp; asdf global elixir x.y.zWorking on your antikythera instance:If .tool-versions already exists, $ asdf installIf not,$ asdf local erlang x.y.z &amp;&amp; asdf local elixir x.y.zthen commit the generated .tool-versions file.Working on a gear:Make sure you have a valid symlink named .tool-versions which points to deps/your_antikythera_instance/.tool-versionsThis way you can make your gear's language versions in sync with your antikythera instance.If your gear is generated using mix antikythera.gear.new, symlink to .tool-versions is automatically created.$ asdf installShell history in iexAlthough iex is able to remember commands executed in previous sessions, the feature is not enabled by default.It is highly recommended to set the following environment variable during development:export ERL_AFLAGS=&quot;-kernel shell_history enabled&quot; (for bash family)","ref":"development_environment.html#install-compilers-and-build-tools","title":"Development Environment - Install Compilers and Build Tools","type":"extras"},{"doc":"Antikythera routes web requests by subdomains and paths. See routing.In local development, you must be able to resolve subdomain of localhost (e.g. your-gear.localhost) into loopback address (127.0.0.1).The easiest way is to add a line like 127.0.0.1 your-gear.localhost to your /etc/hosts.Alternatively, you can setup a local DNS server (such as dnsmasq) to resolve all subdomains of localhost.","ref":"development_environment.html#prepare-for-domain-based-routing","title":"Development Environment - Prepare for Domain-based Routing","type":"extras"},{"doc":"In your local environment you can customize some of antikythera's default settings using the following environment variables:Runtime environment variables:BASE_DOMAIN:Suffix part of domain names to be used when clients interact with running gears. Defaults to localhost.For example, when you are running :some_gear as BASE_DOMAIN=somedomain iex -S mix, you can browse the top page of the gear at http://some-gear.somedomain:8080/ (assuming that the default port number is used; see below).Note that when using BASE_DOMAIN other than localhost, you may need to tell the DNS resolver on the client side about the gear's domain name.PORT:Port number to receive incoming web requests from. Defaults to 8081 during mix test, and 8080 otherwise (thus one can run both iex -S mix and mix test at the same time).Explicitly set this when you run multiple antikythera servers within your machine.TEST_PORT:Port number to send HTTP requests to during blackbox_local tests. Defaults to 8080.NO_LISTEN:A boolean flag for disabling web server functionality of antikythera. Defaults to false.true is implicitly set when using Antikythera.Mix.Task.prepare_antikythera_instance/0 in your mix task.LOG_LEVEL:Log level of all gears. Defaults to info. See also logging.SOME_GEAR_CONFIG_JSON:Gear config of :some_gear. See also gear_config.Compile-time environment variables: (to change the followings you need to recompile antikythera)GEAR_ACTION_TIMEOUT:Milliseconds to wait until gear action finishes. Defaults to 10000. See also controller.GEAR_PROCESS_MAX_HEAP_SIZE:Maximum size of per-process heap memory in words. Defaults to 50000000 (400MB in 64-bit architecture).If you develop mix task, you can use the following environment variables:Runtime environment variables:ANTIKYTHERA_MIX_TASK_MODE:A boolean flag whether Antikythera runs for mix task. Defaults to false.You must set true even if your command is mix task.If you set a value other than local to ANTIKYTHERA_RUNTIME_ENV, Antikythera thinks it was built for a release package and is deployed to a cloud. Then, the path to the config files will be broken, and Antikythera will try to use cloud services even if your mix task running enrivonment doesn't allow them. If this variable is true, Antikythera won't do them.Compile-time environment variables: (to change the followings you need to recompile antikythera)ANTIKYTHERA_MIX_TASK_MODE:A boolean flag whether Antikythera is compiled for mix task. Defaults to false.You must set true even if your command is mix task and automatically compile Antikythera.If you set a value other than local to ANTIKYTHERA_COMPILE_ENV, Antikythera thinks it is built for a release package and will be deployed to a cloud. Then, the path to the config files will be broken, and Antikythera will try to use cloud services even if your mix task running enrivonment doesn't allow them. If this variable is true, Antikythera won't do them.","ref":"development_environment.html#environment-variables-to-tweak-behavior-of-antikythera","title":"Development Environment - Environment variables to tweak behavior of antikythera","type":"extras"},{"doc":"Dependency ManagementElixir ships with the official build tool mix and it manages dependencies for elixir projects. Open source libraries written in Elixir or Erlang are basically published at hex.pm. Usually elixir/mix project specifies its dependencies in mix.exs file.In antikythera, library dependencies are defined in your antikythera instance. Gear projects inherit dependencies of their antikythera instance, and have no means of specifying non-gear dependencies.This is the design decision made based on the following reasons:Antikythera instances host multiple gears that are independent of each other.If each gear could specify its own dependencies, those dependencies would conflict and disrupt execution of other gears.In cases where multiple library candidates are found for a specific purpose, it is beneficial to choose one of them and share it by all gears in that you can reuse knowledge of that library.Therefore all libraries used by both an antikythera instance and gears are managed solely by the antikythera instance.Conversely, it is the duty of antikythera instance administrators to carefully choose good libraries and manage their versions.In order to keep gears' dependencies in-sync with your antikythera instance, gear developers should periodically update their gears with $ mix deps.update antikythera_instance_name.Update cycle should be determined by how often your antikythera instance is updated.Note that unless some breaking changes are introduced to your antikythera instance by e.g. updating a library to an incompatible version, already compiled gears should continue to work.This is an essential feature of antikythera that allows you to independently update antikythera instances and its gears! See Deployment for details.","ref":"library_dependencies.html","title":"Dependency Management","type":"extras"},{"doc":"Available libraries must be defined in your antikythera instance's mix.exs, just as you do in normal mix projects.A gear project inherits its antikythera instance's dependencies, so all libraries listed in the antikythera instance are also available to its gears.If you have requests of libraries to include, consult your antikythera instance administrators.&quot;Indirect&quot; dependenciesIn antikythera instances, you can declare some dependencies as :indirect ones like so:{:ranch, &quot;1.4.0&quot; , [indirect: true]},As the name suggests, you can use this special option to &quot;lock&quot; indirect dependencies defined in your dependencies.Without this, versions of indirect dependencies become ambiguous in gear projects, potentially leading to unexpected behaviors.Startup of indirect dependencies as runtime OTP applications are controlled by their &quot;parent&quot; dependencies. Neither antikythera instances nor their gears explicitly start them.","ref":"library_dependencies.html#libraries-available-from-gears","title":"Dependency Management - Libraries available from gears","type":"extras"},{"doc":"Although gears cannot specify dependencies in general, they can declare dependency to other gears.For this purpose you can specify the names of gears that your gear depends on by gear_deps/0 in gears' mix.exs.For example, the following gear_deps/0 declares dependency to gear_a and gear_bdefp gear_deps() do [ {:gear_a, [git: &quot;git@github.com:your-organization/gear_a.git&quot;]}, {:gear_b, &quot;1.0.0&quot;, [organization: &quot;your-organization&quot;]}, # Private packages; see https://hex.pm/docs/private ] endNote that gear_deps/0 function can be module private.If you have any gear dependencies, you should also update them periodically, e.g. $ mix deps.update antikythera_instance_name gear_a gear_b.","ref":"library_dependencies.html#specifying-other-gears-as-dependencies","title":"Dependency Management - Specifying other gears as dependencies","type":"extras"},{"doc":"Some development/test libraries are useful and recommended to include in your antikythera instance.Also check out antikythera's mix.exs as a reference.Static analysis using dialyzerWith dialyxir, you can run typecheck of your code by $ mix dialyzer.dialyxir wraps the dialyzer, allowing it to conveniently run from mix projects.See here for details of success typing analysis.ex_doc for documentationsWith ex_doc, you can generate nicely rendered HTML documents from your Elixir code.Elixir developers are always encouraged to add @moduledoc/@doc/@typedoc attributes to modules/functions/types to clearly express their intentions.You should consider hosting your generated HTMLs at somewhere visible to your organization.Test coverage reportsTest coverage reports are also essential to monitor code quality.Antikythera uses excoveralls as its coverage tool. See the documentation of the tool for configuration options using coveralls.json file.","ref":"library_dependencies.html#tools","title":"Dependency Management - Tools","type":"extras"},{"doc":"For Gear Developers","ref":"gear_developers.html","title":"For Gear Developers","type":"extras"},{"doc":"","ref":"gear_developers.html#getting-started-guide","title":"For Gear Developers - Getting Started Guide","type":"extras"},{"doc":"","ref":"gear_developers.html#setting-up-your-development-environment","title":"For Gear Developers - Setting up your development environment","type":"extras"},{"doc":"","ref":"gear_developers.html#library-dependencies","title":"For Gear Developers - Library dependencies","type":"extras"},{"doc":"","ref":"gear_developers.html#automatic-deployment","title":"For Gear Developers - Automatic deployment","type":"extras"},{"doc":"","ref":"gear_developers.html#web-request-routing","title":"For Gear Developers - Web request routing","type":"extras"},{"doc":"","ref":"gear_developers.html#gear-to-gear-communication","title":"For Gear Developers - Gear to gear communication","type":"extras"},{"doc":"","ref":"gear_developers.html#implementing-controller-action","title":"For Gear Developers - Implementing controller action","type":"extras"},{"doc":"","ref":"gear_developers.html#dynamic-html-generation-using-templates","title":"For Gear Developers - Dynamic HTML generation using templates","type":"extras"},{"doc":"","ref":"gear_developers.html#implementing-websocket-server","title":"For Gear Developers - Implementing websocket server","type":"extras"},{"doc":"","ref":"gear_developers.html#asynchronous-jobs","title":"For Gear Developers - Asynchronous jobs","type":"extras"},{"doc":"","ref":"gear_developers.html#executor-pool-for-controlling-computing-resources","title":"For Gear Developers - Executor pool for controlling computing resources","type":"extras"},{"doc":"","ref":"gear_developers.html#logging","title":"For Gear Developers - Logging","type":"extras"},{"doc":"","ref":"gear_developers.html#metrics-reporting","title":"For Gear Developers - Metrics Reporting","type":"extras"},{"doc":"","ref":"gear_developers.html#alerting","title":"For Gear Developers - Alerting","type":"extras"},{"doc":"","ref":"gear_developers.html#gear-config","title":"For Gear Developers - Gear config","type":"extras"},{"doc":"","ref":"gear_developers.html#internationalization","title":"For Gear Developers - Internationalization","type":"extras"},{"doc":"","ref":"gear_developers.html#testing","title":"For Gear Developers - Testing","type":"extras"},{"doc":"","ref":"gear_developers.html#what-gear-implementations-must-not-do","title":"For Gear Developers - What gear implementations must not do","type":"extras"},{"doc":"Deployment to Antikythera InstanceNote: This page is being updated for OSS release. Please be patient. Current contents describes how our antikythera instance and gears are deployed in ACCESS.","ref":"deployment.html","title":"Deployment to Antikythera Instance","type":"extras"},{"doc":"Antikythera itself is regularly deployed to both dev and prod environments in the same way as gears described below.For the following purposes antikythera expects each gear to be deployed at least once per month to both dev and prod environments.to keep gears and antikythera in sync,to smoothly phase out deprecated symbols (especially for macros as they require re-compilation and re-deploy of all running gears), without too much communication overhead.","ref":"deployment.html#antikythera-s-deployment-policy","title":"Deployment to Antikythera Instance - Antikythera's deployment policy","type":"extras"},{"doc":"For automatic deployment, antikythera assumes that all gears' code is managed as follows:RepositoryEvery gear implementation is expected to have its own repository in either GitHub (dev/prod), or antikythera git server (dev only).The repository in GitHub must belong to access-company/Antikythera team so that the antikythera team and antikythera's auto-deploy component have read/write access to it.BranchesAntikythera treats the following 2 branches as deploy targets; the other branches are ignored.master branch means &quot;ready to deploy to dev environment&quot;.release branch means &quot;ready to deploy to prod environment&quot;.Updates in these branches will be automatically deployed to the running antikythera system.","ref":"deployment.html#gear-s-git-repository","title":"Deployment to Antikythera Instance - Gear's git repository","type":"extras"},{"doc":"Each of dev and prod environments runs its own jenkins server for automatic testing and deployment.Note that, in order to run a gear within live antikythera environments, it is necessary for the gear to use the latest version of antikythera.The antikythera version used by gear is tracked by mix.lock file. You can manually update to the latest antikythera version by issuing $ mix deps.update antikythera.If antikythera's auto-deploy component detects that a gear is referring to an outdated antikythera version, thenin dev environment it automatically tries to update the antikythera dependency (i.e. perform git-push to origin/master) and try again.in prod environment: it rejects the gear version.","ref":"deployment.html#deployment-flow","title":"Deployment to Antikythera Instance - Deployment flow","type":"extras"},{"doc":"Jenkins servers in dev/prod environment contain deployment jobs per existing gear (and a few jobs for antikythera system operations).The settings of these jenkins jobs are pre-configured and should not be altered, aside from the following exception.If you want to trigger deployment to prod after successful deployment to dev, you can setup &quot;Git publisher&quot; of your gear's deploy job so that it automatically propagate changes in master to release. (This configuration is currently active by default)","ref":"deployment.html#about-jenkins-job-settings","title":"Deployment to Antikythera Instance - About jenkins job settings","type":"extras"},{"doc":"All the following tests are executed in the same way as normal development environment:Before deployment: $ mix testAfter deployment: $ TEST_MODE=blackbox_dev mix test or $ TEST_MODE=blackbox_prod mix test(See here for more about whitebox/blackbox tests)","ref":"deployment.html#tests-executed-by-jenkins-during-deploy-jobs","title":"Deployment to Antikythera Instance - Tests executed by jenkins during deploy jobs","type":"extras"},{"doc":"If you encounter an error about antikythera's mix configuration during deployment of your gear, it might be caused by changes in mix.exs and/or mix_common.exs in antikythera repository. Please re-run the deploy job a few times and see if it works.","ref":"deployment.html#troubleshoot-errors-during-deploy","title":"Deployment to Antikythera Instance - Troubleshoot errors during deploy","type":"extras"},{"doc":"Web Requests RoutingNote: This page is being updated for OSS release. Please be patient.Antikythera's web request router consists of the following 2 stages:Domain-based routingPath-based routingThis process is schematically shown in the following flow diagram:","ref":"routing.html","title":"Web Requests Routing","type":"extras"},{"doc":"Antikythera hosts multiple running gears and incoming web requests are routed based on the domain part of the URL.When a gear is started, antikythera's routing layer registers the domains of the gear and subsequent requests to the domains will be routed to the gear.Each gear's domain is configurable and defaults to the following subdomain (note that _s in gear name are replaced by -s):local environment: &lt;gear-name&gt;.localhost:8080 (when you run $ iex -S mix in your gear project)dev environment: &lt;gear-name&gt;.development.example.comprod environment: &lt;gear-name&gt;.production.example.com","ref":"routing.html#domain-based-routing-to-a-specific-gear","title":"Web Requests Routing - Domain-based routing to a specific gear","type":"extras"},{"doc":"Once an appropriate gear for an web request is determined based on the domain part, antikythera then routes the request to a controller action by matching URL path and HTTP method.Gears must define the routing rules in web/router.ex.Refer to Antikythera.Router for details of the routing DSL.","ref":"routing.html#path-based-routing-to-a-specific-controller-action","title":"Web Requests Routing - Path-based routing to a specific controller action","type":"extras"},{"doc":"Gear-to-Gear (g2g) CommunicationNote: This page is being updated for OSS release. Please be patient.Antikythera defines an interface for g2g communication. The interface closely resembles the HTTP protocol: it has method, path, body, headers, etc. This introduces a few nice things:Gear developers can focus on standard HTTP terminology. They can be written/tested in the same way.The same interface enhances code reuse: e.g. code for web request automatically implements gear request handling.Antikythera routes a g2g request to its target gear's controller action by matching its method and path, as is the case for web request (see also routing).You can send request to another gear by using TargetGear.G2g module. For usage of G2g modules, refer to test code in testgear.","ref":"g2g.html","title":"Gear-to-Gear (g2g) Communication","type":"extras"},{"doc":"Suppose you are implementing a gear controller action that acts as a simple proxy to another gear, i.e., returns a g2g response returned by another gear's action as it is. You would implement the action as follows (assuming JSON encoded body):# Bad: don&#39;t do this def action_xyz(conn) do g2g_res = AnotherGear.G2g.send(conn) json(conn, 200, g2g_res.body) endThis implementation involves unnecessary decoding/encoding of g2g_res.body becauseG2g.send/{1,2} automatically decodes the response body, andAntikythera.Conn.json/3 encodes the body.Instead you should bypass the decoding and re-encoding using G2g.send_without_decoding/{1,2}.# Good def some_action(conn) do g2g_res = AnotherGear.G2g.send_without_decoding(conn) conn |&gt; Conn.put_status(200) |&gt; Conn.put_resp_body(g2g_res.body) |&gt; Conn.put_resp_headers(g2g_res.headers) end","ref":"g2g.html#avoiding-unnecessary-body-decoding-encoding","title":"Gear-to-Gear (g2g) Communication - Avoiding unnecessary body decoding/encoding","type":"extras"},{"doc":"Implementing ControllerNote: This page is being updated for OSS release. Please be patient.Controller action must receives a Antikythera.Conn struct and returns a Antikythera.Conn. In other words, type signature of a controller action must be acion(Antikythera.Conn.t) :: Antikythera.Conn.t.What controller action should do is, based on the request information in Conn struct, to construct a new Conn filled with response information (HTTP status code, body, headers, etc.). Antikythera picks up the response information from the returned Conn and sends back to the request sender.For this purpose many utility functions are defined in Antikythera.Controller. Those functions are auto-imported when you use Antikythera.Controller in your controller module.Controller action must return a response within 10 seconds.It is recommended that you set the client timeout value to 15 seconds or more. This is because the executor pool waits up to 5 seconds and the controller takes up to 10 seconds.Gzip compression of responses is done transparently when a request contains accept-encoding: gzip header.","ref":"controller.html","title":"Implementing Controller","type":"extras"},{"doc":"By default antikythera returns a simple error response to request sender in the following situations:An error occurs during execution of controller action.No controller action matches the request's method/path.Format of the request body does not conform to the value of content-type header.Websocket connections limit is reached.To customize response on error, you can define your gear's custom error handlers by:Add YourGear.Controller.Error module.Inside the module define the following functions:error/2no_route/1bad_request/1bad_executor_pool_id/2 (optional)ws_too_many_connections/1 (optional)These functions must return a Antikythera.Conn.t as in regular controller actions.Note that custom error handlers should do as little task as possible to avoid further troubles.","ref":"controller.html#handling-errors","title":"Implementing Controller - Handling errors","type":"extras"},{"doc":"Before returning an HTTP response antikythera automatically adds the following response headers for security reasons:x-frame-options : DENYx-xss-protection : 1; mode=blockx-content-type-options : nosniffstrict-transport-security : max-age=31536000Gear implementations can explicitly set these headers; in this case antikythera respects the value and don't overwrite it.","ref":"controller.html#response-headers","title":"Implementing Controller - Response headers","type":"extras"},{"doc":"Templates for Dynamic HTMLNote: This page is being updated for OSS release. Please be patient.Gears can use HAML templates to render dynamic HTML.We are using calliope as the HAML engine. Please refer to calliope's documentation for its syntax.To use HAML:Confirm that web/template.ex is present (it's automatically generated by the gear generator).Place your HAML files under web/template/.HAML templates are processed during $ mix compile and content of each file is packed into a clause of YourGear.Template.content_for/2.Render HTML responses by using render/5 function in your controller action.HTML-escaping in HAML templatesDynamic parts in HAML templates are automatically HTML-escaped (i.e. special characters are replaced with character entity references).If you want to insert elements without escaping, use Antikythera.TemplateSanitizer.raw/1. Antikythera.TemplateSanitizer is automatically imported and thus you can just write e.g. = raw &quot;&lt;this won't be escaped&gt;&quot; in your HAML templates.Inserting other templates in a template (a.k.a. partial rendering)You can simply call content_for/2 (without YourGear.Template. prefix) from within your HAML templates. e.g. = content_for &quot;path/to/other/template&quot;, param1: value1","ref":"dynamic_html.html","title":"Templates for Dynamic HTML","type":"extras"},{"doc":"WebsocketNote: This page is being updated for OSS release. Please be patient.Websocket is an extension to HTTP that emulates TCP connections. By using websocket, communication pattern between server and client is no longer restricted to plain HTTP's request-response model.Antikythera supports the websocket protocol to enable gears to interactively communicate with their clients.","ref":"websocket.html","title":"Websocket","type":"extras"},{"doc":"To use websocket in your gear you need todeclare a websocket route in web/router.exThe route is for handshake; GET requests that match the path pattern are processed as websocket handshake requests.See reference of Antikythera.Router.implement a callback module of Antikythera.Websocket behaviour in web/websocket.exFor detailed explanations, see Antikythera.Websocket.","ref":"websocket.html#implementing-websocket-enabled-gear","title":"Websocket - Implementing websocket-enabled gear","type":"extras"},{"doc":"Once a websocket connection is established between antikythera and a client, antikythera allocates a dedicated process for the connection.Note that the connection process is created on the node that received the handshake request in the cluster.This connection process handles all incoming/outgoing frames between the server and the client.To push a frame to the client, you must first send an Erlang message to the connection process. You can use Antikythera.Registry.Unique and/or Antikythera.Registry.Group for this purpose.Connections limitIn order to prevent a specific gear from monopolizing resources in the cluster, antikythera imposes an upper limit on number of websocket connections per executor pool.During handshake, antikythera calls YourGear.executor_pool_for_web_request/1 to ask which executor pool this client belongs to.Trying to connect more than the limit results in an HTTP 503 (Service Unavailable) error.The error can be customized as you wish; see handling errors.Idle timeoutA websocket connection established between an antikythera gear and a client is automatically closed after 60 seconds of idle time.If you want to keep websocket connections during idle time it's recommended that clients periodically send ping frames.It's also possible that the server sends periodic pings but in most cases it's better to distribute computational costs associated with the timers for large number of clients.You don't have to implement the server to reply with pong frame; ping frames are automatically handled by antikythera.Disconnection from soon-to-be-terminated serverFor maintenance reason, a subset of antikythera servers in the cluster may be shut down at any time. Before it is actually terminated, each target server will automatically send a close frame with status code 1001 to all the connected websocket clients. Client implementations should be prepared with these situations by properly reconnecting to other working servers in the cluster.","ref":"websocket.html#websocket-connection-process","title":"Websocket - Websocket connection process","type":"extras"},{"doc":"Asynchronous JobsNote: This page is being updated for OSS release. Please be patient.Antikythera provides gears with a way to asynchronously run arbitrary code. This feature is referred to as &quot;async job&quot; throughout documentations of antikythera. Async jobs are executed in background of HTTP request/response interactions.Async jobs are useful for tasks such as:batch insertssending many emailsdownload and process filesscheduled jobsAntikythera's async job processing comes with the following features:Automatic retry of failed jobsSupport of timed jobs (jobs that start at specified times)Support of recurring schedule (using crontab format)Timeout of job executionLoad balancing of job executions within ErlangVMs in the clusterResource capping (implemented in terms of executor pools)","ref":"async_job.html","title":"Asynchronous Jobs","type":"extras"},{"doc":"To use async job, gear implementation must define a module that uses Antikythera.AsyncJob.defmodule YourGear.SomeAsyncJob do use Antikythera.AsyncJob @impl true def run(payload, _job_id, _context) do # put arbitrary code here YourGear.Logger.info(inspect(payload)) end endThen invoke YourGear.SomeAsyncJob.register/3. You can register new jobs from within both controller actions and async jobs. In your local development environment you can try within $ iex -S mix.YourGear.SomeAsyncJob.register(%{&quot;arbitrary&quot; =&gt; &quot;map&quot;}, {:gear, :your_gear})Internally, it inserts the job to a job queue for executor pool {:gear, :your_gear}, the job queue notifies a broker process of the newly registered job, the broker spawns a worker to run the job, and then the following call to YourGear.SomeAsyncJob.run/3 is evaluated within the worker:YourGear.SomeAsyncJob.run(%{&quot;arbitrary&quot; =&gt; &quot;map&quot;}, job_metadata, context_for_this_job_execution)For details of the async job API please refer to Antikythera.AsyncJob.","ref":"async_job.html#usage-example","title":"Asynchronous Jobs - Usage example","type":"extras"},{"doc":"“Executor Pool” for Resource ManagementNote: This page is being updated for OSS release. Please be patient.","ref":"executor_pool.html","title":"“Executor Pool” for Resource Management","type":"extras"},{"doc":"Antikythera supports multi-application (multi-gear) and multi-tenant workloads. This means that multiple gears and multiple tenants share the same computing resources in an antikythera cluster. In order to mitigate influences of heavily-loaded gear and/or tenant on the other gears/tenants, antikythera controls execution of simultaneously running tasks using &quot;executor pool&quot;s.Each executor pool consists of the following pools of Erlang processes:Processes for web request processingProcesses for websocket connectionsProcesses for async job executionNumber of processes in the pools are managed by the antikythera core. These types of pools in an executor pool are independent of each other, i.e., web request processing does not affect async job execution.Executor pools are classified into the following two categories:Gear executor pool:An executor pool that associates with exactly one gear. This type of executor pools is for e.g.Gears that do not have multi-tenant use cases,Gears that do support multi-tenant but need to process tasks which do not belong to any tenants.Every time a gear starts/stops (i.e. antikythera installs/uninstalls a gear) the gear's executor pool is also created/terminated. Thus each gear can always use its own gear executor pool.Tenant executor pool:An executor pool that associates with a &quot;tenant&quot; which represents a set of request senders. This type of executor pools is intended for gears that provide service to multiple tenants.TODO: write about life-cycle of tenant executor poolsNote that this type of executor pools can be used by multiple gears.Each task (e.g. web request processing) is executed by an Erlang process in the executor pool that corresponds to the task; thus simultaneous task executions are capped by the number of processes in each executor pool.","ref":"executor_pool.html#purpose","title":"“Executor Pool” for Resource Management - Purpose","type":"extras"},{"doc":"Web requestsTo handle an incoming web request, gear implementations must choose an appropriate executor pool for the request.The target executor pool must be specified by YourGear.executor_pool_for_web_request/1 which receives a Antikythera.Conn.t and returns a Antikythera.ExecutorPool.Id.t.Implementations of executor_pool_for_web_request/1 must be pure; i.e. return value must be computed solely from the given Antikythera.Conn.t.When the executor pool specified by executor_pool_for_web_request/1 is overloaded and no available executor process found within 5 seconds, the request results in an error.In development environment (more precisely, when Antikythera.Env.compiling_for_release?() == true), the returned value from YourGear.executor_pool_for_web_request/1 is basically neglected and gear executor pool is used for all requests to simplify setting-up of gear development.For gear-to-gear requests it's not necessary to choose an executor pool to use; no additional executor pool is necessary to process gear-to-gear requests.Example implementations of executor_pool_for_web_request/1A gear that does not support multi-tenant use cases: uses its gear executor pool for all requests def executor_pool_for_web_request(_conn) do {:gear, :your_gear} endA gear that serves to multiple tenants: specifies tenant ID included in the request path def executor_pool_for_web_request(%Conn{request: req}) do {:tenant, req.path_matches[:tenant_id]} endAsync jobsWhen you register your async jobs, you must specify which executor pool to use as arguments to YourGear.SomeAsyncJob.register/3. See API reference for detailed explanation.","ref":"executor_pool.html#how-to-choose-target-executor-pool-for-the-given-task","title":"“Executor Pool” for Resource Management - How to choose target executor pool for the given task","type":"extras"},{"doc":"After choosing an executor pool for a task (by e.g. SomeGear.executor_pool_for_web_request/1), antikythera verifies that the gear is allowed to use the specified executor pool.The primary purpose of this verification is to protect from DoS attack by requests containing invalid tenant IDs.Available executor pools for a gear are:the gear executor pool of the geartenant executor pools associated with the gearTherefore developer of a gear that uses tenant executor pool must establish associations between his/her gear and target tenant executor pools to use.","ref":"executor_pool.html#associations-between-gears-and-tenant-executor-pools","title":"“Executor Pool” for Resource Management - Associations between gears and tenant executor pools","type":"extras"},{"doc":"Capacities of executor pools are determined by AntikytheraCore.ExecutorPool.Setting.Each field of AntikytheraCore.ExecutorPool.Setting means following.The product of n_pools_a and pool_size_aThe number of processes for web request processing.ws_max_connectionsThe number of processes for websocket connections.pool_size_jThe number of processes for async job execution.","ref":"executor_pool.html#managing-capacity-of-executor-pools","title":"“Executor Pool” for Resource Management - Managing capacity of executor pools","type":"extras"},{"doc":"In addition to capping of simultaneous processes by executor pools, antikythera imposes memory usage limit (up to 400MB on 64bit machine) on each process that runs under an executor pool.Any process that violates this upper limit will be killed.This limit, together with the limit on number of processes, protects the entire ErlangVM from running out of memory.","ref":"executor_pool.html#limits-for-gear-processes","title":"“Executor Pool” for Resource Management - Limits for gear processes","type":"extras"},{"doc":"LoggingNote: This page is being updated for OSS release. Please be patient.From any part of your gear code, you can put messages to log files. Pass a String.t to one of the following functions:YourGear.Logger.error/1YourGear.Logger.info/1YourGear.Logger.debug/1error, info, debug are the log levels that represent severity of each message.You can configure your logger setting to include which levels of messages to be included in your logs. Default setting is info (i.e., error and info are included, debug is not included).On your local development environment, you can set your log level by setting LOG_LEVEL environment variable.Developers will be notified when any error level logs are reported. See Alerting for details.","ref":"logging.html","title":"Logging","type":"extras"},{"doc":"Information about incoming web requests is automatically logged, as in the following format:2016-01-26T00:40:22.557+00:00 [info] context=20160126-004022.557_ip-172-31-5-176_0.684.0 GET /path?query=params from=xxx.xxx.xxx.xxx START encoding=gzip, deflate, sdch 2016-01-26T00:40:22.567+00:00 [info] context=20160126-004022.557_ip-172-31-5-176_0.684.0 GET /path?query=params from=xxx.xxx.xxx.xxx END status=200 time=10mscontext field is a context ID of the current request processing, in the form of &lt;start date and time&gt;_&lt;erlang node ID&gt;_&lt;process ID&gt;.Query parameters are shown in the URL-decoded form.encoding field is the value of accept-encoding request header. This field is shown mainly to check whether the client uses gzip/deflate compression.On start/end of async job executions the following logs are generated:2016-08-06T09:17:24.043+00:00 [info] context=20160806-091724.043_ip-172-31-22-164_0.662.0 &lt;async_job&gt; module=Testgear.TestAsyncJob job_id=P97tnfACMEivaKW-3zey attempt=1th/3 run_at=2016-08-06T09:17:24.042+00:00 START 2016-08-06T09:17:24.144+00:00 [info] context=20160806-091724.043_ip-172-31-22-164_0.662.0 &lt;async_job&gt; module=Testgear.TestAsyncJob job_id=P97tnfACMEivaKW-3zey attempt=1th/3 run_at=2016-08-06T09:17:24.042+00:00 END status=success time=71mscontext is the same as in the case of web requests (see above).module is the name of the module which defines the job.attempt is the number of job executions (including retries) for this job, together with its upper limit.run_at is the start time specified by the job's schedule.status is one of success, failure_retry and failure_abandon.By providing implementation of inspect_payload/1 callback, you can additionally include information of payload. This can be useful to easily identify jobs in logs. See documentation for Antikythera.AsyncJob for detail.Also websocket connected/disconnected events are logged:2016-11-09T04:47:19.089+00:00 [info] context=20161109-044719.089_ip-172-31-15-109_0.1164.0 &lt;websocket&gt; CONNECTED 2016-11-09T04:47:19.831+00:00 [info] context=20161109-044719.089_ip-172-31-15-109_0.1164.0 &lt;websocket&gt; DISCONNECTED connected_at=2016-11-09T04:47:19.089+00:00 frames_received=0 frames_sent=0frames_received is the number of frames the connection received from the client. Some control frames are automatically handled by antikythera and not included in the number.frames_sent is the number of frames the connection sent to the client. Some control frames are automatically sent by antikythera and not included in the number.In addition to the default log messages explained above, antikythera automatically logs errors which occur during execution of gear code.","ref":"logging.html#auto-generated-log-messages","title":"Logging - Auto-generated log messages","type":"extras"},{"doc":"(TBD)Note that there are multiple running nodes in the antikythera instance and as such the log files are created on a per-node basis.Note also that log files will become downloadable in a few hours:log files are rotated on every 2 hours, androtated logs are uploaded to cloud storage on every 30 minutes.","ref":"logging.html#obtaining-log-files","title":"Logging - Obtaining log files","type":"extras"},{"doc":"Metrics ReportingNote: This page is being updated for OSS release. Please be patient. Current contents describes how we are handling our antikythera instance's and gears' metrics data in ACCESS.In antikythera core and gears, statistical metrics can be generated.Generated metrics are buffered, aggregated, then flushed to stable storage every minute.By default, antikythera uses Elasticsearch as its metrics storage, utilizing its search/aggregation feature and visualization with Kibana.All metrics are stored in metrics-YYYY.MM.DD indices under antikythera subspace.hAll metrics documents come with following predefined fields:@timestampnode_idotp_app_nameantikythera or gear nameepool_idgear-&lt;gear_name&gt; or tenant-&lt;tenant_id&gt;Exists only in executor pool related metricsMetrics are stored for 1 month. Older indices will be automatically deleted.","ref":"metrics_reporting.html","title":"Metrics Reporting","type":"extras"},{"doc":"The following metrics are automatically gathered by antikythera:Metrics about web/g2g requestsNumber of processed requests (web/g2g_request_count_*)Time distribution of response times (web/g2g_response_time_ms_*)Executor pool checkout failure count (web_timeout_in_epool_checkout_sum)Number of working processes for web request handling in an executor pool (epool_working_action_runner_*)Metrics about websocket interactionsNumber of active connections (epool_websocket_connections_*)Number of rejected attempts to establish websocket connections (epool_websocket_rejected_count)Number of received/sent websocket frames (websocket_frames_received/sent)Metrics about async jobNumber of completed/failed jobs (async_job_success/failure_sum)Time distribution of async job executions (async_job_execution_time_ms_*)Number of waiting jobs in job queue (epool_waiting_job_count)Number of runnable jobs in job queue (epool_runnable_job_count)Number of running jobs in job queue (epool_running_job_count)Number of waiting job brokers (epool_waiting_broker_count)Number of working processes for async job in an executor pool (epool_working_job_runner_*)","ref":"metrics_reporting.html#auto-collected-metrics","title":"Metrics Reporting - Auto-collected metrics","type":"extras"},{"doc":"You can generate and collect arbitrary numeric metrics from your gear's code.Field names for such metrics are prefixed with custom_ and can be searched/visualized just like auto-generated metrics.Use YourGear.MetricsUploader.submit/2 from anywhere in your code to generate metrics. YourGear.MetricsUploader process will then buffer and aggregate them before uploading.First argument is metrics data list (Antikythera.Metrics.DataList.t).strategy for each data must be an atom representation of one of aggregation strategies. Currently available strategies are::average:sum:time_distributionGenerates average, max and 95-percentile values:gaugeTakes last value of each time windowSecond argument is the context (Antikythera.Context.t) from which the currently used executor pool ID will be extracted.","ref":"metrics_reporting.html#custom-metrics","title":"Metrics Reporting - Custom metrics","type":"extras"},{"doc":"Simply search metrics-* indices with filtering on otp_app_name field using your gear name.Note that all metrics are aggregated in uploader process per node, then uploaded to Elasticsearch. There you will aggregate those metrics across nodes (mostly via Kibana query).This two-phase aggregation provides the entire view of metrics from applications running in multiple nodes, while reducing volume of network traffic.However, total metrics could be inaccurate, even with a coherent strategy is used. e.g. A sum of per-node sums is an accurate total sum, but an average of per-node averages is not an accurate total average.","ref":"metrics_reporting.html#metrics-search-and-visualization","title":"Metrics Reporting - Metrics search and visualization","type":"extras"},{"doc":"AlertingNote: This page is being updated for OSS release. Please be patient.When error logs are reported via YourGear.Logger.error/1 function, the errors are sent to developers as alerts.It is also possible to send alerts without logging, by calling YourGear.AlertManager.notify/1 function from any part of your gear code.Currently, only email alerting interface is defined as a behaviour AntikytheraEal.AlertMailer.Slack and Twillio are candidates for alternative notification channels to support. Requests and contributions are welcomed.","ref":"alerting.html","title":"Alerting","type":"extras"},{"doc":"To prevent excessive number of alerts from being sent, alert handlers have a built-in buffering mechanism.Occasional errors will be sent in shorter period of buffering (called fast_interval, 1 minute by default).If errors keep occurring beyond fast_interval, they will be buffered for longer period (called delayed_interval, 30 minutes by default) before sent.These intervals are configured per alert methods.Required and optional settings (such as addresses for email alert), along with intervals above, can be configured in :alerts field of gear config.","ref":"alerting.html#alert-behavior-and-configurations","title":"Alerting - Alert behavior and configurations","type":"extras"},{"doc":"Gear ConfigNote: This page is being updated for OSS release. Please be patient.In general web services need some kind of &quot;secret token&quot;s, such as API key for external services. Also, it's sometimes useful to change configurations on the fly (i.e. without changing source code and without deployment).For these purposes antikythera provides &quot;gear config&quot;.You can think of gear config as something like environment variables for gears.Each gear's gear config is an arbitrary JSON object.","ref":"gear_config.html","title":"Gear Config","type":"extras"},{"doc":"From gear implementation, gear config is accessble by:YourGear.get_all_env/0: Returns a map of JSON-parsed gear config.YourGear.get_env/2: A convenience to just return a single value for the given key in gear config. Use this when you just want a single value; if you need multiple values use get_all_env/0 for better performance.","ref":"gear_config.html#getting-gear-config","title":"Gear Config - Getting gear config","type":"extras"},{"doc":"In cloud (dev/prod environment):(TBD)After update, new values of gear config become visible from gear code, running within multiple ErlangVM nodes, in about a few minutes.In local machineUse environment variable to specify gear config for your locally-running antikythera. For instance, set SOME_GEAR_CONFIG_JSON for some_gear and so on.During tests:You can use Antikythera.Test.GearConfigHelper.set_config/1 to manipulate gear config from test code.","ref":"gear_config.html#setting-gear-config","title":"Gear Config - Setting gear config","type":"extras"},{"doc":"InternationalizationNote: This page is being updated for OSS release. Please be patient.Sometimes antikythera gears want to show translated messages to users. For this purpose antikythera comes with Elixir's gettext package. Documentation for gettext package is available here.Gettext itself is one of GNU projects, and used in many other languages.","ref":"i18n.html","title":"Internationalization","type":"extras"},{"doc":"To use gettext you must define YourGear.Gettext.Antikythera's gear generator script automatically sets up YourGear.Gettext.Translation files are located in priv/gettext/${locale}/LC_MESSAGES/${domain}.po.${locale} is a locale such as en, jp, etc. Default locale is en.${domain} is the domain that can be used with dgettext and defaults to default.","ref":"i18n.html#preparing-translations","title":"Internationalization - Preparing translations","type":"extras"},{"doc":"You can also use mix gettext.extract and mix gettext.merge to manage translation files.As written in Gettext's README, the basic workflow will be as follows:Put gettext/1,2, dgettext/2,3 or other translation macro calls in your sources code.Run $ mix gettext.extract. All messages will be extracted into template files (priv/gettext/*.pot).This is basically an Elixir-equivalent of GNU's xgettext.Run $ mix gettext.merge priv/gettext/ --locale &lt;locale&gt;. Template files will be merged into translation files.Similarly, this corresponds to GNU's msginit or msgmerge.If the task is run for the first time, translation files will be generated from the template files.Add translations in translation files.Notice that you need to put macro calls in your code to use these features.In other words, messages appearing in translation function calls (e.g. Gettext.gettext(YourGear.Gettext, &quot;Some message&quot;)), cannot be extracted by the gettext.extract task.And importantly, messages passed to macro calls must be compile-time strings.You must use function calls to translate messages that dynamically change on runtime.Consider these trade-offs before deciding whether you use this extract-and-edit workflow, or just manually manage translation files.","ref":"i18n.html#workflow-using-gettext-mix-tasks-and-macros","title":"Internationalization - Workflow using Gettext mix tasks and macros","type":"extras"},{"doc":"First you have to determine where to receive locale information from your users. Popular options are:URL path: /some/site/ja/hello.htmlquery parameter: /some/site/hello.html?locale=jaAuto-generated YourGear.Gettext module comes with put_locale/1, which is a convenient wrapper around Gettext.put_locale/2. Invoke put_locale/1 within your controller action as follows (here in the case of query parameter):YourGear.Gettext.put_locale(conn.request.query_params[&quot;locale&quot;] || &quot;ja&quot;)The specified locale is stored within the process's process dictionary and will be used in later *gettext calls.","ref":"i18n.html#setting-locale-for-each-web-request","title":"Internationalization - Setting locale for each web request","type":"extras"},{"doc":"TestingNote: This page is being updated for OSS release. Please be patient.","ref":"testing.html","title":"Testing","type":"extras"},{"doc":"You can write tests for your gear using standard ExUnit test framework.StreamData (powerful property-based testing library) is also available out of the box. Consider using property-based style, especially when testing side-effect free functions.For testing purposes antikythera provides some helpers. See modules prefixed with Antikythera.Test.. Note that those modules are solely for test code; don't use these modules in your production code.","ref":"testing.html#libraries","title":"Testing - Libraries","type":"extras"},{"doc":"Antikythera defines the following two ways to run your gear's tests.Start an ErlangVM to run both production code and test code of your gear. This type of test execution is called whitebox testing as test code may touch the internal of the gear implementation.Start an ErlangVM to run only test code which interacts with an already-running ErlangVM that is executing your gear's production code. The tests in this mode check behavior of the target only through public interface of your gear (e.g. HTTP) and thus it's called blackbox testing.Running testswhitebox tests:$ mix testblackbox tests:$ TEST_MODE=blackbox_local mix testTest against locally running ErlangVM; Antikythera.Test.Config.base_url/0 points to your gear's URL in your local environment.$ TEST_MODE=blackbox_dev mix testTest against dev environment; Antikythera.Test.Config.base_url/0 points to your gear's URL in the antikythera dev environment.$ TEST_MODE=blackbox_prod mix testTest against prod environment; Antikythera.Test.Config.base_url/0 points to your gear's URL in the antikythera prod environment.You can specify when to run each of your tests by putting tags.@tag :blackbox : runs during both whitebox and blackbox testing@tag :blackbox_only : runs during blackbox testing; omitted during whitebox testing(no tag) : runs during whitebox testing; omitted during blackbox testingRecommendation on which tag to useIn general, your tests can be classified based on the following properties:target interfaceinternal (Elixir) functioninterface which users consume, such as HTTPinteraction with external service(s) during testdo not use any external serviceuse stubbed/mocked version of external service(s) to test in isolationuse real external service(s) for integration testingUse the following table as a general rule of thumb.target interfaceexternal serviceswhitebox testingblackbox testingtaga (Elixir)a (no)OXnonea (Elixir)b (stub)OXnonea (Elixir)c (yes)XX(high- and low-level concepts are mixed; don't write this kind of tests!)b (end-user)a (no)OO@blackboxb (end-user)b (stub)OXnoneb (end-user)c (yes)XO@blackbox_onlyReference: See also Antikythera.Test.Config","ref":"testing.html#whitebox-blackbox-testing-and-test-modes","title":"Testing - Whitebox/blackbox testing and test modes","type":"extras"},{"doc":"Sometimes tests require certain kind of secret that should not be hardcoded in tests.e.g. API key for an external serviceTo pass such information to test runner process, antikythera defines WHITEBOX_TEST_SECRET_JSON and BLACKBOX_TEST_SECRET_JSON environment variable.In your test cases you can obtain contents of the environment variable via Antikythera.Test.Config.whitebox_test_secret/0 or Antikythera.Test.Config.blackbox_test_secret/0 which returns JSON-parsed variable.","ref":"testing.html#secret-in-testing","title":"Testing - Secret in testing","type":"extras"},{"doc":"What Gears Must Not DoNote: This page is being updated for OSS release. Please be patient.(Some of the issues listed here are checked by compile.antikythera_gear_static_analysis every time you compile your gear's code.)Modules prefixed with Antikythera define interface functions to be used by gear implementations. On the other hand, modules with the other prefixes (AntikytheraCore, AntikytheraEal and AntikytheraLocal) are internal to antikythera and not for gear implementations. Gears must not directly depend on these antikythera-internal modules.All modules in a gear must be properly prefixed with the gear name, e.g. YourGear.SomeModule or Mix.Tasks.YourGear.SomeTask. Modules without correct prefixes are not allowed; they can cause name clashes.Dynamically creating atoms (e.g. make atoms from request bodies) is strictly prohibited as it is memory leak.Atoms are stored globally within an ErlangVM and are not garbage-collected. Accumulated memory resources occupied by dynamically created atoms can result in memory issue.Following code in runtime context are considered problematic:String.to_atom/1 : use String.to_existing_atom/1 insteadModule.concat/1,2 : use Module.safe_concat/1,2 insteadatom expression with interpolation such as :&quot;abc_\#{foo}&quot;Scheduling of Erlang processes is controlled by antikythera. Gear implementations must not disturb it by manually spawning/terminating processes.Accessing local file system is basically of no practical use, as they will be discarded by changes in underlying infrastructure configuration. However the following use cases are allowed:Reading files in your gear's priv directory. Files in your gear's priv directory are directly copied from the git repository during compilation and thus under your control.Reading/writing files within temporary directory created by Antikythera.Tmpdir.make/2.Writing to STDOUT/STDERR must also be avoided since these streams are used by antikythera and not for a specific gear. Use YourGear.Logger instead.","ref":"must_nots.html","title":"What Gears Must Not Do","type":"extras"}]